local thisdofilename dataset_aer
include ../lib_local/header

// load full dataset
u `formatteddatadir'/exp_dhs, clear

// replace nohhmem by anonymised version
rename nohhmem old_id
gen nohhmem = _n
list nohhmem old_id if ///
  old_id ==  116602 | ///
  old_id ==  225301 | ///
  old_id == 1084203 | ///
  old_id == 5638101 | ///
  old_id == 5949901

// define and label variables used in final version of paper
label var sex "Female"

gen agecat_exp12 = agecat_exp1 + agecat_exp2
label var agecat_exp12 "Age 16-34 years"
label var agecat_exp3 "Age 35-44 years"
label var agecat_exp4 "Age 45-54 years"
label var agecat_exp5 "Age 55-64 years"
label var agecat_exp6 "Age 65 years and older"

gen educ_exp12 = educ_exp1 + educ_exp2
gen educ_exp34 = educ_exp3 + educ_exp4
label var educ_exp12 "Primary / lower secondary education"
label var educ_exp34 "Higher secondary education / Intermediate Vocational Training"
label var educ_exp5 "Higher Vocational Training"
label var educ_exp6 "University Degree / University Student"

gen ninchhcat2_exp12 = 0
replace ninchhcat2_exp12 = ninchhcat2_exp1 + ninchhcat2_exp2
label var ninchhcat2_exp12 "Total net annual household income below $22\text{k Euros}$"
label var ninchhcat2_exp3 "Total net annual household income $\in [22\text{k Euros}; 40\text{k Euros})$"
label var ninchhcat2_exp4 "Total net annual household income at least $40\text{k Euros}$"

label var assetd1 "Total wealth below $10\text{k Euros}$"
label var assetd2 "Total wealth $\in [10\text{k Euros}; 50\text{k Euros})$"
label var assetd3 "Total wealth $\in [50\text{k Euros}; 200\text{k Euros})$"
label var assetd4 "Total wealth at least $200\text{k Euros}$"

label var finadmin "Respondent is the household's financial administrator"
label var finknowd "Respondent rates himself/herself as financially knowledgeable"

foreach i in 0 1 3 {
    gen incentive`i' = 0
    replace incentive`i' = 1 if incentive == `i'
}
label var incentive3 "High incentive treatment"
label var incentive0 "Hypothetical treatment"
label var incentive1 "Low incentive treatment"

gen durmed = 1 - durshort - durlong
label var durshort "Took less than 9 minutes to complete the experiment"
label var durmed "Took between 9 and 18 minutes to complete the experiment"
label var durlong "Took more than 18 minutes to complete the experiment"



// keep only minimal dataset to be put on AER website
keep nohhmem q?_* ///
  sex agecat_exp12 agecat_exp3 agecat_exp4 agecat_exp5 agecat_exp6 ///
  educ_exp12 educ_exp34 educ_exp5 educ_exp6 ///
  ninchhcat2_exp12 ninchhcat2_exp3 ninchhcat2_exp4 ///
  assetd1 assetd2 assetd3 assetd4 ///
  finadmin finknowd ///
  durshort durmed durlong duration ///
  incentive0 incentive1 incentive3 order2 ///
  nincons1 nincons2 nincons3 nincons4 nincons5 nincons6 nincons7 ninconswithin ///
  ninconstotal inconstotal1-inconstotal7 ///
  inconsist1_* inconsist2_* inconsist3_* inconsist4_* inconsist5_* inconsist6_* inconsist7_*

order nohhmem q?_* ///
  sex agecat_exp12 agecat_exp3 agecat_exp4 agecat_exp5 agecat_exp6 ///
  educ_exp12 educ_exp34 educ_exp5 educ_exp6 ///
  ninchhcat2_exp12 ninchhcat2_exp3 ninchhcat2_exp4 ///
  assetd1 assetd2 assetd3 assetd4 ///
  finadmin finknowd ///
  durshort durmed durlong duration ///
  incentive0 incentive1 incentive3 order2 ///
  nincons1 nincons2 nincons3 nincons4 nincons5 nincons6 nincons7 ninconswithin ///
  ninconstotal inconstotal1-inconstotal7 ///
  inconsist1_* inconsist2_* inconsist3_* inconsist4_* inconsist5_* inconsist6_* inconsist7_*

// implement sampling restrictions described in the appendix
drop if duration<5.33 | duration==.
foreach var of varlist sex - order2 {
    di "`var'"
    drop if `var' == .
}
drop duration

label data "Replication data: Gaudecker/Soest/Wengstrom, Heterogeneity in risky choice ..."
save `formatteddatadir'/exp_dhs_aer, replace

log close
scons_returncode
