local thisdofilename dhs
include ../lib_local/header
set maxvar 10000
set mem 500m

tempfile temp1 temp2 temp3 temp4 temp5 temp6 temp7 temp8 dhs_temp


// GENERAL HOUSEHOLD INFORMATION

u `rawdatadir'/dhs/hhi05en_alg
gen id_geninfo=1
gen nohhmem=nohhold*100+nomem
order nohhmem

replace geslacht=2 if nohhmem==8088001

sort nohhmem
save `temp1'


// HOUSEHOLD AND WORK

u `rawdatadir'/dhs/wrk05en_alg
gen id_hhwrk=1
gen nohhmem=nohhold*100+nomem
order nohhmem
sort nohhmem
save `temp2'


// ACCOMODATION AND MORTGAGES

u `rawdatadir'/dhs/hse05en_alg
gen id_accmort=1
gen nohhmem=nohhold*100+nomem
order nohhmem
sort nohhmem
save `temp3'


// ECONOMIC AND PSYCHOLOGICAL CONCEPTS

u `rawdatadir'/dhs/psy05en_alg
gen id_ecopsy=1
gen nohhmem=nohhold*100+nomem
order nohhmem
sort nohhmem
save `temp4'


// AGGREGATED DATA ON INCOME

u `rawdatadir'/dhs/agi05en_alg
gen id_agginc=1
gen nohhmem=nohhold*100+nomem
order nohhmem
sort nohhmem
save `temp5'


// AGGREGATED DATA ON ASSETS, MORTGAGES, AND LIABILITIES

u `rawdatadir'/dhs/agw05en_alg
gen id_aggass=1
gen nohhmem=nohhold*100+nomem
order nohhmem
sort nohhmem
save `temp6'


// DATA ON HEALTH AND INCOME

u `rawdatadir'/dhs/inc05en_alg
gen id_health=1
gen nohhmem=nohhold*100+nomem
order nohhmem
sort nohhmem
save `temp7'


// DATA ON ASSETS AND LIABILITIES

u `rawdatadir'/dhs/wth05en_alg
gen id_assets=1
gen nohhmem=nohhold*100+nomem
order nohhmem
sort nohhmem
save `temp8'


// MERGE THE TEMPORARY DATASETS, GENERATE RESPONSE INDICATORS

u `temp1'
forvalues j=2/8  {
    merge nohhmem using `temp`j'', sort
    drop _merge
    sort nohhmem
}
compress
foreach i of varlist id_geninfo id_hhwrk id_accmort id_ecopsy id_agginc id_aggass id_health id_assets {
    replace `i'=0 if `i'==.
    label value `i' `i'
}
label var id_geninfo "Answered General Info questionnaire"
label var id_hhwrk "Answered Household and Work questionnaire"
label var id_accmort "Answered Accomodation and Mortgages questionnaire"
label var id_ecopsy "Answered Economic and Psychological Concepts questionnaire"
label var id_agginc "Aggregated Income Questionnaire exists"
label var id_aggass "Aggregated Assets, Liabilities and Mortgages questionnaire exists"
label var id_health "Answered Health and Income questionnaire"
label var id_assets "Answered Assets and Liabilities questionnaire"

order nohhmem nohhold nomem id_geninfo id_hhwrk id_accmort id_ecopsy id_agginc id_aggass id_health


// EDUCATION, FOR SOME REASON APPEARS HERE ALREADY

gen oplcat=1 if (oplmet==1 | oplmet==2 | oplmet==9)
replace oplcat=2 if (oplmet==3)
replace oplcat=3 if (oplmet==4)
replace oplcat=4 if (oplmet==5)
replace oplcat=5 if (oplmet==6)
replace oplcat=6 if (oplmet==7)

qui tab oplcat, gen(educ_dhs)


// RENAME VARIABLES

rename inkhh incnethh_estdir
recode incnethh_estdir (2=1)
recode incnethh_estdir (3=2)
recode incnethh_estdir (4=3)
recode incnethh_estdir (5=4)
recode incnethh_estdir (6=4)
recode incnethh_estdir (7=.)
rename account finadmin
rename inkrond inc_enough_ind
rename ecsit econsit5yrs_ind
rename control investcontr
replace investcontr = investcontr - 1
rename kostwin breadwinner
rename burgst marstatus
qui tab marstatus, gen(marstatus)
rename kidout kidsout
recode kidsout (2=0)
rename gez1 tall_dhs
rename gez2 weight_dhs
rename gez3 srh
rename gez4 srhdelta1
rename gez5 longill
recode longill (2=0)
rename gez7 smoke
recode smoke (3=0)
rename gez8 ncigsday
rename gez9 drinks4day
recode drinks4day (2=0)
rename huisa1 gpcontact1
rename huisa2 gpcontact2
rename huisa3 gpcontact3
rename ziek workabsill
recode workabsill (2=0)
rename hziek workabsilldays
rename kans1 survprob75
rename kans2 survprob80
rename kans3 survprob85
rename kans4 survprob90
rename kans5 survprob95
rename kans6 survprob100
rename bz02 esavp_ind_offer
recode esavp_ind_offer (2=1)


// GENERATE VARIABLES


// ASSET VARIABLES: 1) DUMMIES

// employer sponsored savings plans (yes/no)
gen esavp_ind=b2a
replace esavp_ind=1 if b2a>0 & b2a<.
sort nohhold nomem
save `dhs_temp'
collapse (max) esavp_hh=esavp_ind, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
drop _merge

// savings AA - savings, deposit books,..., incl. bonds, incl. annuity
gen savingsAA=0
replace savingsAA=1 if b3a>0 & b3a<.
replace savingsAA=1 if b4a>0 & b4a<.
replace savingsAA=1 if b6a>0 & b6a<.
replace savingsAA=1 if b7a>0 & b7a<.
replace savingsAA=1 if b13a>0 & b13a<.
replace savingsAA=. if b3a==. & b4a==. & b6a==. & b7a==. & b13a==.
sort nohhold nomem
save `dhs_temp', replace
collapse (max) savingsAA=savingsAA, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
drop _merge

// savings AB - savings, deposit books,..., incl. bonds, excl. annuity
gen savingsAB=0
replace savingsAB=1 if b3a>0 & b3a<.
replace savingsAB=1 if b4a>0 & b4a<.
replace savingsAB=1 if b6a>0 & b6a<.
replace savingsAB=1 if b13a>0 & b13a<.
replace savingsAB=. if b3a==. & b4a==. & b6a==. & b13a==.
sort nohhold nomem
save `dhs_temp', replace
collapse (max) savingsAB=savingsAB, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
drop _merge

// savings BA - savings, deposit books,..., excl. bonds, incl. annuity
gen savingsBA=0
replace savingsBA=1 if b3a>0 & b3a<.
replace savingsBA=1 if b4a>0 & b4a<.
replace savingsBA=1 if b6a>0 & b6a<.
replace savingsBA=1 if b7a>0 & b7a<.
replace savingsBA=. if b3a==. & b4a==. & b6a==. & b7a==.
sort nohhold nomem
save `dhs_temp', replace
collapse (max) savingsBA=savingsBA, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
drop _merge

// savings BB - savings, deposit books,..., excl. bonds, excl. annuity
gen savingsBB=0
replace savingsBB=1 if b3a>0 & b3a<.
replace savingsBB=1 if b4a>0 & b4a<.
replace savingsBB=1 if b6a>0 & b6a<.
replace savingsBB=. if b3a==. & b4a==. & b6a==.
sort nohhold nomem
save `dhs_temp', replace
collapse (max) savingsBB=savingsBB, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
drop _merge

// funds AC - funds, stocks, shares, options, excl. real estates not
// used for own accomodation, excl. bonds
gen fundsAC=0
replace fundsAC=1 if b11a>0 & b11a<.
replace fundsAC=1 if b12a>0 & b12a<.
replace fundsAC=1 if b14a>0 & b14a<.
replace fundsAC=1 if b15a==1
replace fundsAC=. if b11a==. & b12a==. & b14a==. & b15a==.
sort nohhold nomem
save `dhs_temp', replace
collapse (max) fundsAC=fundsAC, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
drop _merge

// funds BC - funds, stocks, shares, options, excl. real estates not
// used for own accomodation, incl. bonds
gen fundsBC=0
replace fundsBC=1 if b11a>0 & b11a<.
replace fundsBC=1 if b12a>0 & b12a<.
replace fundsBC=1 if b13a>0 & b13a<.
replace fundsBC=1 if b14a>0 & b14a<.
replace fundsBC=1 if b15a==1
replace fundsBC=. if b11a==. & b12a==. & b13a==. & b14a==. & b15a==.
sort nohhold nomem
save `dhs_temp', replace
collapse (max) fundsBC=fundsBC, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
drop _merge

// funds AD - funds, stocks, shares, options, incl. real estates not
// used for own accomodation, excl. bonds
gen fundsAD=0
replace fundsAD=1 if b11a>0 & b11a<.
replace fundsAD=1 if b12a>0 & b12a<.
replace fundsAD=1 if b14a>0 & b14a<.
replace fundsAD=1 if b15a==1
replace fundsAD=1 if b19oga>0 & b19oga<.
replace fundsAD=. if b11a==. & b12a==. & b14a==. & b15a==. & b19oga==.
sort nohhold nomem
save `dhs_temp', replace
collapse (max) fundsAD=fundsAD, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
drop _merge

// funds BD - funds, stocks, shares, options, incl. real estates not
// used for own accomodation, incl. bonds
gen fundsBD=0
replace fundsBD=1 if b11a>0 & b11a<.
replace fundsBD=1 if b12a>0 & b12a<.
replace fundsBD=1 if b13a>0 & b13a<.
replace fundsBD=1 if b14a>0 & b14a<.
replace fundsBD=1 if b15a==1
replace fundsBD=1 if b19oga>0 & b19oga<.
replace fundsBD=. if b11a==. & b12a==. & b13a==. & b14a==. & b15a==. & b19oga==.
sort nohhold nomem
save `dhs_temp', replace
collapse (max) fundsBD=fundsBD, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
drop _merge

// houseowner - owner of current accomodation?
sort nohhold nomem
save `dhs_temp', replace
collapse (max) wo1_new=wo1, by (nohhold)
// this works because not more than one person
// per household has answered this question
sort nohhold
qui merge nohhold using `dhs_temp'
gen houseowner=(wo1_new==3)
replace houseowner=. if wo1_new==.
drop _merge


// ASSET VARIABLES: 2) VALUES

// value of employer-sponsored savings plans
gen esavp_ind_val=b2b
sort nohhold nomem
save `dhs_temp', replace
collapse (sum) esavp_hh_val=esavp_ind_val, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
replace esavp_hh_val=. if esavp_hh==. | esavp_hh==0
drop _merge

// value of savings AA
gen savingsAA_val=b3b+b4b+b6b+b7b+b13b
sort nohhold nomem
save `dhs_temp', replace
collapse (sum) savingsAA_val=savingsAA_val, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
replace savingsAA_val=. if savingsAA==. | savingsAA==0
drop _merge

// value of savings AB
gen savingsAB_val=b3b+b4b+b6b+b13b
sort nohhold nomem
save `dhs_temp', replace
collapse (sum) savingsAB_val=savingsAB_val, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
replace savingsAB_val=. if savingsAB==.| savingsAB==0
drop _merge

// value of savings BA
gen savingsBA_val=b3b+b4b+b6b+b7b
sort nohhold nomem
save `dhs_temp', replace
collapse (sum) savingsBA_val=savingsBA_val, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
replace savingsBA_val=. if savingsBA==.| savingsBA==0
drop _merge

// value of savings BB
gen savingsBB_val=b3b+b4b+b6b
sort nohhold nomem
save `dhs_temp', replace
collapse (sum) savingsBB_val=savingsBB_val, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
replace savingsBB_val=. if savingsBB==. | savingsBB==0
drop _merge

// value of funds AC
gen fundsAC_val=b11b+b12b+b14b+b15b
sort nohhold nomem
save `dhs_temp', replace
collapse (sum) fundsAC_val=fundsAC_val, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
replace fundsAC_val=. if fundsAC==. | fundsAC==0
drop _merge

// value of funds BC
gen fundsBC_val=b11b+b12b+b13b+b14b+b15b
sort nohhold nomem
save `dhs_temp', replace
collapse (sum) fundsBC_val=fundsBC_val, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
replace fundsBC_val=. if fundsBC==. | fundsBC==0
drop _merge

// value of funds AD
gen fundsAD_val=b11b+b12b+b14b+b15b+b19ogb
sort nohhold nomem
save `dhs_temp', replace
collapse (sum) fundsAD_val=fundsAD_val, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
replace fundsAD_val=. if fundsAD==. | fundsAD==0
drop _merge

// value of funds BD
gen fundsBD_val=b11b+b12b+b13b+b14b+b15b+b19ogb
sort nohhold nomem
save `dhs_temp', replace
collapse (sum) fundsBD_val=fundsBD_val, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
replace fundsBD_val=. if fundsBD==. | fundsBD==0
drop _merge

// value of own accomodation
replace wod44s=. if wod44s==9999999
replace wod44s=wod44s/1000 if wod44s>1986 & wod44s<.
sort nohhold nomem
save `dhs_temp', replace
collapse (sum) wod44s_new=wod44s (count) flag=wod44s, by (nohhold)
gen house_val=wod44s_new*1000
sort nohhold
qui merge nohhold using `dhs_temp'
replace house_val=. if flag==0
drop _merge flag


// ASSET VARIABLES: 3) AGGREGATES

// existence of any debts
gen debts=0
forvalues i=1/8  {
    replace debts=1 if s`i'a>0 & s`i'a<.
}
replace debts=. if s1a==. & s2a==. & s3a==. & s4a==. & s5a==. & s6a==. & s7a==. & s8a==.
sort nohhold nomem
save `dhs_temp', replace
collapse (max) debts=debts, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
drop _merge

// existence of any mortgages
gen mortg=0
replace mortg=1 if b26hya>0 & b26hya<.
replace mortg=1 if b27hya>0 & b27hya<.
replace mortg=. if b26hya==. & b27hya==.
sort nohhold nomem
save `dhs_temp', replace
collapse (max) mortg=mortg, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
drop _merge

// value of all debts
gen debts_val=s1b+s2b+s3b+s4b+s5b+s6b+s7b+s8b
sort nohhold nomem
save `dhs_temp', replace
collapse (sum) debts_val=debts_val, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
replace debts_val=. if debts==0 | debts==.
drop _merge

// value of all mortgages
gen mortg_val=b26hyb+b27hyb
sort nohhold nomem
save `dhs_temp', replace
collapse (sum) mortg_val=mortg_val, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
replace mortg_val=. if mortg==0 | mortg==.
drop _merge

// existence / value of any debts & mortgages
gen debtmortg=1
replace debtmortg=0 if debts==0 & mortg==0
replace debtmortg=. if debts==. & mortg==.
gen debtmortg_val=.
replace debtmortg_val=debts_val+mortg_val
replace debtmortg_val=debts_val if debtmortg_val==. & debts==1
replace debtmortg_val=mortg_val if debtmortg_val==. & mortg==1

// existence of any assets
gen assets1=0
replace assets1=. if esavp_hh==. & savingsBA==. & fundsBD==.
replace assets1=1 if esavp_hh==1 | savingsBA==1 | fundsBD==1
gen assets2=0
replace assets2=. if esavp_hh==. & savingsBA==. & fundsBD==. & houseowner==.
replace assets2=1 if esavp_hh==1 | savingsBA==1 | fundsBD==1 | houseowner==1

// value of all assets
gen assets1_val=esavp_hh_val
replace assets1_val=assets1_val+savingsBA_val if savingsBA_val <.
replace assets1_val= savingsBA_val if assets1_val==. & esavp_hh==0
replace assets1_val=assets1_val+ fundsBD_val if fundsBD_val <.
replace assets1_val= fundsBD_val if assets1_val==. & esavp_hh==0 & savingsBA==0
replace assets1_val=assets1_val- debts_val if debts_val <.
replace assets1_val= -debts_val if assets1_val==. & esavp_hh==0 & savingsBA==0 & fundsBD_val==0

gen assets2_val=assets1_val
replace assets2_val=assets2_val+house_val if house_val<.
replace assets2_val= house_val if assets2_val==. & assets2==0
replace assets2_val=assets2_val-mortg_val if mortg_val<.
replace assets2_val= -mortg_val if assets2_val==. & assets2==0

gen assetd1=0
gen assetd2=0
gen assetd3=0
gen assetd4=0
replace assetd1=1 if assets2_val<= 10000 & assets2_val!=.
replace assetd2=1 if assets2_val> 10000 & assets2_val<= 50000 & assets2_val!=.
replace assetd3=1 if assets2_val> 50000 & assets2_val<=200000 & assets2_val!=.
replace assetd4=1 if assets2_val>200000 & assets2_val!=.
replace assetd1=. if assets2_val==.
replace assetd2=. if assets2_val==.
replace assetd3=. if assets2_val==.
replace assetd4=. if assets2_val==.


// INCOME VARIABLES

// aggregated data on income
sort nohhold nomem
save `dhs_temp', replace
collapse (sum) incnethh_sumind=ntot incgrhh=btot, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
drop _merge


// VARIABLES ON ECONOMIC AND PSYCHOLOGICAL CONCEPTS

// difficulties to get by on income at the household level
sort nohhold nomem
save `dhs_temp', replace
collapse (mean) inc_enough_hh=inc_enough_ind econsit5yrs_hh=econsit5yrs_ind, by (nohhold)
sort nohhold
qui merge nohhold using `dhs_temp'
drop _merge

// Summe der einzelnen Spargrnden beigemessenen Bedeutung (Skala 1-6)
gen saveimport=0
forvalues i = 1/9  {
    replace saveimport = saveimport + spaarm0`i' - 1
    rename spaarm0`i' saveimport`i'
    replace saveimport`i' = saveimport`i' - 1
}
forvalues i = 10/16  {
    replace saveimport = saveimport + spaarm`i' - 1
    rename spaarm`i' saveimport`i'
    replace saveimport`i' = saveimport`i' - 1
}
// Summe der Bewertungen (Skala 1-6) verschiedener Spargrnde
gen savemotive=0
replace stig03=8-stig03
replace stig09=8-stig09
forvalues i = 1/9  {
    replace savemotive = savemotive + stig0`i' - 1
    rename stig0`i' savemotive`i'
    replace savemotive`i' = savemotive`i' - 1
}
replace stig14=8-stig14
replace stig18=8-stig18
replace stig20=8-stig20
replace stig21=8-stig21
forvalues i = 10/21  {
    replace savemotive = savemotive + stig`i' - 1
    rename stig`i' savemotive`i'
    replace savemotive`i' = savemotive`i' - 1
}
// Summe der Bewertungen (Skala 1-6) der eigenen Situation mit der anderer
gen peersitu=0
replace situat3=8-situat3
forvalues i = 1/4  {
    replace peersitu = peersitu + situat`i' - 1
    rename situat`i' peersitu`i'
    replace peersitu`i'=peersitu`i' - 1
}
// Summe der Bewertungen (Skala 1-6) von Investitionen
gen investatt=0
replace spaar3=8-spaar3
replace spaar5=8-spaar5
replace spaar6=8-spaar6
forvalues i = 1/6  {
    replace investatt = investatt + spaar`i' - 1
    rename spaar`i' investatt`i'
    replace investatt`i' = investatt`i' - 1
}
// REGION OF RESIDENCE ETC.

rename sted urban_dhs
tab urban_dhs, gen(urband)
rename regio region
tab region, gen(regiond)
rename prov province
tab province, gen(provinced)


// KEEP IMPORRTANT VARIABLES, SAVE

keep nohhmem nohhold nomem btot ntot incnethh_estdir ///
  finadmin inc_enough_ind inc_enough_hh econsit5yrs_ind econsit5yrs_hh ///
  investcontr breadwinner marstatus* kidsout partner ///
  esavp_ind_offer esavp_ind esavp_hh ///
  savingsAA savingsAB savingsBA savingsBB ///
  fundsAC fundsBC fundsAD fundsBD ///
  houseowner esavp_ind_val esavp_hh_val ///
  savingsAA_val savingsAB_val savingsBA_val savingsBB_val ///
  fundsAC_val fundsBC_val fundsAD_val fundsBD_val ///
  house_val debts debts_val mortg mortg_val debtmortg debtmortg_val ///
  assets1 assets1_val assets2 assets2_val assetd1 assetd2 assetd3 assetd4 ///
  btot ntot incgrhh incnethh_sumind incnethh_estdir ///
  saveimport* peersitu* savemotive* investatt* investcontr ///
  tall_dhs weight_dhs srh srhdelta1 longill smoke ncigsday ///
  drinks4day gpcontact* workabsill* survprob* ///
  urban* region* province*

sort nohhmem
label data "DHS 2005, formatted"
compress
saveold `formatteddatadir'/dhs, replace
log close
scons_returncode

