local thisdofilename merge
include ../lib_local/header
set maxvar 10000
set mem 700m
tempfile tempdata

// MERGE AND APPEND DATASET

u `formatteddatadir'/centerpanel_exp
merge nohhmem using `formatteddatadir'/dhs
tab _merge
drop _merge
sort nohhmem


// CONSISTENCY CHECKS ACROSS ANSWERS

forvalues j=1(1)7  {
    disp " CONSISTENCY CHECK 1: ANSWERS ON FIRST SCREEN CONSISTENT? QUESTION " `j'
    gen inconsist1_`j'=0
    replace inconsist1_`j'=1 if q`j'_10==. & q`j'_40==. & q`j'_60==. & q`j'_80==.
    replace inconsist1_`j'=0 if q`j'_25==0 & q`j'_50==0 & q`j'_75==0 & q`j'_100==0
}
gen nincons1=inconsist1_1+inconsist1_2+inconsist1_3+inconsist1_4+inconsist1_5+inconsist1_6+inconsist1_7

forvalues j=1(1)7  {
    disp " CONSISTENCY CHECK 2: ANSWERS ON SECOND SCREEN CONSISTENT? QUESTION " `j'
    gen inconsist2_`j'=0
    forvalues i1=10(10)100   {
        local i0=`i1'-10
        replace inconsist2_`j'=1 if q`j'_`i1'-q`j'_`i0'<0 & q`j'_`i1'<. & q`j'_`i0'<.
    }
}
gen nincons2=inconsist2_1+inconsist2_2+inconsist2_3+inconsist2_4+inconsist2_5+inconsist2_6+inconsist2_7

forvalues j=1(1)7  {
    disp " CONSISTENCY CHECK 3: ANSWERS BETWEEN FIRST AND SECOND SCREEN CONSISTENT? QUESTION " `j'
    gen inconsist3_`j'=0
    replace inconsist3_`j'=1 if q`j'_0 == 1
    replace inconsist3_`j'=1 if q`j'_30 == 0 & q`j'_0 !=.
    replace inconsist3_`j'=1 if q`j'_20 == 1 & q`j'_40 !=.
    replace inconsist3_`j'=1 if q`j'_50a == 0 & q`j'_40 !=.
    replace inconsist3_`j'=1 if q`j'_50a == 1 & q`j'_60 !=.
    replace inconsist3_`j'=1 if q`j'_80 == 0 & q`j'_60 !=.
    replace inconsist3_`j'=1 if q`j'_70 == 1 & q`j'_100a!=.
    replace inconsist3_`j'=1 if q`j'_100a== 0
}
gen nincons3=inconsist3_1+inconsist3_2+inconsist3_3+inconsist3_4+inconsist3_5+inconsist3_6+inconsist3_7

forvalues j=1(1)7  {
    disp " CONSISTENCY CHECK 4: ANSWERS TO 50% QUESTIONS ON FIRST / SECOND SHEET CONSISTENT? QUESTION " `j'
    gen inconsist4_`j'=0
    replace inconsist4_`j'=1 if q`j'_50a == 0 & q`j'_40 !=.
    replace inconsist4_`j'=1 if q`j'_50a == 1 & q`j'_60 !=.
}
gen nincons4=inconsist4_1+inconsist4_2+inconsist4_3+inconsist4_4+inconsist4_5+inconsist4_6+inconsist4_7

forvalues j=1(1)7  {
    disp " CONSISTENCY CHECK 5: ANSWERS TO FIRST 100% QUESTIONS EQUAL TO B? QUESTION " `j'
    gen inconsist5_`j'=0
    replace inconsist5_`j'=1 if q`j'_100 == 0
}
gen nincons5=inconsist5_1+inconsist5_2+inconsist5_3+inconsist5_4+inconsist5_5+inconsist5_6+inconsist5_7

forvalues j=1(1)7  {
    disp " CONSISTENCY CHECK 6: ANSWERS TO SECOND 100% QUESTIONS EQUAL TO B? QUESTION " `j'
    gen inconsist6_`j'=0
    replace inconsist6_`j'=1 if q`j'_100a== 0
}
gen nincons6=inconsist6_1+inconsist6_2+inconsist6_3+inconsist6_4+inconsist6_5+inconsist6_6+inconsist6_7

forvalues j=1(1)7  {
    disp " CONSISTENCY CHECK 7: ANSWERS TO 0% QUESTION (SECOND SCREEN) EQUAL TO A? QUESTION " `j'
    gen inconsist7_`j'=0
    replace inconsist7_`j'=1 if q`j'_0==1
}
gen nincons7=inconsist7_1+inconsist7_2+inconsist7_3+inconsist7_4+inconsist7_5+inconsist7_6+inconsist7_7

forvalues sheet=1/7  {
    gen inconstotal`sheet'=0 if anyexp==1
    foreach type in 1 2 3 5 6 7   {
        // don't include type 4: could be indifference!!!
        replace inconstotal`sheet'=inconstotal`sheet'+inconsist`type'_`sheet'
    }
    replace inconstotal`sheet'=1 if inconstotal`sheet'>1 & inconstotal`sheet'<.
}
gen ninconswithin=nincons1+nincons2
gen ninconstotal=inconstotal1+inconstotal2+inconstotal3+inconstotal4+inconstotal5+inconstotal6+inconstotal7

tab1 nincons*


// SORT, ORDER, AND LABEL

label drop _all
foreach j of varlist _all  {
    label val `j' `j'
}
label variable nohhmem "Unique Person ID"
label variable nohhold "Household ID"
label variable nomem "Within-Household ID"
label variable findecide "decision of financial matters"
label define findecide 1 "always partner" 2 "partner more than i" 3 "partner and i equally" 4 "i more than partner" 5 "always i"
label variable findec1 "findecide$>$3"
label variable findec1m "findecide$>$3 \& sex$==$0"
label variable findec1f "findecide$>$3 \& sex$==$1"
label variable findec2 "findecide$>=$3"
label variable findec2m "findecide$>=$3 \& sex$==$0"
label variable findec2f "findecide$>=$3 \& sex$==$1"
label variable btot "total gross income per year"
label variable ntot "total net income per year"
label variable incgrhh "household gross income per year"
label variable incnethh_sumind "household net income per year"
label variable incnethh_estdir "estimated total net income"
label variable ninchhcat2_exp1 "$<$14000"
label variable ninchhcat2_exp2 "$>=$14000 \& $<$22000"
label variable ninchhcat2_exp3 "$>=$22000 \& $<$40000"
label variable ninchhcat2_exp4 "$>=$40000"
label variable positionhh_exp1 "head of the household"
label variable positionhh_exp2 "spouse"
label variable positionhh_exp3 "permanent partner (not married)"
label variable positionhh_exp4 "parent (in law)"
label variable positionhh_exp5 "child living at home"
label variable positionhh_exp6 "housemate"
label variable positionhh_exp7 "family member or border"
label variable sex "sex"
label de sex 0 "male" 1 "female"
label variable birthyear_exp "year of birth"
label variable age_exp "age"
label variable agecat_exp1 "15-24 years"
label variable agecat_exp2 "25-34 years"
label variable agecat_exp3 "35-44 years"
label variable agecat_exp4 "45-54 years"
label variable agecat_exp5 "55-64 years"
label variable agecat_exp6 "65 years and older"
label variable typehh_exp1 "is living by himself/herself"
label variable typehh_exp2 "living together, no children"
label variable typehh_exp3 "living together plus children"
label variable typehh_exp4 "without a partner, with children"
label variable typehh_exp5 "other"
label variable urban_exp1 "very high degree of urbanization"
label variable urban_exp2 "high degree of urbanization"
label variable urban_exp3 "moderate degree of urbanization"
label variable urban_exp4 "low degree of urbanization"
label variable urban_exp5 "very low degree of urbanization"
label variable occu_exp1 "employed on a contractual basis"
label variable occu_exp2 "works in own business"
label variable occu_exp3 "free profession"
label variable occu_exp4 "looking for work"
label variable occu_exp5 "looking for first-time work"
label variable occu_exp6 "student"
label variable occu_exp7 "works in own household"
label variable occu_exp8 "retired (pre-retired, AOW, VUT)"
label variable occu_exp9 "partly disabled"
label variable occu_exp10 "unpaid work"
label variable occu_exp11 "works as a volunteer"
label variable occu_exp12 "other occupation"
label variable educ_exp1 "primary education"
label variable educ_exp2 "lower secondary education"
label variable educ_exp3 "higher secondary education"
label variable educ_exp4 "intermediate vocational training"
label variable educ_exp5 "higher vocational training"
label variable educ_exp6 "university"
label variable occu3_exp1 "occstatus: working"
label variable occu3_exp2 "occstatus: unemloyed"
label variable occu3_exp3 "occstatus: other"
label variable numkidshh_exp "number of children in the household"
label variable kids_dummy "children yes/no"
label variable finknowd "financial knowledge = (very) knowledgeable"
label variable finadmin "does financial administration"
label variable marstatus1 "having community of property"
label variable marstatus2 "with a marriage settlement"
label variable marstatus3 "divorced from spouse"
label variable marstatus4 "living together with partner"
label variable marstatus5 "widowed"
label variable marstatus6 "never married"
label variable kidsout "children, not in the household"
label variable inc_enough_ind "managing on the total income (individual)"
label variable inc_enough_hh "managing on the total income (household)"
label variable econsit5yrs_ind "situation in five years (individual)"
label variable econsit5yrs_hh "situation in five years (household)"
label variable saveimport "assessment - importance of saving money"
label variable peersitu "assessment - own situation compared to the situation others"
label variable savemotive "attitude towards saving money"
label variable investatt "attitude towards taking risks to receive heigher returns on savings"
label variable investcontr "control of investments and returns"
label variable alone1 "presence - no, nobody"
label variable alone2 "presence - yes, my spouse"
label variable alone3 "presence - yes, my parent(s)"
label variable alone4 "presence - yes, my kids"
label variable alone5 "presence - yes, someone else"
label variable tall_dhs "body height"
label variable weight_dhs "weight"
label variable srh "state of health"
label variable srhdelta1 "health is better than one year ago"
label variable longill "long illness, disorder, or handicap"
label variable smoke "smoking cigarettes"
label variable ncigsday "how many cigarettes"
label variable gpcontact1 "having phoned general practitioner"
label variable gpcontact2 "having visited general practitioner"
label variable gpcontact3 "being visited by general practitioner"
label variable workabsill "absence from work because of illness"
label variable workabsilldays "how many days absent"
label variable survprob75 "attaining (at least) the age of 75"
label variable survprob80 "attaining (at least) the age of 80"
label variable survprob85 "attaining (at least) the age of 85"
label variable survprob90 "attaining (at least) the age of 90"
label variable survprob95 "attaining (at least) the age of 95"
label variable survprob100 "attaining (at least) the age of 100"
label variable esavp_ind_offer "employer sponsered savings plan offered (individual)"
label variable esavp_ind "holds employer sponsored savings plan (individual)"
label variable esavp_hh "holds employer sponsored savings plan (household)"
label variable savingsAA "holds savings or deposit accounts, incl. bonds, incl. annuity (household)"
label variable savingsAB "holds savings or deposit accounts, incl. bonds, excl. annuity (household)"
label variable savingsBA "holds savings or deposit accounts, excl. bonds, incl. annuity (household)"
label variable savingsBB "holds savings or deposit accounts, excl. bonds, excl. annuity (household)"
label variable fundsAC "holds funds, excl. real estates, excl. bonds (household)"
label variable fundsBC "holds funds, excl. real estates, incl. bonds (household)"
label variable fundsAD "holds funds, incl. real estates, excl. bonds (household)"
label variable fundsBD "holds funds, incl. real estates, incl. bonds (household)"
label variable houseowner "owner of current accomodation (household)"
label variable esavp_ind_val "value of employer sponsored savings plans (individual)"
label variable esavp_hh_val "value of employer sponsored savings plans (household)"
label variable savingsAA_val "value of savings or deposit accounts, incl. bonds, incl. annuity (household)"
label variable savingsAB_val "value of savings or deposit accounts, incl. bonds, excl. annuity (household)"
label variable savingsBA_val "value of savings or deposit accounts, excl. bonds, incl. annuity (household)"
label variable savingsBB_val "value of savings or deposit accounts, excl. bonds, excl. annuity (household)"
label variable fundsAC_val "value of funds excl. real estates, excl. bonds (household)"
label variable fundsBC_val "value of excl. real estates, incl. bonds (household)"
label variable fundsAD_val "value of incl. real estates, excl. bonds (household)"
label variable fundsBD_val "value of incl. real estates, incl. bonds (household)"
label variable debts "has any debts (household)"
label variable mortg "has any mortgages (household)"
label variable debtmortg "has any debts or mortgages (household)"
label variable debts_val "value of all debts (household)"
label variable mortg_val "value of all mortgages (household)"
label variable debtmortg_val "value of all debts and mortgages (household)"
label variable assets1 "holds any assets excl. real estate (household)"
label variable assets2 "holds any assets incl. real estate (household)"
label variable assets1_val "value of all assets excl. real estate (household)"
label variable assets2_val "value of all assets incl. real estate (household)"
label variable assetd1 "Total value all assets less than 10,000 Euros"
label variable assetd2 "Total value all assets more than 10,000 Euros and less than 50,000 Euros"
label variable assetd3 "Total value all assets more than 50,000 Euros and less than 200,000 Euros"
label variable assetd4 "Total value all assets more than 200,000 Euros"
label define incnethh_estdir 1 "less than 14,000 euro" 2 "14,000 - 22,000 euro" 3 "22,000 - 40,000 euro" 4 "more than 40,000 euro"
label var order2 "Order Treatment 2"
label de order 0 "Order 1" 1 "Order 2", add
label var incentive "Incentive Treatment"
label de incentive 0 "No Incentive" 1 "1x Incentive" 3 "3x Incentive"
label var anyexp "Participation in any Experiment"
label var exptype "Participation in CentERp, LabSept, LabMay"
label de exptype 1 "CentERpanel" 2 "Lab Sept" 3 "Lab May"
label var q1_0
label var q1_10
label var q1_20
label var q1_25
label var q1_30
label var q1_40
label var q1_50
label var q1_50a
label var q1_60
label var q1_70
label var q1_75
label var q1_80
label var q1_90
label var q1_100
label var q1_100a
label var q2_0
label var q2_10
label var q2_20
label var q2_25
label var q2_30
label var q2_40
label var q2_50
label var q2_50a
label var q2_60
label var q2_70
label var q2_75
label var q2_80
label var q2_90
label var q2_100
label var q2_100a
label var q3_0
label var q3_10
label var q3_20
label var q3_25
label var q3_30
label var q3_40
label var q3_50
label var q3_50a
label var q3_60
label var q3_70
label var q3_75
label var q3_80
label var q3_90
label var q3_100
label var q3_100a
label var q4_0
label var q4_10
label var q4_20
label var q4_25
label var q4_30
label var q4_40
label var q4_50
label var q4_50a
label var q4_60
label var q4_70
label var q4_75
label var q4_80
label var q4_90
label var q4_100
label var q4_100a
label var q5_0
label var q5_10
label var q5_20
label var q5_25
label var q5_30
label var q5_40
label var q5_50
label var q5_50a
label var q5_60
label var q5_70
label var q5_75
label var q5_80
label var q5_90
label var q5_100
label var q5_100a
label var q6_0
label var q6_10
label var q6_20
label var q6_25
label var q6_30
label var q6_40
label var q6_50
label var q6_50a
label var q6_60
label var q6_70
label var q6_75
label var q6_80
label var q6_90
label var q6_100
label var q6_100a
label var q7_0
label var q7_10
label var q7_20
label var q7_25
label var q7_30
label var q7_40
label var q7_50
label var q7_50a
label var q7_60
label var q7_70
label var q7_75
label var q7_80
label var q7_90
label var q7_100
label var q7_100a
label var nincons1 "Number of Nonmonotonicities within First Screen"
label var nincons2 "Number of Nonmonotonicities within Second Screen"
label var nincons3 "Number of Nonmonotonicities between First and Second Screens"
label var nincons4 "Number of Inconsistencies between First and Second 50\% Question"
label var nincons5 "Number of First 100\% Answers equal to A"
label var nincons6 "Number of Second 100\% Answers equal to A"
label var nincons7 "Number of Second 0\% Answers equal to B"
label var ninconswithin "Number of Inconsistent Answers within Screens"
label var ninconstotal "Overall Number of Inconsistent Answers"
label var weeknr "Week in which Experiment was performed"
label var begin_datetime "Experiment: Start Date and Time"
label var end_datetime "Experiment: End Date and Time"
label var duration_exp "Duration of the Experiment (Minutes)"
label var durshort "Duration below 9 Minutes"
label var durlong "Duration above 18 Minutes"
label var remarks "Experiment: Remarks given"
label var centerp_resp "Response mode to CentERpanel experiment"
label def centerp_resp 1 "Completed Quest." 2 "Nonpart. Screen 1" 3 "Drop Out", add

sort nohhmem

order nohhmem nohhold nomem anyexp exptype centerpanel centerp_resp order incentive ///
  sex birthyear_exp age_exp agecat_exp* marstatus* partner typehh_exp* urban_exp* educ_exp* occu_exp* occu3_exp* ///
  nummemhh_exp kids_dummy numkidshh_exp kidsout ///
  btot ntot incgrhh incnethh_sumind incnethh_estdir ninchhcat2* ninchh2_exp nincind2_exp ginc* incnorm* ///
  esavp_ind_offer esavp_ind esavp_hh savingsAA savingsAB savingsBA savingsBB ///
  fundsAC fundsBC fundsAD fundsBD houseowner ///
  esavp_ind_val esavp_hh_val savingsAA_val savingsAB_val savingsBA_val savingsBB_val ///
  fundsAC_val fundsBC_val fundsAD_val fundsBD_val house_val ///
  debts mortg debtmortg assets1 assets2 ///
  debts_val mortg_val debtmortg_val assets1_val assets2_val ///
  assetd1 assetd2 assetd3 assetd4 ///
  finsitu_exp* positionhh* horizon* findecide findec1 findec1m findec1f findec2 findec2m findec2f findechh_exp* mondechh_exp* ///
  finknowd finknowl_exp* finadmin breadwinner inc_enough_ind inc_enough_hh ///
  econsit5yrs_ind econsit5yrs_hh alone1 alone2 alone3 alone4 alone5 saveimport* peersitu* savemotive* ///
  investatt* investcontr tall_exp tall_dhs weight_dhs ///
  srh srhdelta1 longill smoke ncigsday drinks4day gpcontact* ///
  workabsill workabsilldays survprob* ///
  weeknr begin_datet end_datet duration_exp durshort durlong remarks ///
  q1_0 q1_10 q1_20 q1_25 q1_30 q1_40 q1_50 q1_50a q1_60 q1_70 q1_75 q1_80 q1_90 q1_100 q1_100a ///
  q2_0 q2_10 q2_20 q2_25 q2_30 q2_40 q2_50 q2_50a q2_60 q2_70 q2_75 q2_80 q2_90 q2_100 q2_100a ///
  q3_0 q3_10 q3_20 q3_25 q3_30 q3_40 q3_50 q3_50a q3_60 q3_70 q3_75 q3_80 q3_90 q3_100 q3_100a ///
  q4_0 q4_10 q4_20 q4_25 q4_30 q4_40 q4_50 q4_50a q4_60 q4_70 q4_75 q4_80 q4_90 q4_100 q4_100a ///
  q5_0 q5_10 q5_20 q5_25 q5_30 q5_40 q5_50 q5_50a q5_60 q5_70 q5_75 q5_80 q5_90 q5_100 q5_100a ///
  q6_0 q6_10 q6_20 q6_25 q6_30 q6_40 q6_50 q6_50a q6_60 q6_70 q6_75 q6_80 q6_90 q6_100 q6_100a ///
  q7_0 q7_10 q7_20 q7_25 q7_30 q7_40 q7_50 q7_50a q7_60 q7_70 q7_75 q7_80 q7_90 q7_100 q7_100a ///
  nincons1 nincons2 nincons3 nincons4 nincons5 nincons6 nincons7 ninconswithin ///
  ninconstotal inconstotal1-inconstotal7 ///
  inconsist1_* inconsist2_* inconsist3_* inconsist4_* inconsist5_* inconsist6_* inconsist7_*


// Save data sets
format nohhmem %12.0f
compress
keep if anyexp==1
keep if centerpanel==1
label data "Merged Dataset CentERpanel Exp, DHS 2005 - Only Participants"
saveold `formatteddatadir'/exp_dhs, replace

log close
scons_returncode
