// cediff_cara v1.0.0 HMG 26oct2007
program define cediff_cara, rclass
    
    syntax varlist(min=11 max=11 numeric) [, name(string)]
    
    local GAM `1'
    local LAM `2'
    local RHO `3'
    local SGN `4'
    local ALO `5'
    local AHI `6'
    local ALATE `7'
    local BLO `8'
    local BHI `9'
    local BLATE `10'
    local PHI `11'
    
    local tempvar1 GAMPOS GAMNEG LAMBDA S NORM ONE ZERO ualo uahi ublo ubhi
    tempvar `tempvar1'
    
    gen double GAMPOS=`GAM'
    
    // safeguard against too small values of risk aversion parameter -> linear utility
    qui replace GAMPOS=1.0e-10 if abs(GAMPOS)<1.0e-10
    
    // sign of GAMMA for KP transformations
    gen S=sign(GAMPOS)
    
    // switching risk preferences for PT specification
    gen GAMNEG=`SGN'*GAMPOS
    
    // don't switch risk preferences for risk loving on positive domain
    qui replace GAMNEG=GAMPOS if (S<0 & `SGN'<0)
    
    // generate temporary variable for LAMBDA
    gen LAMBDA=`LAM'
    
    // different normalisations for PT and KP specifications
    gen NORM=1-max(-`LAM'/GAMPOS,0)*GAMPOS
    qui replace NORM=0 if (GAMNEG~=GAMPOS)
    
    // if bLO is weakly positive use parameters for the positive domain
    qui replace LAMBDA=1 if `BLO'>=0
    qui replace GAMNEG=GAMPOS if `BLO'>=0
    
    gen ZERO=0
    gen ONE = 1
    
    gen double ualo=0
    gen double uahi=0
    gen double ublo=0
    gen double ubhi=0
    
    // calculate period 2 utility
    uper2_cara `ALO' GAMPOS ONE `RHO' S NORM ualo
    uper2_cara `AHI' GAMPOS ONE `RHO' S NORM uahi
    uper2_cara `BLO' GAMNEG LAMBDA `RHO' S NORM ublo
    uper2_cara `BHI' GAMPOS ONE `RHO' S NORM ubhi
    
    local tempvar2 cea ceb wa wb w0 eua eub eu0 hualo_early huahi_early hublo_early hubhi_early
    tempvar `tempvar2'
    
    gen wa=0
    gen hualo_early=0
    gen huahi_early=0
    gen wb=0
    gen hublo_early=0
    gen hubhi_early=0
    gen eua=(1-`PHI')* ualo + `PHI' * uahi
    gen eub=(1-`PHI')* ublo + `PHI' * ubhi
    
    kpweight ualo `RHO' S hualo_early
    kpweight uahi `RHO' S huahi_early
    kpweight ublo `RHO' S hublo_early
    kpweight ubhi `RHO' S hubhi_early
    
    // utility option A for early resolution
    qui replace wa = (1-`PHI')*hualo_early + `PHI'*huahi_early if (`ALATE'==0)
    // utility option A for late resolution
    kpweight eua `RHO' S wa if (`ALATE'==1)
    
    // utility option B for early resolution
    qui replace wb = (1-`PHI')*hublo_early + `PHI'*hubhi_early if (`BLATE'==0)
    // utility option B for late resolution
    kpweight eub `RHO' S wb if (`BLATE'==1)
    
    // utility of zero, needed for case of certainty equivalent of b
    gen w0=0
    gen eu0=0
    uper2_cara ZERO GAMPOS ONE `RHO' S NORM eu0
    kpweight eu0 `RHO' S w0
    
    // calculate certainty equivalents, take difference
    gen cea=0
    gen ceb=0
    certequivcara wa GAMPOS ONE `RHO' S NORM cea
    certequivcara wb GAMPOS ONE `RHO' S NORM ceb if wb>=w0
    certequivcara wb GAMNEG LAMBDA `RHO' S NORM ceb if wb<w0
    gen CE`name'=ceb-cea
    // gen CE`name'=wb-wa
    
    drop `tempvar1' `tempvar2'
end
