! **************************************************************
!
!  MODULE:  controlpars
!
!  PURPOSE: contains the global control parameters
!
! **************************************************************

module controlpars
use nrtype
use hm_utils
implicit none
include 'mpif.h'
integer(I4B):: status(MPI_STATUS_SIZE)

! Execution control 
logical(LGT),parameter:: MAX1=.TRUE.   ! first round maximisation
logical(LGT),parameter:: MAX2=.FALSE.   ! second round maximisation -- switch off if good starting values exist
logical(LGT),parameter:: STDE=.TRUE.   ! calculate standard errrors
logical(LGT),parameter:: IPAR=.FALSE.  ! calculate individual-level parameters

! Dataset size
integer(I4B),parameter::NJ       = 27472  ! total number of observations
integer(I4B),parameter::N        =   532  ! number of individuals 
integer(I4B),parameter::K_GAMMA  =    16   ! number of coefficients in gamma
integer(I4B),parameter::K_LAMBDA =    16   ! number of coefficients in lambda
integer(I4B),parameter::K_RHO    =    16   ! number of coefficients in rho
integer(I4B),parameter::K_TAU    =     1   ! number of coefficients in tau
integer(I4B),parameter::K_OMEGA  =    18   ! number of coefficients in omega
integer(I4B),parameter::K_INC1   =     0   ! number of coefficients in K_INC0
integer(I4B),parameter::K_COV_RC =     4   ! number of parameters to be estimated in covariance matrix
integer(I4B),parameter::L_COV_RC =     4   ! dimension of covariance matrix K_COV_RC for COVREST and otherwise K_COVRC*(K_COV_RC+1)/2 
    								       ! careful: needs to conform with covrest AND 
    								       ! CORR_RC_START AND HET_xxx-Variables

! Model specification controls 
logical(LGT),parameter::    CARA =.TRUE.    ! utility type: CARA (true) or CRRA (false)
logical(LGT),parameter:: COVREST =.TRUE.    ! covariances of rc's restricted to zero?
    real(DP),parameter:: SIGNNEG = 1.0		! gamma in the negative domain (1.0/-1.0)

logical(LGT),parameter::HET_GAMMA  =.TRUE.	! gamma heterogeneous? 
logical(LGT),parameter::EXP_GAMMA  =.FALSE.	! gamma positive?
logical(LGT),parameter::CDF_GAMMA  =.FALSE.	! gamma \in (0,1) ?
logical(LGT),parameter::CDF2_GAMMA =.FALSE.	! gamma \in (-1,1)

logical(LGT),parameter::HET_LAMBDA =.TRUE.	! lambda heterogeneous? 
logical(LGT),parameter::EXP_LAMBDA =.TRUE.	! lambda positive?
logical(LGT),parameter::CDF_LAMBDA =.FALSE.	! lambda \in (0,1) ?

logical(LGT),parameter::HET_RHO    =.TRUE.	! rho heterogeneous? 
logical(LGT),parameter::EXP_RHO    =.TRUE.	! rho positive?
logical(LGT),parameter::CDF_RHO    =.FALSE.	! rho \in (0,1) ?

logical(LGT),parameter::HET_TAU    =.FALSE.	! tau heterogeneous? 
logical(LGT),parameter::EXP_TAU    =.TRUE.	! tau positive?
logical(LGT),parameter::CDF_TAU    =.FALSE.	! tau \in (0,1) ?

logical(LGT),parameter::HET_OMEGA  =.TRUE.	! omega heterogeneous? 
logical(LGT),parameter::EXP_OMEGA  =.FALSE.	! omega positive?
logical(LGT),parameter::CDF_OMEGA  =.TRUE.	! omega \in (0,1) ?



! Path for loading the data, input and output of coefficients
character(LEN=*),parameter:: loadpath     ='../../../data/formatted/txt/demog-inc1-f/'
character(LEN=*),parameter:: parinppath   ='input_restr/'
character(LEN=*),parameter:: paroutpath   ='output_restr/'
character(LEN=*),parameter:: paroutpathind='outputind_restr/'

! Parameters for the integration routine 
integer(I4B),parameter::   NDRAWS=1000 ! number of halton draws



! nohhmem's to calculate individual-level parameters
integer(I4B),parameter::indlevnr(3)=(/   193, &
                                         370, &
                                        1589 /)



! Control printing of results
logical(LGT),parameter::PRINTSWITCH(3)=(/.TRUE.,.TRUE.,.FALSE./)
! dimension 1: parameters, logl_value, gradient,hessian
! dimension 2: maximisation output wrt LOGL_ALL
! dimension 3: complete individual likelihoods (LIKEL_IND) in LOGL_ALL









! things that are not to be altered

! MPI-related stuff
integer(I4B):: ierr
integer(I4B):: my_rank ! My process rank.
integer(I4B):: proc    ! The number of processes
logical(LGT):: paralliter

! variable definitions
integer(I4B),parameter::   K=K_GAMMA+K_LAMBDA+K_RHO+K_TAU+K_OMEGA+K_INC1+K_COV_RC 
integer(I4B),parameter::   parameters_print=1    ! printing unit number for parameters file 
integer(I4B),parameter::   likel_ind_print=2     ! printing unit number for individual likelihood contribution file
integer(I4B)::             PU                              ! printing unit for maximisation/integration file.
integer(I4B)::             ind,             &
                           funccounter,     &
                           gradcounter,     &
                           INDIVINDIC(N,4)

logical(LGT)::             COEFFS_EXP(K),   &
                           COEFFS_CDF(K),   &
                           COEFFS_CDF2(K),  &
                           COEFFS_CONST(K), & 
                           CALCGRAD,        &
                           CALCIPAR         

real(DP)::                 GAMMA_START(max(K_GAMMA,1)),       &
                           LAMBDA_START(max(K_LAMBDA,1)),     &
                           RHO_START(max(K_RHO,1)),           &
                           TAU_START(max(K_TAU,1)),           &
                           OMEGA_START(max(K_OMEGA,1)),       &
                           INC1_START(max(K_INC1,1)),         &
                           CORR_RC_START(L_COV_RC,L_COV_RC),  &
                           CHOL_RC_START(L_COV_RC,L_COV_RC),  &
                           CHOL_RC(L_COV_RC,L_COV_RC),        &
                           GAMMA_RAW(NJ),                     &
                           LAMBDA_RAW(NJ),                    &
                           RHO_RAW(NJ),                       &
                           TAU_RAW(NJ),                       &
                           OMEGA_RAW(NJ),                     &  
                           GAMMA_INC1(NJ),                    &
                           LAMBDA_INC1(NJ),                   &
                           RHO_INC1(NJ),                      &
                           TAU_INC1(NJ),                      &
                           OMEGA_INC1(NJ),                    & 
                           SIM(N,L_COV_RC,NDRAWS),            &
                           COEFFS_START(K),                   &
                           COEFFS_SCALE(K),                   &
                           Y(NJ,1),                           &
                           X_GENERAL(NJ,7),                   &
                           X_GAMMA(NJ,K_GAMMA),               &
                           X_LAMBDA(NJ,K_LAMBDA),             &
                           X_RHO(NJ,K_RHO),                   &
                           X_TAU(NJ,K_TAU),                   &
                           X_OMEGA(NJ,K_OMEGA),               &
                           X_INC1(NJ,1),                      &
                           GRADIENT_IND(N,K),                 &
                           RIDDERS_ERR



! **************************************************************

contains



! **************************************************************

subroutine convertcoeffs(LENGTH,EXPEXP,CDFCDF,CDF2CDF2,COEFFS_CONV)
! converts coefficients from R^1 to their restricted value

integer(I4B),intent(in)::LENGTH
real(DP),intent(inout)::COEFFS_CONV(LENGTH)
logical(LGT),intent(in)::EXPEXP,CDFCDF,CDF2CDF2
integer(I4B)::i
real(dp)::temp


if (EXPEXP) then
  COEFFS_CONV=exp(COEFFS_CONV)
elseif (CDFCDF) then
  do i=1,LENGTH
    COEFFS_CONV(i)=logistcdf(COEFFS_CONV(i))
  enddo
elseif (CDF2CDF2) then
  temp=logistcdf(coeffs_conv(1))
  do i=1,LENGTH
    COEFFS_CONV(i)=( logistcdf(COEFFS_CONV(i)) - 0.5d0)*2.0d0
  enddo
endif

end subroutine convertcoeffs




! **************************************************************

subroutine convertcoeffs_end(COEFFS_CONV)
! converts back coefficients that enter the likelihood in a transformed way
real(DP),intent(inout)::COEFFS_CONV(K)
real(DP)::COEFFS_RAW(K),c,d
integer(I4B)::i,j,indic_c(K_INC1),indic_d(K_INC1)


COEFFS_RAW=COEFFS_CONV

j=0
do i=1,K
  if (COEFFS_EXP(i)) then
    if (COEFFS_CONST(i)) then
	  COEFFS_CONV(i)=exp(COEFFS_RAW(i))
	  j=i
	else 
	  COEFFS_CONV(i)=exp(COEFFS_RAW(i)+COEFFS_RAW(j)) - COEFFS_CONV(j)
	endif
  elseif (COEFFS_CDF(i)) then
    if (COEFFS_CONST(i)) then
	  COEFFS_CONV(i)=logistcdf(COEFFS_RAW(i))
	  j=i
	else 
	  COEFFS_CONV(i)=logistcdf(COEFFS_RAW(i)+COEFFS_RAW(j)) - COEFFS_CONV(j)
	endif
  elseif (COEFFS_CDF2(i)) then
    if (COEFFS_CONST(i)) then
	  COEFFS_CONV(i)=(logistcdf(COEFFS_RAW(i)) - .5d0 ) *2.0d0
	  j=i
	else 
	  COEFFS_CONV(i)=(logistcdf(COEFFS_RAW(i)+COEFFS_RAW(j)) - .5d0 ) *2.0d0 - COEFFS_CONV(j)
	endif
  endif
enddo


if (K_INC1>0) then
  
  ! indicators for the constant term on respective parameter
  i=1
  if (K_GAMMA>0) then
    indic_c(i)=1
    i=i+1
  endif
  if (K_LAMBDA>0) then
    indic_c(i)=K_GAMMA+1
    i=i+1
  endif
  if (K_RHO>0) then
    indic_c(i)=K_GAMMA+K_LAMBDA+1
    i=i+1
  endif
  if (K_TAU>0) then
    indic_c(i)=K_GAMMA+K_LAMBDA+K_RHO+1
    i=i+1
  endif
  if (K_OMEGA>0) then
    indic_c(i)=K_GAMMA+K_LAMBDA+K_RHO+K_TAU+1
  endif

  ! indicators for coefficient on incentive 1 on the respective parameter
  do i=1,K_INC1
    indic_d(i)=K_GAMMA+K_LAMBDA+K_RHO+K_TAU+K_OMEGA+i
  enddo
 
  ! convert multiplicative coefficients
  do i=1,K_INC1
    c=COEFFS_CONV(indic_c(i)) ! coefficient on constant
    d=COEFFS_CONV(indic_d(i)) ! coefficient on incentive_1 
    if (COEFFS_EXP(indic_c(i))) then
      COEFFS_CONV(indic_d(i))=  c**d/c
    elseif (COEFFS_CDF(indic_c(i))) then
      COEFFS_CONV(indic_d(i))=1.0d0/(1.0d0+((1.0d0-c)/c)**d)/c
    elseif (COEFFS_CDF2(indic_c(i))) then
      COEFFS_CONV(indic_d(i))=2.0d0/c/(1.0d0+((1.0d0/2.0d0-c/2.0d0)/(c/2.0d0+1.0d0/2.0d0))**d)-1/c
    endif
  enddo
endif 

end subroutine convertcoeffs_end



! **************************************************************

end module controlpars
