function cediff_cara(GAMPOS,LAMBDA,RHO,dat)
use nrtype
use controlpars, only: SIGNNEG
implicit none

real(DP),intent(in)::RHO,dat(7)
real(DP)::cediff_cara,GAMPOS,GAMNEG,LAMBDA,ualo,uahi,ublo,ubhi,u0,wa,wb,w0,S,cea,ceb,NORM
real(DP),external::uper2,h,certequivcara_cara
! dimensions of dat:
! 1 pHI
! 2 aLO
! 3 aHI
! 4 aLATE
! 5 bLO
! 6 bHI 
! 7 bLATE


! safeguard against too small values of risk aversion parameter -> linear utility
if (abs(GAMPOS)<1.0d-10) GAMPOS=sign(1.0d-10,GAMPOS) 

! sign of GAMMA for KP transformations
S=sign(1.0d0,GAMPOS)

! switching risk preferences for PT specification
GAMNEG=signneg*GAMPOS

! don't switch risk preferences for risk loving on positive domain
if (S<0 .AND. signneg<0) GAMNEG=GAMPOS

! different normalisations for PT and KP specifications
NORM=1.0d0-max(-LAMBDA/GAMPOS,0.0d0)*GAMPOS
if (GAMNEG .NE. GAMPOS) NORM=0.0d0

! if bLO is weakly positive use parameters for the positive domain
if (dat(5)>-1.0E-8) then
  LAMBDA=1.0d0
  GAMNEG=GAMPOS
endif



! calculate period 2 utility
ualo = uper2(dat(2),GAMPOS,1.0d0 ,RHO,S,NORM)
uahi = uper2(dat(3),GAMPOS,1.0d0 ,RHO,S,NORM)

ublo = uper2(dat(5),GAMNEG,LAMBDA,RHO,S,NORM)
ubhi = uper2(dat(6),GAMPOS,1.0d0 ,RHO,S,NORM)



if (dat(4)<1.0d-8) then     ! utility option A for early resolution

  wa =    (1.0d0-dat(1))*h(ualo,RHO,S) +  dat(1)*h(uahi,RHO,S)

else                        ! utility option A for late resolution

  wa = h( (1.0d0-dat(1))*  ualo        +  dat(1) * uahi       ,RHO,S)

endif


if (dat(7)<1.0d-8) then     ! utility option B for early resolution

  wb =    (1.0d0-dat(1))*h(ublo,RHO,S) +  dat(1)*h(ubhi,RHO,S)

else                        ! utility option B for late resolution

  wb = h( (1.0d0-dat(1))*  ublo        +  dat(1) * ubhi       ,RHO,S)

endif




! utility of zero, needed for case of certainty equivalent of b
u0 = uper2(0.0d0,GAMPOS,1.0d0,RHO,S,NORM)
w0 = h(u0,RHO,S)



! calculate certainty equivalents, take difference
  cea = certequivcara_cara(wa,GAMPOS,1.0d0 ,RHO,S,NORM)
if (wb .GE. w0) then
  ceb = certequivcara_cara(wb,GAMPOS,1.0d0 ,RHO,S,NORM)
else
  ceb = certequivcara_cara(wb,GAMNEG,LAMBDA,RHO,S,NORM)
endif
cediff_cara=ceb-cea


end function cediff_cara



! ***********************************************************************************

function uper2(Z,GAM,LAMBDA,RHO,S,NORM)
! calculates period 2 utility
use nrtype
implicit none
real(DP)::uper2,Z,GAM,LAMBDA,RHO,S,NORM    

uper2 = ( LAMBDA - NORM - LAMBDA*min(exp(-GAM*(RHO**S)*Z),huge(GAM)) ) / GAM

end function uper2



! ***********************************************************************************

function h(X,RHO,S)
! calculates kreps-porteus transformation
use nrtype
implicit none
real(DP)::h,X,RHO,S

h = -S*(-S*X)**(RHO**(-S))

end function h


! ***********************************************************************************

function certequivcara_cara(V,GAM,LAMBDA,RHO,S,NORM)
! returns certainty equivalent of utility V

use nrtype
implicit none
real(DP)::certequivcara_cara,V,GAM,LAMBDA,RHO,S,NORM

certequivcara_cara = -log( (LAMBDA - NORM - GAM*(-S*(-S*V)**(RHO**S))) / LAMBDA ) / (GAM*(RHO**S))

end function certequivcara_cara