function cediff_crra(GAMPOS,LAMBDA,RHO,dat)
use nrtype
implicit none

real(DP),intent(in)::RHO,dat(7),LAMBDA,GAMPOS
real(DP)::cediff_crra,ualo,uahi,ublo,ubhi,wa,wb,cea,ceb,GAMNEG
real(DP),external::util_crra,certequiv_crra

! dimensions of dat:
! 1 pHI
! 2 aLO
! 3 aHI
! 4 aLATE
! 5 bLO
! 6 bHI 
! 7 bLATE



if (dat(5)<0.0d0) then
  ! switch risk preferences b/w positive and negative domain
  GAMNEG=GAMPOS
  ! don't switch risk preferences for risk loving on positive domain
  if (GAMPOS<0) GAMNEG=-GAMPOS
else
  ! for weakly positive outcomes of lottery b 
  GAMNEG=GAMPOS
endif



! calculate utility
ualo = util_crra(dat(2),GAMPOS,GAMNEG,LAMBDA)
uahi = util_crra(dat(3),GAMPOS,GAMNEG,LAMBDA)

ublo = util_crra(dat(5),GAMPOS,GAMNEG,LAMBDA)
ubhi = util_crra(dat(6),GAMPOS,GAMNEG,LAMBDA)



wa =    (1.0d0-dat(1))*ualo +  dat(1)*uahi
wb =    (1.0d0-dat(1))*ublo +  dat(1)*ubhi


! calculate certainty equivalents, take difference
cea = certequiv_crra(wa,GAMPOS,GAMNEG,LAMBDA)
ceb = certequiv_crra(wb,GAMPOS,GAMNEG,LAMBDA)

cediff_crra=ceb-cea

end function cediff_crra



! ***********************************************************************************

function util_crra(Z,GAMMAPOS,GAMMANEG,LAMBDA)
! calculates crra utility
use nrtype
implicit none
real(DP),intent(in)::Z,GAMMAPOS,GAMMANEG,LAMBDA
real(DP)::util_crra

if (Z .GE. 0.0d0) then
  util_crra =          Z **(1.0d0-GAMMAPOS)
else
  util_crra =-LAMBDA*(-Z)**(1.0d0-GAMMANEG)
endif


end function util_crra



! ***********************************************************************************

function certequiv_crra(V,GAMMAPOS,GAMMANEG,LAMBDA)
! returns certainty equivalent of utility V

use nrtype
implicit none
real(DP),intent(in)::V,GAMMAPOS,GAMMANEG,LAMBDA
real(DP)::certequiv_crra

if (V .GE. 0.0d0) then
  certequiv_crra =          V            ** (1.0d0/(1.0d0-GAMMAPOS))
else
  certequiv_crra = -  ( ( - V / LAMBDA ) ** (1.0d0/(1.0d0-GAMMANEG)) )
endif

end function certequiv_crra