!****************************************************************************
!
!  SUBROUTINE:  checkcontrols
!
!  PURPOSE:		checks for consistency of control parameters and sets up
!				estimation parameters
!
!****************************************************************************

subroutine checkcontrols
use controlpars
use hm_utils
implicit none
integer(I4B):: temp,i1,i2,i3
real(DP)::GAMMA_SCALE(K_GAMMA),LAMBDA_SCALE(K_LAMBDA),RHO_SCALE(K_RHO) 
real(DP)::TAU_SCALE(K_TAU),OMEGA_SCALE(K_OMEGA),INC1_SCALE(K_INC1),CHOL_RC_SCALE(L_COV_RC,L_COV_RC)
logical(LGT)::FLAG


! **************************************************************

! check dimensions of startvalues and data on random coefficients
if (K_RHO .NE. 0 .AND. CARA==.FALSE.) then
  print*,' '
  print*,' '
  print*,'error in controls: K_RHO>0 and CRRA do not go together'
  print*,' '
  pause
endif

if (K_GAMMA .NE. size(GAMMA_START,1)) then
  print*,' '
  print*,' '
  print*,'error in controls: K_GAMMA and GAMMA_START do not conform'
  print*,' '
  pause
endif

if (K_LAMBDA .NE. size(LAMBDA_START,1) .AND. K_LAMBDA>0) then
  print*,' '
  print*,' '
  print*,'error in controls: K_LAMBDA and LAMBDA_START do not conform'
  print*,' '
  pause
elseif (K_LAMBDA==0 .AND. ((abs(LAMBDA_START(1)-1.0)>1.0E-8) .OR. (size(LAMBDA_START,1)>1))) then
  print*,' '
  print*,' '
  print*,'error in controls: LAMBDA not estimated and LAMBDA_START not equal to one'
  print*,' '
  pause
endif

if (K_RHO .NE. size(RHO_START,1) .AND. K_RHO>0) then
  print*,' '
  print*,' '
  print*,'error in controls: K_RHO and RHO_START do not conform'
  print*,' '
  pause
elseif (K_RHO==0 .AND. ((abs(RHO_START(1)-1.0)>1.0E-8) .OR. (size(RHO_START,1)>1))) then
  print*,' '
  print*,' '
  print*,'error in controls: RHO not estimated and RHO_START not equal to one'
  print*,' '
  pause
endif

if (K_TAU .NE. size(TAU_START,1)) then
  print*,' '
  print*,' '
  print*,'error in controls: K_TAU and TAU_START do not conform'
  print*,' '
  pause
endif

if (K_TAU == 0) then
  print*,' '
  print*,' '
  print*,'error in controls: K_TAU = 0'
  print*,' '
  pause
endif

if (K_OMEGA .NE. size(OMEGA_START,1) .AND. K_OMEGA>0) then
  print*,' '
  print*,' '
  print*,'error in controls: K_OMEGA and OMEGA_START do not conform'
  print*,' '
  pause
elseif (K_OMEGA==0 .AND. ((abs(OMEGA_START(1))>1.0E-8) .OR. (size(OMEGA_START,1)>1))) then
  print*,' '
  print*,' '
  print*,'error in controls: OMEGA not estimated and OMEGA_START not equal to zero'
  print*,' '
  pause
endif

if (K_INC1 > 0) then
  if (K_INC1 .NE. size(INC1_START,1)) then
    print*,' '
    print*,' '
    print*,'error in controls: K_INC1 and INC1_START do not conform'
    print*,' '
    pause
  endif
endif

! **************************************************************

! check dimensions of K_INC1

if (K_INC1 > 0) then
  temp=min(1,K_GAMMA)+min(1,K_LAMBDA)+min(1,K_RHO)+min(1,K_TAU)+min(1,K_OMEGA)
  if (temp .NE. K_INC1) then 
    print*,' '
    print*,' '
    print*,'error in controls:'
    print*,'K_INC1 has wrong dimension'
    print*,' '
    pause
  endif
endif

! **************************************************************

! check dimension of random coefficients covariance matrix and heterogeneous effecs

if (L_COV_RC .NE. size(CORR_RC_START,2)) then 
  print*,' '
  print*,' '
  print*,'error in controls:'
  print*,'covariance matrix of heterogeneous coefficients not symmetric'
  print*,' '
  pause
endif

temp = abs(HET_GAMMA + HET_LAMBDA + HET_RHO + HET_TAU + HET_OMEGA)
if (L_COV_RC .NE. temp) then 
  print*,' '
  print*,' '
  print*,'error in controls: number of heterogeneous coefficients and'
  print*,'the size of their covariance matrix do not conform'
  print*,' '
  pause
endif 

if (COVREST) then
  if (temp .NE. K_COV_RC) then
    print*,' '
    print*,' '
    print*,'error in controls: number of heterogeneous coefficients and'
    print*,'the number of respective estimation parameters (K_COV_RC)'
    print*,'do not conform'
    print*,' '
    pause
  endif 
else
  if ((temp*(temp+1)/2) .NE. K_COV_RC) then
    print*,' '
    print*,' '
    print*,'error in controls: number of heterogeneous coefficients and'
    print*,'the number of respective estimation parameters (K_COV_RC)'
    print*,'do not conform'
    print*,' '
    pause
  endif 
endif

if (L_COV_RC>1 .AND. COVREST) then 
  do i1 = 1,L_COV_RC
    do i2 = 1,L_COV_RC
        if ((i1 .NE. i2) .AND. (abs(CORR_RC_START(i1,i2)) > 10**-8)) then
        print*,' '
        print*,' '
        print*,'error in controls: covariances of random coefficients'
        print*,'restricted to zero but starting values not zero'
        print*,' '
        pause
      endif
    enddo
  enddo
endif



! **************************************************************

! convert  random coefficients correlation matrix 
! to cholesky-factors, take log of diagonal elements

if (K_COV_RC>0) then

  call corr2chol(L_COV_RC,CORR_RC_START,CHOL_RC_START)

  do i1 = 1,L_COV_RC
    CHOL_RC_START(i1,i1)=log(CHOL_RC_START(i1,i1))
  enddo

endif



! **************************************************************

! check whether signneg & KP-specification okay
if (abs(SIGNNEG)-1.0d0>10**-8) then 
  print*,' '
  print*,' '
  print*, 'abs(SIGNNEG) not equal to one, misspecified'
  print*,' '
  pause
endif

if (SIGNNEG==-1 .AND. K_RHO>0) then
  print*,' '
  print*,' '
  print*,'error in controls: kp-utility function is not possible'
  print*,'together with switching risk preferences'
  print*,' '
  pause
endif



! **************************************************************

! fill up indicator vectors for conversions
COEFFS_EXP  =.FALSE.
COEFFS_CDF  =.FALSE.
COEFFS_CDF2 =.FALSE.
COEFFS_CONST=.FALSE.
i2=0
if (K_GAMMA >0) then
  if (EXP_GAMMA  .OR. CDF_GAMMA .OR. CDF2_GAMMA ) COEFFS_CONST(i2+1)=.TRUE.
  do i1=1,K_GAMMA 
    if (EXP_GAMMA ) COEFFS_EXP(i1+i2) =.TRUE.
    if (CDF_GAMMA ) COEFFS_CDF(i1+i2) =.TRUE.
    if (CDF2_GAMMA) COEFFS_CDF2(i1+i2)=.TRUE.
  enddo
  i2=i1+i2-1
endif
if (K_LAMBDA>0) then
  if (EXP_LAMBDA .OR. CDF_LAMBDA) COEFFS_CONST(i2+1)=.TRUE.
  do i1=1,K_LAMBDA
    if (EXP_LAMBDA) COEFFS_EXP(i1+i2)=.TRUE.
    if (CDF_LAMBDA) COEFFS_CDF(i1+i2)=.TRUE.
  enddo
  i2=i1+i2-1
endif
if (K_RHO   >0) then
  if (EXP_RHO    .OR. CDF_RHO   ) COEFFS_CONST(i2+1)=.TRUE.
  do i1=1,K_RHO   
    if (EXP_RHO   ) COEFFS_EXP(i1+i2)=.TRUE.
    if (CDF_RHO   ) COEFFS_CDF(i1+i2)=.TRUE.
  enddo
  i2=i1+i2-1
endif
if (K_TAU   >0) then
  if (EXP_TAU    .OR. CDF_TAU   ) COEFFS_CONST(i2+1)=.TRUE.
  do i1=1,K_TAU   
    if (EXP_TAU   ) COEFFS_EXP(i1+i2)=.TRUE.
    if (CDF_TAU   ) COEFFS_CDF(i1+i2)=.TRUE.
  enddo
  i2=i1+i2-1
endif
if (K_OMEGA >0) then
  if (EXP_OMEGA  .OR. CDF_OMEGA ) COEFFS_CONST(i2+1)=.TRUE.
  do i1=1,K_OMEGA 
    if (EXP_OMEGA ) COEFFS_EXP(i1+i2)=.TRUE.
    if (CDF_OMEGA ) COEFFS_CDF(i1+i2)=.TRUE.
  enddo
  i2=i1+i2-1
endif
if (K_INC1 >0) then
  do i1=1,K_INC1 ! always larger than zero
    COEFFS_CONST(i1+i2)=.TRUE.
	COEFFS_EXP(i1+i2)  =.TRUE.
  enddo
  i2=i1+i2-1
endif
if (K_COV_RC>0) then
  i2=i2+1
  if (COVREST) then
    do i1=i2,K
	  COEFFS_EXP(i1)=.TRUE.
	  COEFFS_CONST(i1)=.TRUE.
    enddo
  else
    do i1=1,L_COV_RC
	  do i3=1,i1
	    if (i1==i3) then
		  COEFFS_EXP(i2)=.TRUE.
		  COEFFS_CONST(i2)=.TRUE.
		endif
        i2=i2+1
	  enddo
	enddo
  endif
endif



! **************************************************************

! convert the elements of coefficient vectors, except for 
! INC1 and CHOL_RC
if (K_GAMMA  > 0) then
  call convertcoeffs_start(K_GAMMA ,EXP_GAMMA ,CDF_GAMMA , CDF2_GAMMA , GAMMA_START)
  do i1=1,K_GAMMA
	  GAMMA_SCALE(i1)=1.0d0/max(abs(GAMMA_START(i1)),2.0d-2)
  enddo
endif
if (K_LAMBDA > 0) then
  call convertcoeffs_start(K_LAMBDA,EXP_LAMBDA,CDF_LAMBDA, .FALSE.    ,LAMBDA_START)
  do i1=1,K_LAMBDA
	  LAMBDA_SCALE(i1)=1.0d0/max(abs(LAMBDA_START(i1)),2.0d-2)
  enddo
endif
if (K_RHO    > 0) then
  call convertcoeffs_start(K_RHO   ,EXP_RHO   ,CDF_RHO   , .FALSE.    ,   RHO_START)
  do i1=1,K_RHO  
	  RHO_SCALE(i1)=1.0d0/max(abs(RHO_START(i1)),2.0d-2)
  enddo
endif
if (K_TAU    > 0) then
  call convertcoeffs_start(K_TAU   ,EXP_TAU   ,CDF_TAU   , .FALSE.    ,   TAU_START)
  do i1=1,K_TAU
	  TAU_SCALE(i1)=1.0d0/max(abs(TAU_START(i1)),2.0d-2)
  enddo
endif
if (K_OMEGA  > 0) then
  call convertcoeffs_start(K_OMEGA ,EXP_OMEGA ,CDF_OMEGA , .FALSE.    , OMEGA_START)
  do i1=1,K_OMEGA
	  OMEGA_SCALE(i1)=1.0d0/max(abs(OMEGA_START(i1)),2.0d-2)
  enddo
endif




! **************************************************************

! fill up vector of coefficients and scaling parameters from 
! single coefficient vectors, except for INC1 and CHOL_RC
temp=0
if (K_GAMMA > 0) then
  COEFFS_START(temp+1:temp+K_GAMMA)=GAMMA_START
  COEFFS_SCALE(temp+1:temp+K_GAMMA)=GAMMA_SCALE
  temp=temp+K_GAMMA
endif
if (K_LAMBDA > 0) then
  COEFFS_START(temp+1:temp+K_LAMBDA)=LAMBDA_START
  COEFFS_SCALE(temp+1:temp+K_LAMBDA)=LAMBDA_SCALE
  temp=temp+K_LAMBDA
endif
if (K_RHO > 0) then
  COEFFS_START(temp+1:temp+K_RHO)=RHO_START
  COEFFS_SCALE(temp+1:temp+K_RHO)=RHO_SCALE
  temp=temp+K_RHO
endif
if (K_TAU > 0) then
  COEFFS_START(temp+1:temp+K_TAU)=TAU_START
  COEFFS_SCALE(temp+1:temp+K_TAU)=TAU_SCALE
  temp=temp+K_TAU
endif
if (K_OMEGA > 0) then
  COEFFS_START(temp+1:temp+K_OMEGA)=OMEGA_START
  COEFFS_SCALE(temp+1:temp+K_OMEGA)=OMEGA_SCALE
  temp=temp+K_OMEGA
endif




! **************************************************************

! fill up vector of coefficients and scaling parameters for 
! INC1 and CHOL_RC
if (K_INC1   > 0) then
   call convertmultiplicstart(COEFFS_START,INC1_START)
   do i1=1,K_INC1 
	  INC1_SCALE(i1)=1.0d0/max(abs(INC1_START(i1)),2.0d-2)
  enddo
endif
if (K_COV_RC > 0) then
  do i1=1,L_COV_RC
    do i2=1,i1
	  CHOL_RC_SCALE(i2,i1)=1.0d0/max(abs(CHOL_RC_START(i2,i1)),2.0d-2)
	enddo
  enddo
endif




if (K_INC1  > 0) then
  COEFFS_START(temp+1:temp+K_INC1)=INC1_START
  COEFFS_SCALE(temp+1:temp+K_INC1)=INC1_SCALE
  temp=temp+K_INC1
endif
if (K_COV_RC > 0) then
  if (COVREST) then
    do i1 = 1,L_COV_RC
      COEFFS_START(temp+1)=CHOL_RC_START(i1,i1)
	  COEFFS_SCALE(temp+1)=CHOL_RC_SCALE(i1,i1)
      temp=temp+1
    enddo
  else 
    call triangmat2vec(L_COV_RC,CHOL_RC_START,COEFFS_START(temp+1:K))
    call triangmat2vec(L_COV_RC,CHOL_RC_SCALE,COEFFS_SCALE(temp+1:K))
  endif
endif




! **************************************************************

contains




! **************************************************************

! converts coefficients that are to be transformed to R^1
subroutine convertcoeffs_start(KK,EXPEXP,CDFCDF,CDF2CDF2,COEFFS_CONV)
integer(I4B),intent(in)::KK
real(DP),intent(inout)::COEFFS_CONV(KK)
LOGICAL(LGT),intent(in)::EXPEXP,CDFCDF,CDF2CDF2
real(DP)::COEFFS_RAW(KK)


COEFFS_RAW=COEFFS_CONV

if (EXPEXP .AND. CDFCDF) then
  print*,' '
  print*,' '
  print*,'both restriction BETA>0 and 0<BETA<1 set to'
  print*,'.TRUE. for some parameter'
  print*,' '
  pause
endif


if (EXPEXP) then
  if (COEFFS_RAW(1) .LE. 0) then
    print*,' '
    print*,' '
    print*,'a constant that is restricted to be larger'
    print*,'than zero is set wrongly'
    print*,' '
    pause
  endif
  COEFFS_CONV(1)=log(COEFFS_RAW(1))
  if (KK>1) then
    do i1=2,KK
      if (COEFFS_RAW(1)+COEFFS_RAW(i1) .LE. 0) then
        print*,' '
        print*,' '
        print*,'a coefficient that is restricted to be larger'
        print*,'than zero overall is set wrongly'
        print*,' '
        pause
      endif
      COEFFS_CONV(i1)=log(COEFFS_RAW(1)+COEFFS_RAW(i1)) - log(COEFFS_RAW(1))
    enddo
  endif
elseif (CDFCDF) then
  if ((COEFFS_RAW(1) .LE. 0 ) .OR. (COEFFS_RAW(1) .GE. 1 )) then
    print*,' '
    print*,' '
    print*,'a constant that is restricted to be in the'
    print*,'unit interval is set wrongly'
    print*,' '
    pause
  endif
  COEFFS_CONV(1)=logistinv(COEFFS_RAW(1))
  if (KK>1) then
    do i1=2,KK
      if ((COEFFS_RAW(1)+COEFFS_RAW(i1) .LE. 0 ) .OR. (COEFFS_RAW(1)+COEFFS_RAW(i1) .GE. 1 )) then
        print*,' '
        print*,' '
        print*,'a coefficient that is restricted to be in the'
        print*,'unit interval overall is set wrongly'
        print*,' '
        pause
      endif
      COEFFS_CONV(i1)=logistinv(COEFFS_RAW(1)+COEFFS_RAW(i1)) - logistinv(COEFFS_RAW(1))
    enddo
  endif
elseif (CDF2CDF2) then
  if ((COEFFS_RAW(1) .LE. -1 ) .OR. (COEFFS_RAW(1) .GE. 1 )) then
    print*,' '
    print*,' '
    print*,'a constant that is restricted to be in the'
    print*,'interval (-1,1) is set wrongly'
    print*,' '
    pause
  endif
  COEFFS_CONV(1)=logistinv(COEFFS_RAW(1)/2.0d0 + .5d0)
  if (KK>1) then
    do i1=2,KK
      if ((COEFFS_RAW(1)+COEFFS_RAW(i1) .LE. -1 ) .OR. (COEFFS_RAW(1)+COEFFS_RAW(i1) .GE. 1 )) then
        print*,' '
        print*,' '
        print*,'a constant that is restricted to be in the'
        print*,'interval (-1,1) is set wrongly'
        print*,' '
        pause
      endif
      COEFFS_CONV(i1)=logistinv((COEFFS_RAW(1)+COEFFS_RAW(i1))/2.0d0 + .5d0) - logistinv(COEFFS_RAW(1)/2.0d0 + .5d0)
    enddo
  endif
endif

end subroutine convertcoeffs_start




! **************************************************************

subroutine convertmultiplicstart(COEFFS_START,INC1_START)
use controlpars
use hm_utils
real(DP),intent(in)::COEFFS_START(K)
real(DP),intent(inout)::INC1_START(K_INC1)
real(DP)::VCOV_OPGhlp(K,K),jacmult(K,K), c, d
integer(I4B)::i, indic_c(K_INC1), indic_d(K_INC1)




! indicators for the constant term on respective parameter
i=1
if (K_GAMMA>0) then
  indic_c(i)=1
  i=i+1
endif
if (K_LAMBDA>0) then
  indic_c(i)=K_GAMMA+1
  i=i+1
endif
if (K_RHO>0) then
  indic_c(i)=K_GAMMA+K_LAMBDA+1
  i=i+1
endif
if (K_TAU>0) then
  indic_c(i)=K_GAMMA+K_LAMBDA+K_RHO+1
  i=i+1
endif
if (K_OMEGA>0) then
  indic_c(i)=K_GAMMA+K_LAMBDA+K_RHO+K_TAU+1
endif




do i=1,K_INC1
  c=COEFFS_START(indic_c(i)) ! coefficient on constant
  d=INC1_START(i)            ! coefficient on incentive_1 
  if (COEFFS_EXP(indic_c(i))) then
	INC1_START(i)=  log(d)/c+1.0d0
  elseif (COEFFS_CDF(indic_c(i))) then
	INC1_START(i)= -1.0d0/c * log((1.0d0+exp(-c))/d-1.0d0)
  elseif (COEFFS_CDF2(indic_c(i))) then
	INC1_START(i)= -1.0d0/c * log((d*(1.0d0/(1.0d0+exp(-c))-.5d0)+.5d0)**-1.0d0 -1.0d0)
  endif
  INC1_START(i)=log(INC1_START(i))
enddo

end subroutine convertmultiplicstart




! **************************************************************

end subroutine checkcontrols
