subroutine loaddata
! loads the data 
use nrtype 
use controlpars
implicit none
integer(I4B):: file_id



! files that are always needed
file_id=1
call readrealmat(NJ,1,file_id,Y)
file_id=2
call readrealmat(NJ,7,file_id,X_GENERAL)
file_id=1
call readint (N ,4,file_id,INDIVINDIC)



! optional files depending on model specification
if (K_GAMMA>0) then
  file_id=3
  call readrealmat(NJ,K_GAMMA ,file_id,X_GAMMA)
  call readrealvec(K_GAMMA    ,file_id,GAMMA_START)
endif

if (K_LAMBDA>0) then
  file_id=4
  call readrealmat(NJ,K_LAMBDA,file_id,X_LAMBDA)
  call readrealvec(K_LAMBDA,   file_id,LAMBDA_START)
else
  LAMBDA_START=1.0d0
endif

if (K_RHO>0) then
  file_id=5
  call readrealmat(NJ,K_RHO   ,file_id,X_RHO)
  call readrealvec(K_RHO,      file_id,RHO_START)
else
  RHO_START=1.0d0
endif

if (K_TAU>0) then
  file_id=6
  call readrealmat(NJ,K_TAU   ,file_id,X_TAU)
  call readrealvec(K_TAU      ,file_id,TAU_START)
else
  TAU_START=0.0d0
endif

if (K_OMEGA>0) then
  file_id=7
  call readrealmat(NJ,K_OMEGA ,file_id,X_OMEGA)
  call readrealvec(K_OMEGA    ,file_id,OMEGA_START)
else
  OMEGA_START=0.0d0
endif

if (K_INC1>0) then
  file_id=8
  call readrealmat(NJ,1       ,file_id,X_INC1)
  call readrealvec(K_INC1,     file_id,INC1_START)
else
  INC1_START=0.0d0
endif

if (K_COV_RC>0) then
  file_id=9
  call readrealmat(L_COV_RC,L_COV_RC,file_id,CORR_RC_START)
endif




! **************************************************************

contains


! **************************************************************

subroutine readrealmat(nobs,npars,file_id,dat)
! loads data files with real variables 

integer(I4B),intent(in)::nobs,npars,file_id
real(DP),dimension(:,:),intent(out)::dat
real(DP),dimension(:,:),allocatable::temp

if (allocated(temp)) deallocate(temp)
allocate(temp(1:npars,1:nobs))
select case (file_id)
case (1) 
    open(1,file=loadpath//'y.txt')
case (2) 
	open(1,file=loadpath//'lotterycharacs.txt')
case (3) 
	open(1,file=loadpath//'x_gam.txt')
case (4) 
	open(1,file=loadpath//'x_lam.txt')
case (5) 
	open(1,file=loadpath//'x_rho.txt')
case (6) 
	open(1,file=loadpath//'x_tau.txt')
case (7) 
	open(1,file=loadpath//'x_omg.txt')
case (8) 
	open(1,file=loadpath//'x_in1.txt')
case (9) 
	open(1,file=parinppath//'corr.txt')
case default
	print*,'file_id for data specified incorrectly'
	pause		
end select
read(1,*) temp
close(1)
dat = transpose(temp)
end subroutine readrealmat




! **************************************************************


subroutine readrealvec(nobs,file_id,dat)
! loads data files with real variables 

integer(I4B),intent(in)::nobs,file_id
real(DP),dimension(:),intent(out)::dat
real(DP),dimension(:),allocatable::temp

if (allocated(temp)) deallocate(temp)
allocate(temp(1:nobs))
select case (file_id)
case (3) 
	open(1,file=parinppath//'gamma.txt')
case (4) 
	open(1,file=parinppath//'lambda.txt')
case (5) 
	open(1,file=parinppath//'rho.txt')
case (6) 
	open(1,file=parinppath//'tau.txt')
case (7) 
	open(1,file=parinppath//'omega.txt')
case (8) 
	open(1,file=parinppath//'incentive1.txt')
case default
	print*,'file_id for data specified incorrectly'
	pause		
end select
read(1,*) temp
close(1)
dat = temp
end subroutine readrealvec




! **************************************************************

subroutine readint(nobs,npars,file_id,dat)
!loads data files containing integer variables

integer(I4B),intent(in)::nobs,npars,file_id
integer(I4B),dimension(:,:),intent(out)::dat
integer(I4B),dimension(:,:),allocatable::temp

if (allocated(temp)) deallocate(temp)
allocate(temp(1:npars,1:nobs))
if (file_id==1) then
	open(1,file=loadpath//'indivindic.txt')
endif
read(1,*) temp
close(1)
dat = transpose(temp)
end subroutine readint




! **************************************************************

end subroutine loaddata