subroutine standerr(COEFFS,SE,LOGL_VALUE)
! computes standard errors and transforms parameters and standard errors, prints them
use controlpars
use hm_utils
implicit none
integer(I4B)::i,j1,j2
real(DP),intent(in)::COEFFS(K)
real(DP)::COEFFSSE(K),VCOV_OPG(K,K),SE(K),JAC(K,K),LOGL_VALUE

! use local version of COEFFS
COEFFSSE=COEFFS




! calculate inverse of variance-covariance matrix from individual gradients
VCOV_OPG=0.0d0;
do i=1,N
  do j1=1,K
    do j2=1,K
      VCOV_OPG(j1,j2)=VCOV_OPG(j1,j2)+GRADIENT_IND(i,j1)*GRADIENT_IND(i,j2);
	enddo
  enddo
enddo

! invert inverse to get variance-covariance matrix
call unit_matrix(JAC)     ! JAC is only dummy argument here
call gaussj(VCOV_OPG,JAC) ! inversion routine




! calculate Jacobian of parameter transformations
call convertcoeffs_jac(COEFFSSE,JAC)
! special treatment of multiplicative parameters (INC1)
if (K_INC1>0) then
  call convertmultiplicjac(COEFFSSE,JAC)
endif
! calculate variance-covariance matrix of final parameters
VCOV_OPG=matmul(JAC,VCOV_OPG)
VCOV_OPG=matmul(VCOV_OPG,transpose(JAC))
! convert parameters 
call convertcoeffs_end(COEFFSSE)
! convert cholesky-matrix of random coefficients to correlation matrix
! also adjust variance-covariance matrix
if (COVREST==.FALSE. .AND. K_COV_RC>1) then
  call convertchol2corr(COEFFSSE,VCOV_OPG)
endif
! calculate vector of standard errors
do i=1,K
  SE(i)=sqrt(VCOV_OPG(i,i))
enddo




! add converted coefficients along with their standard error
! to the file `par.txt'
write(parameters_print,*)
write(parameters_print,*) 'Coefficient    Standard_Error'
write(parameters_print,*)
do i=1,K
  write(parameters_print,*) COEFFSSE(i),SE(i)
enddo
write(parameters_print,*)
write(parameters_print,*) LOGL_VALUE
write(parameters_print,*) 
write(parameters_print,*) 'Maximum Error in Gradient Calc', RIDDERS_ERR
write(parameters_print,*) 

! print variance-covariance matrix
open (UNIT=1001,FILE=paroutpath//'vcov.txt')
write(1001,*) 'row col sigma_row_col'
do j1=1,K
  do j2=1,K
    write(1001,*) j1,j2,VCOV_OPG(j1,j2)
  enddo
enddo
close(1001)


! print log-likelihood
open (UNIT=1002,FILE=paroutpath//'logl.txt')
write(1002,*) LOGL_VALUE
close(1002)


! print single coefficient vectors / matrices
call printfinal(COEFFSSE,SE)

end subroutine standerr




! **************************************************************

subroutine convertcoeffs_jac(COEFFS_IN,JACOB)
! generates jacobian matrix to transform standard errors
use controlpars
use hm_utils
real(DP),intent(in)::COEFFS_IN(K)
real(DP)::JACOB(K,K)
integer(I4B)::i,j

call unit_matrix(JACOB)

j=0
do i=1,K
  if (COEFFS_EXP(i)) then
    if (COEFFS_CONST(i)) then
	  JACOB(i,i)=exp(COEFFS_IN(i))
	  j=i+1
	  do while (j.LE.K .AND. COEFFS_CONST(j)==.FALSE.)
	    JACOB(j,i)=exp(COEFFS_IN(i)+COEFFS_IN(j))-exp(COEFFS_IN(i))
		j=j+1
      enddo
	  j=i
	else 
	  JACOB(i,i)=exp(COEFFS_IN(i)+COEFFS_IN(j))
	endif
  elseif (COEFFS_CDF(i)) then
    if (COEFFS_CONST(i)) then
	  JACOB(i,i)=logistpdf(COEFFS_IN(i))
	  j=i+1
	  do while (j.LE.K .AND. COEFFS_CONST(j)==.FALSE.)
	    JACOB(j,i)=logistpdf(COEFFS_IN(i)+COEFFS_IN(j))-logistpdf(COEFFS_IN(i))
		j=j+1
      enddo
	  j=i
	else 
	  JACOB(i,i)=logistpdf(COEFFS_IN(i)+COEFFS_IN(j))
	endif
  elseif (COEFFS_CDF2(i)) then
    if (COEFFS_CONST(i)) then
	  JACOB(i,i)=logistpdf(COEFFS_IN(i))*2.0d0
	  j=i+1
	  do while (j.LE.K .AND. COEFFS_CONST(j)==.FALSE.)
	    JACOB(j,i)=(logistpdf(COEFFS_IN(i)+COEFFS_IN(j))-logistpdf(COEFFS_IN(i)))*2.0d0
		j=j+1
      enddo
	  j=i
	else 
	  JACOB(i,i)=logistpdf(COEFFS_IN(i)+COEFFS_IN(j))*2.0d0
	endif
  endif
enddo

end subroutine convertcoeffs_jac




! **************************************************************

subroutine convertchol2corr(COEFFSSE,VCOV_OPG)
use controlpars
use hm_utils
real(DP),intent(inout)::COEFFSSE(K),VCOV_OPG(K,K)
real(DP)::c(K_COV_RC),               corrvechlp(K_COV_RC)      ,VCOV_OPGhlp(K_COV_RC,K_COV_RC)
real(DP)::cholhlp(L_COV_RC,L_COV_RC),corrhlp(L_COV_RC,L_COV_RC),jacse(K_COV_RC,K_COV_RC)


if (K_COV_RC>10) write(parameters_print,*) 'WRONG CORRELATION MATRIX -- only implemented up to dimension 4'

c=COEFFSSE(K-K_COV_RC+1:K);


jacse(1,1) = 1/sqrt(c(1)**2)*c(1)
jacse(1,2) = 0
jacse(1,3) = 0

jacse(2,1) = c(2)/sqrt(c(2)**2+c(3)**2)/sqrt(c(1)**2)-c(1)**2*c(2)/sqrt(c(2)**2+c(3)**2)/sqrt(c(1)**2)**3
jacse(2,2) = c(1)/sqrt(c(2)**2+c(3)**2)/sqrt(c(1)**2)-c(1)*c(2)**2/sqrt(c(2)**2+c(3)**2)**3/sqrt(c(1)**2)
jacse(2,3) = -c(1)*c(2)/sqrt(c(2)**2+c(3)**2)**3/sqrt(c(1)**2)*c(3)

jacse(3,1) = 0
jacse(3,2) = 1/sqrt(c(2)**2+c(3)**2)*c(2)
jacse(3,3) = 1/sqrt(c(2)**2+c(3)**2)*c(3)

if (L_COV_RC>2) then
  jacse(1,4) = 0
  jacse(1,5) = 0
  jacse(1,6) = 0
  
  jacse(2,4) = 0
  jacse(2,5) = 0
  jacse(2,6) = 0
  
  jacse(3,4) = 0
  jacse(3,5) = 0
  jacse(3,6) = 0
  
  jacse(4,1) = c(4)/sqrt(c(4)**2+c(5)**2+c(6)**2)/sqrt(c(1)**2)-c(1)**2*c(4)/sqrt(c(4)**2+c(5)**2+c(6)**2)/sqrt(c(1)**2)**3
  jacse(4,2) = 0
  jacse(4,3) = 0
  jacse(4,4) = c(1)/sqrt(c(4)**2+c(5)**2+c(6)**2)/sqrt(c(1)**2)-c(1)*c(4)**2/sqrt(c(4)**2+c(5)**2+c(6)**2)**3/sqrt(c(1)**2)
  jacse(4,5) = -c(1)*c(4)/sqrt(c(4)**2+c(5)**2+c(6)**2)**3/sqrt(c(1)**2)*c(5)
  jacse(4,6) = -c(1)*c(4)/sqrt(c(4)**2+c(5)**2+c(6)**2)**3/sqrt(c(1)**2)*c(6)
  
  jacse(5,1) = 0
  jacse(5,2) = c(4)/sqrt(c(4)**2+c(5)**2+c(6)**2)/sqrt(c(2)**2+c(3)**2)-(c(2)*c(4)+c(3)*c(5))/sqrt(c(4)**2+c(5)**2+c(6)**2)/sqrt(c(2)**2+c(3)**2)**3*c(2)
  jacse(5,3) = c(5)/sqrt(c(4)**2+c(5)**2+c(6)**2)/sqrt(c(2)**2+c(3)**2)-(c(2)*c(4)+c(3)*c(5))/sqrt(c(4)**2+c(5)**2+c(6)**2)/sqrt(c(2)**2+c(3)**2)**3*c(3)
  jacse(5,4) = c(2)/sqrt(c(4)**2+c(5)**2+c(6)**2)/sqrt(c(2)**2+c(3)**2)-(c(2)*c(4)+c(3)*c(5))/sqrt(c(4)**2+c(5)**2+c(6)**2)**3/sqrt(c(2)**2+c(3)**2)*c(4)
  jacse(5,5) = c(3)/sqrt(c(4)**2+c(5)**2+c(6)**2)/sqrt(c(2)**2+c(3)**2)-(c(2)*c(4)+c(3)*c(5))/sqrt(c(4)**2+c(5)**2+c(6)**2)**3/sqrt(c(2)**2+c(3)**2)*c(5)
  jacse(5,6) = -(c(2)*c(4)+c(3)*c(5))/sqrt(c(4)**2+c(5)**2+c(6)**2)**3/sqrt(c(2)**2+c(3)**2)*c(6)
  
  jacse(6,1) = 0
  jacse(6,2) = 0
  jacse(6,3) = 0
  jacse(6,4) = 1/sqrt(c(4)**2+c(5)**2+c(6)**2)*c(4)
  jacse(6,5) = 1/sqrt(c(4)**2+c(5)**2+c(6)**2)*c(5)
  jacse(6,6) = 1/sqrt(c(4)**2+c(5)**2+c(6)**2)*c(6)
endif  
  
if (L_COV_RC>3) then
  jacse(1,7) = 0
  jacse(1,8) = 0
  jacse(1,9) = 0
  jacse(1,10) = 0
  
  jacse(2,7) = 0
  jacse(2,8) = 0
  jacse(2,9) = 0
  jacse(2,10) = 0
  
  jacse(3,7) = 0
  jacse(3,8) = 0
  jacse(3,9) = 0
  jacse(3,10) = 0
  
  jacse(4,7) = 0
  jacse(4,8) = 0
  jacse(4,9) = 0
  jacse(4,10) = 0
  
  jacse(5,7) = 0
  jacse(5,8) = 0
  jacse(5,9) = 0
  jacse(5,10) = 0
  
  jacse(6,7) = 0
  jacse(6,8) = 0
  jacse(6,9) = 0
  jacse(6,10) = 0
  
  jacse(7,1) = c(7)/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)/sqrt(c(1)**2)-c(1)**2*c(7)/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)/sqrt(c(1)**2)**3
  jacse(7,2) = 0
  jacse(7,3) = 0
  jacse(7,4) = 0
  jacse(7,5) = 0
  jacse(7,6) = 0
  jacse(7,7) = c(1)/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)/sqrt(c(1)**2)-c(1)*c(7)**2/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)**3/sqrt(c(1)**2)
  jacse(7,8) = -c(1)*c(7)/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)**3/sqrt(c(1)**2)*c(8)
  jacse(7,9) = -c(1)*c(7)/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)**3/sqrt(c(1)**2)*c(9)
  jacse(7,10) = -c(1)*c(7)/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)**3/sqrt(c(1)**2)*c(10)
  
  jacse(8,1) = 0
  jacse(8,2) = c(7)/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)/sqrt(c(2)**2+c(3)**2)-(c(2)*c(7)+c(3)*c(8))/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)/sqrt(c(2)**2+c(3)**2)**3*c(2)
  jacse(8,3) = c(8)/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)/sqrt(c(2)**2+c(3)**2)-(c(2)*c(7)+c(3)*c(8))/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)/sqrt(c(2)**2+c(3)**2)**3*c(3)
  jacse(8,4) = 0
  jacse(8,5) = 0
  jacse(8,6) = 0
  jacse(8,7) = c(2)/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)/sqrt(c(2)**2+c(3)**2)-(c(2)*c(7)+c(3)*c(8))/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)**3/sqrt(c(2)**2+c(3)**2)*c(7)
  jacse(8,8) = c(3)/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)/sqrt(c(2)**2+c(3)**2)-(c(2)*c(7)+c(3)*c(8))/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)**3/sqrt(c(2)**2+c(3)**2)*c(8)
  jacse(8,9) = -(c(2)*c(7)+c(3)*c(8))/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)**3/sqrt(c(2)**2+c(3)**2)*c(9)
  jacse(8,10) = -(c(2)*c(7)+c(3)*c(8))/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)**3/sqrt(c(2)**2+c(3)**2)*c(10)
  
  jacse(9,1) = 0
  jacse(9,2) = 0
  jacse(9,3) = 0
  jacse(9,4) = c(7)/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)/sqrt(c(4)**2+c(5)**2+c(6)**2)-(c(4)*c(7)+c(5)*c(8)+c(6)*c(9))/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)/sqrt(c(4)**2+c(5)**2+c(6)**2)**3*c(4)
  jacse(9,5) = c(8)/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)/sqrt(c(4)**2+c(5)**2+c(6)**2)-(c(4)*c(7)+c(5)*c(8)+c(6)*c(9))/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)/sqrt(c(4)**2+c(5)**2+c(6)**2)**3*c(5)
  jacse(9,6) = c(9)/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)/sqrt(c(4)**2+c(5)**2+c(6)**2)-(c(4)*c(7)+c(5)*c(8)+c(6)*c(9))/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)/sqrt(c(4)**2+c(5)**2+c(6)**2)**3*c(6)
  jacse(9,7) = c(4)/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)/sqrt(c(4)**2+c(5)**2+c(6)**2)-(c(4)*c(7)+c(5)*c(8)+c(6)*c(9))/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)**3/sqrt(c(4)**2+c(5)**2+c(6)**2)*c(7)
  jacse(9,8) = c(5)/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)/sqrt(c(4)**2+c(5)**2+c(6)**2)-(c(4)*c(7)+c(5)*c(8)+c(6)*c(9))/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)**3/sqrt(c(4)**2+c(5)**2+c(6)**2)*c(8)
  jacse(9,9) = c(6)/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)/sqrt(c(4)**2+c(5)**2+c(6)**2)-(c(4)*c(7)+c(5)*c(8)+c(6)*c(9))/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)**3/sqrt(c(4)**2+c(5)**2+c(6)**2)*c(9)
  jacse(9,10) = -(c(4)*c(7)+c(5)*c(8)+c(6)*c(9))/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)**3/sqrt(c(4)**2+c(5)**2+c(6)**2)*c(10)
  
  jacse(10,1) = 0
  jacse(10,2) = 0
  jacse(10,3) = 0
  jacse(10,4) = 0
  jacse(10,5) = 0
  jacse(10,6) = 0
  jacse(10,7) = 1/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)*c(7)
  jacse(10,8) = 1/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)*c(8)
  jacse(10,9) = 1/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)*c(9)
  jacse(10,10) = 1/sqrt(c(7)**2+c(8)**2+c(9)**2+c(10)**2)*c(10)
endif

VCOV_OPGhlp=VCOV_OPG(K-K_COV_RC+1:K,K-K_COV_RC+1:K)
VCOV_OPGhlp=matmul(jacse,VCOV_OPGhlp)
VCOV_OPGhlp=matmul(VCOV_OPGhlp,transpose(jacse))
VCOV_OPG(K-K_COV_RC+1:K,K-K_COV_RC+1:K)=VCOV_OPGhlp

call vec2triangmat(L_COV_RC,c,cholhlp)
call chol2corr(L_COV_RC,cholhlp,corrhlp)
call triangmat2vec(L_COV_RC,corrhlp,corrvechlp)
COEFFSSE(K-K_COV_RC+1:K)=corrvechlp;

end subroutine convertchol2corr




! **************************************************************

subroutine convertmultiplicjac(COEFFSSE,JAC)
use controlpars
use hm_utils
real(DP),intent(inout)::COEFFSSE(K),JAC(K,K)
real(DP)::jacmult(K,K), c, d
integer(I4B)::i, indic_c(K_INC1), indic_d(K_INC1)

call unit_matrix(jacmult)


! indicators for the constant term on respective parameter
i=1
if (K_GAMMA>0) then
  indic_c(i)=1
  i=i+1
endif
if (K_LAMBDA>0) then
  indic_c(i)=K_GAMMA+1
  i=i+1
endif
if (K_RHO>0) then
  indic_c(i)=K_GAMMA+K_LAMBDA+1
  i=i+1
endif
if (K_TAU>0) then
  indic_c(i)=K_GAMMA+K_LAMBDA+K_RHO+1
  i=i+1
endif
if (K_OMEGA>0) then
  indic_c(i)=K_GAMMA+K_LAMBDA+K_RHO+K_TAU+1
endif

! indicators for coefficient on incentive 1 on the respective parameter
do i=1,K_INC1
  indic_d(i)=K_GAMMA+K_LAMBDA+K_RHO+K_TAU+K_OMEGA+i
enddo

! calculate additional jacobian elements
do i=1,K_INC1
  c=    COEFFSSE(indic_c(i))  ! coefficient on constant
  d=exp(COEFFSSE(indic_d(i))) ! coefficient on incentive_1, always >0
  if (COEFFS_EXP(indic_c(i))) then
    c=exp(c)
    jacmult(indic_d(i),indic_c(i))=c**d*(d-1.0d0)/c**2.0d0
    jacmult(indic_d(i),indic_d(i))=c**d*log(c)/c
  elseif (COEFFS_CDF(indic_c(i))) then
    c=logistcdf(c)
    jacmult(indic_d(i),indic_c(i))=1.0d0/((1.0d0+((1.0d0-c)/c)**d)**2.0d0)*((1.0d0-c)/c)**d*d/(1.0d0-c)/c**2.0d0-1.0d0/(1.0d0+((1.0d0-c)/c)**d)/c**2.0d0
    jacmult(indic_d(i),indic_d(i))=-1.0d0/((1.0d0+((1.0d0-c)/c)**d)**2.0d0)/c*((1.0d0-c)/c)**d*log((1.0d0-c)/c)
  elseif (COEFFS_CDF2(indic_c(i))) then
    c=(logistcdf(c)-.5d0 )*2.0d0
    jacmult(indic_d(i),indic_c(i))=(-c**2.0d0+1.0d0-4.0d0*((1.0d0-c)/(c+1.0d0))**d*d*c+(((1.0d0-c)/(c+1.0d0))**d)**2.0d0*c**2.0d0-(((1.0d0-c)/(c+1.0d0))**d)**2.0d0)/(-1.0d0+c)/(c+1.0d0)/(1.0d0+((1.0d0-c)/(c+1.0d0))**d)**2.0d0/c**2.0d0
    jacmult(indic_d(i),indic_d(i))=-2.0d0/c/(1.0d0+((1.0d0-c)/(c+1.0d0))**d)**2.0d0*((1.0d0-c)/(c+1.0d0))**d*log((1.0d0-c)/(c+1.0d0))
  endif
enddo

JAC=matmul(jacmult,JAC)

end subroutine convertmultiplicjac




! **************************************************************

subroutine printfinal(COEFFSSE,SE)
use controlpars
use hm_utils
real(DP),intent(in)::COEFFSSE(K),SE(K)
integer(I4B)::temp,i,j
real(DP)::GAMSE(2*K_GAMMA),LAMSE(2*K_LAMBDA),RHOSE(2*K_RHO),             &
          TAUSE(2*K_TAU),OMGSE(2*K_OMEGA),IN1SE(2*K_INC1),               & 
		  CORRPRINT(L_COV_RC,L_COV_RC),CORRPRINTSE(2*L_COV_RC,L_COV_RC), &
		  CORRPRINT_HLP(L_COV_RC,L_COV_RC) 


temp=0
if (K_GAMMA > 0) then
  open (UNIT=99,FILE=paroutpath//'gamma.txt')
  call printvec(K_GAMMA,COEFFSSE(temp+1:temp+K_GAMMA),99)
  close(99)
  i=1
  do j=1,K_GAMMA
    GAMSE(i)=COEFFSSE(temp+j)
	i=i+1
    GAMSE(i)=      SE(temp+j)
	i=i+1
  enddo
  open (UNIT=99,FILE=paroutpath//'gammase.txt')
  call printvec(2*K_GAMMA,GAMSE,99)
  close(99)
  temp=temp+K_GAMMA
endif
if (K_LAMBDA > 0) then
  open (UNIT=99,FILE=paroutpath//'lambda.txt')
  call printvec(K_LAMBDA,COEFFSSE(temp+1:temp+K_LAMBDA),99)
  close(99)
  i=1
  do j=1,K_LAMBDA
    LAMSE(i)=COEFFSSE(temp+j)
	i=i+1
    LAMSE(i)=      SE(temp+j)
	i=i+1
  enddo
  open (UNIT=99,FILE=paroutpath//'lambdase.txt')
  call printvec(2*K_LAMBDA,LAMSE,99)
  close(99)
  temp=temp+K_LAMBDA
endif
if (K_RHO > 0) then
  open (UNIT=99,FILE=paroutpath//'rho.txt')
  call printvec(K_RHO,COEFFSSE(temp+1:temp+K_RHO),99)
  close(99)
  i=1
  do j=1,K_RHO
    RHOSE(i)=COEFFSSE(temp+j)
	i=i+1
    RHOSE(i)=      SE(temp+j)
	i=i+1
  enddo
  open (UNIT=99,FILE=paroutpath//'rhose.txt')
  call printvec(2*K_RHO,RHOSE,99)
  close(99)
  temp=temp+K_RHO
endif
if (K_TAU > 0) then
  open (UNIT=99,FILE=paroutpath//'tau.txt')
  call printvec(K_TAU,COEFFSSE(temp+1:temp+K_TAU),99)
  close(99)
  i=1
  do j=1,K_TAU
    TAUSE(i)=COEFFSSE(temp+j)
	i=i+1
    TAUSE(i)=      SE(temp+j)
	i=i+1
  enddo
  open (UNIT=99,FILE=paroutpath//'tause.txt')
  call printvec(2*K_TAU,TAUSE,99)
  close(99)
  temp=temp+K_TAU
endif
if (K_OMEGA > 0) then
  open (UNIT=99,FILE=paroutpath//'omega.txt')
  call printvec(K_OMEGA,COEFFSSE(temp+1:temp+K_OMEGA),99)
  close(99)
  i=1
  do j=1,K_OMEGA
    OMGSE(i)=COEFFSSE(temp+j)
	i=i+1
    OMGSE(i)=      SE(temp+j)
	i=i+1
  enddo
  open (UNIT=99,FILE=paroutpath//'omegase.txt')
  call printvec(2*K_OMEGA,OMGSE,99)
  close(99)
  temp=temp+K_OMEGA
endif
if (K_INC1  > 0) then
  open (UNIT=99,FILE=paroutpath//'incentive1.txt')
  call printvec(K_INC1,COEFFSSE(temp+1:temp+K_INC1),99)
  close(99)
  i=1
  do j=1,K_INC1
    IN1SE(i)=COEFFSSE(temp+j)
	i=i+1
    IN1SE(i)=      SE(temp+j)
	i=i+1
  enddo
  open (UNIT=99,FILE=paroutpath//'incentive1se.txt')
  call printvec(2*K_INC1,IN1SE,99)
  close(99)
  temp=temp+K_INC1
endif

CORRPRINT  =0.0d0
CORRPRINTSE=0.0d0
if (K_COV_RC > 0) then
  if (COVREST) then
    i=1
    do j = 1,L_COV_RC
      CORRPRINT  (j,j)=COEFFSSE(temp+j)
	  CORRPRINTSE(i,j)=COEFFSSE(temp+j)
	  i=i+1
	  CORRPRINTSE(i,j)=      SE(temp+j)
	  i=i+1
    enddo
  else 
    call vec2triangmat(L_COV_RC,COEFFSSE(temp+1:K),CORRPRINT)
    call vec2triangmat(L_COV_RC,      SE(temp+1:K),CORRPRINT_HLP)
    i=1
    do j = 1,L_COV_RC
      CORRPRINTSE(i,:)=CORRPRINT(j,:)
      i=i+1
      CORRPRINTSE(i,:)=CORRPRINT_HLP(j,:)
      i=i+1
    enddo
  endif
  open (UNIT=99,FILE=paroutpath//'corr.txt')
  call printarray(L_COV_RC,L_COV_RC,CORRPRINT,99)
  close(99)
  open (UNIT=99,FILE=paroutpath//'corrse.txt')
  call printarray(2*L_COV_RC,L_COV_RC,CORRPRINTSE,99)
  close(99)
endif




end subroutine printfinal