local thisdofilename corrtable-condensed
include ../lib_local/header
log close
// graphs condensed table with standard deviations etc.
// not foolproof, i.e. if model specification is changed, will need
// some changes in the bottom as well
pause on

local Sigma "restr"

local nmodels 2

local model1 kp
local datatype1 demog
local fullsimple1 s
local freerestr1 `Sigma'

local model2 kp
local datatype2 demog
local fullsimple2 f
local freerestr2 `Sigma'


// 1 PREPARE COLUMNS WITH VARIABLE NAMES

// get raw parameter names from all models in the sample
forvalues n=1/`nmodels' {
    if ("`model`n''"=="kp" & "`model`n''"!="ca") {
        local vars`n' gam lam rho omg
        local nvars`n'=4
        local sigvars " "
        foreach x in `vars`n'' {
            local sigvars= "`sigvars' sig`x'`n'"
        }
        qui infile `sigvars' using "../main_estimation/`model`n''-`datatype`n''-`fullsimple`n''/output_`freerestr`n''/corrse.txt", clear
    }
    if ("`model`n''"!="kp" & "`model`n''"=="ca") {
        local vars`n' gam omg
        local nvars`n' = 2
        local sigvars " "
        foreach x in `vars`n'' {
            local sigvars= "`sigvars' sig`x'`n'"
        }
        qui infile `sigvars' using "../main_estimation/`model`n''-`datatype`n''-`fullsimple`n''/output_`freerestr`n''/corrse.txt", clear
    }
    if ("`model`n''"!="kp" & "`model`n''"!="ca") {
        local vars`n' gam lam omg
        local nvars`n' = 3
        local sigvars " "
        foreach x in `vars`n'' {
            local sigvars= "`sigvars' sig`x'`n'"
        }
        qui infile `sigvars' using "../main_estimation/`model`n''-`datatype`n''-`fullsimple`n''/output_`freerestr`n''/corrse.txt", clear
    }
    qui gen rowname=" "
    local i=1
    foreach var in `vars`n'' {
        qui replace rowname="sig`var'" in `i'
        local i=`i'+1
        qui replace rowname="sig`var'se" in `i'
        local i=`i'+1
    }
    gen `model`n''_`datatype`n''_`fullsimple`n''=.
    local j1 = 1
    local j2 = 2
    foreach var in `sigvars' {
        qui replace `model`n''_`datatype`n''_`fullsimple`n'' = `var' in `j1'/`j2'
        local j1 = `j1'+2
        local j2 = `j2'+2
    }
    keep rowname `model`n''_`datatype`n''_`fullsimple`n''
    if `n'==1 {
        qui save temp1, replace
    }
    else {
        qui save temp2, replace
        u temp1
        qui merge rowname using temp2, sort
        drop _m
        qui save temp1, replace
    }
    qui infile `model`n''_`datatype`n''_`fullsimple`n'' using "../main_estimation/`model`n''-`datatype`n''-`fullsimple`n''/output_`freerestr`n''/tause.txt", clear
    qui gen rowname="tau"
    qui replace rowname="tause" in 2
    if (`n'==1) {
        append using temp1
        save temp1,replace
    }
    else {
        qui save temp2, replace
        u temp1
        qui merge rowname using temp2, sort update
        drop _m
        qui save temp1, replace
    }
    qui infile `model`n''_`datatype`n''_`fullsimple`n'' using "../main_estimation/`model`n''-`datatype`n''-`fullsimple`n''/output_`freerestr`n''/incentive1se.txt", clear
    qui su `model`n''_`datatype`n''_`fullsimple`n''
    local loc1=r(N)-3
    local loc2=r(N)-2
    keep in `loc1'/`loc2'
    qui gen rowname="in1tau"
    qui replace rowname="in1tause" in 2
    if (`n'==1) {
        append using temp1
        save temp1, replace
    }
    else {
        qui save temp2, replace
        u temp1
        qui merge rowname using temp2, sort update
        drop _m
        qui save temp1, replace
    }
    qui infile `model`n''_`datatype`n''_`fullsimple`n'' using "../main_estimation/`model`n''-`datatype`n''-`fullsimple`n''/output_`freerestr`n''/logl.txt", clear
    qui gen rowname="logl"
    if (`n'==1) {
        append using temp1
        save temp1,replace
    }
    else {
        qui save temp2, replace
        u temp1
        qui merge rowname using temp2, sort update
        drop _m
        qui save temp1, replace
    }
}
qui gen id=1 if rowname=="siggam"
qui replace id=2 if rowname=="siggamse"
qui replace id=3 if rowname=="siglam"
qui replace id=4 if rowname=="siglamse"
qui replace id=5 if rowname=="sigrho"
qui replace id=6 if rowname=="sigrhose"
qui replace id=7 if rowname=="sigomg"
qui replace id=8 if rowname=="sigomgse"
qui replace id=9 if rowname=="tau"
qui replace id=10 if rowname=="tause"
qui replace id=11 if rowname=="in1tau"
qui replace id=12 if rowname=="in1tause"
qui replace id=13 if rowname=="logl"

sort id


forvalues stop_logging = 0/0 {
    
    // preliminaries for out-tex
    local OUTFILE "`tablesdir_prefhet'/corr-condensed.tex"
    capture erase `OUTFILE'
    qui log using `OUTFILE'
    
    di "\begin {tabular} {lrr} \hline\hline\\"
    di "& \multicolumn {1} {c} {Minimal Set of} & \multicolumn {1} {c} {Full Set of} \\"
    di "& \multicolumn {1} {c} {Covariates} & \multicolumn {1} {c} {Covariates} \\[2ex]\hline"
    
    qui su id
    local nobs=r(N)
    
    local modelslist
    forvalues n=1/`nmodels' {
        local modelslist = "`modelslist' `model`n''_`datatype`n''_`fullsimple`n''"
    }
    forvalues i=1/`nobs' {
        
        if (rowname[`i']=="siggam") {
            di "$\sigma_\gamma$"
            foreach var in `modelslist' {
                if (missing(`var'[`i'])==0) {
                    di "& " %9.3f `var'[`i']
                }
                else {
                    di "& "
                }
            }
            local j=`i'+1
            di "\\[-.75ex]"
            foreach var in `modelslist' {
                if (missing(`var'[`i'])==0) {
                    di "& \tiny {$( "%9.3f `var'[`j'] ")$}"
                }
                else {
                    di "& "
                }
            }
            di "\\"
        }
        if (rowname[`i']=="siglam") {
            local k=1
            foreach var in `modelslist' {
                if (`k'==1) {
                    di "$\sigma_\lambda$"
                }
                local k=`k'+1
                if (missing(`var'[`i'])==0) {
                    di "& " %9.3f `var'[`i']
                }
                else {
                    di "& "
                }
            }
            local j=`i'+1
            di "\\[-.75ex]"
            foreach var in `modelslist' {
                if (missing(`var'[`i'])==0) {
                    di "& \tiny {$( "%9.3f `var'[`j'] ")$}"
                }
                else {
                    di "& "
                }
            }
            di "\\"
        }
        if (rowname[`i']=="sigrho") {
            local k=1
            foreach var in `modelslist' {
                if (`k'==1) {
                    di "$\sigma_\rho$"
                }
                local k=`k'+1
                if (missing(`var'[`i'])==0) {
                    di "& " %9.3f `var'[`i']
                }
                else {
                    di "& "
                }
            }
            local j=`i'+1
            di "\\[-.75ex]"
            foreach var in `modelslist' {
                if (missing(`var'[`i'])==0) {
                    di "& \tiny {$( "%9.3f `var'[`j'] ")$}"
                }
                else {
                    di "& "
                }
            }
            di "\\"
        }
        if (rowname[`i']=="sigomg") {
            local k=1
            foreach var in `modelslist' {
                if (`k'==1) {
                    di "$\sigma_\omega$"
                }
                local k=`k'+1
                if (missing(`var'[`i'])==0) {
                    di "& " %9.3f `var'[`i']
                }
                else {
                    di "& "
                }
            }
            local j=`i'+1
            di "\\[-.75ex]"
            foreach var in `modelslist' {
                if (missing(`var'[`i'])==0) {
                    di "& \tiny {$( "%9.3f `var'[`j'] ")$}"
                }
                else {
                    di "& "
                }
            }
            di "\\[2ex]\hline"
        }
        if (rowname[`i']=="tau") {
            local k=1
            foreach var in `modelslist' {
                if (`k'==1) {
                    di "$\tau$"
                }
                local k=`k'+1
                if (missing(`var'[`i'])==0) {
                    di "& " %9.3f `var'[`i']
                }
                else {
                    di "& "
                }
            }
            local j=`i'+1
            di "\\[-.75ex]"
            foreach var in `modelslist' {
                if (missing(`var'[`i'])==0) {
                    di "& \tiny {$( "%9.3f `var'[`j'] ")$}"
                }
                else {
                    di "& "
                }
            }
            di "\\"
        }
        if (rowname[`i']=="in1tau") {
            local k=1
            foreach var in `modelslist' {
                if (`k'==1) {
                    di "$\tau_ {\text {Low Inc}}~^\dag$"
                }
                local k=`k'+1
                if (missing(`var'[`i'])==0) {
                    di "& " %9.3f `var'[`i']
                }
                else {
                    di "& "
                }
            }
            local j=`i'+1
            di "\\[-.75ex]"
            foreach var in `modelslist' {
                if (missing(`var'[`i'])==0) {
                    di "& \tiny {$( "%9.3f `var'[`j'] ")$}"
                }
                else {
                    di "& "
                }
            }
            di "\\[2ex]\hline"
        }
        if (rowname[`i']=="logl") {
            local k=1
            foreach var in `modelslist' {
                if (`k'==1) {
                    di "Log-Likel"
                }
                local k=`k'+1
                if (missing(`var'[`i'])==0) {
                    di "& " %9.1f `var'[`i']
                }
                else {
                    di "& "
                }
            }
            local j=`i'+1
        }
    }
    di "\\\hline\hline\end {tabular}"
    qui log c
}
erase temp1.dta
erase temp2.dta

scons_returncode

