local thisdofilename graph2models
include ../lib_local/header

// STRUCTURE OF THIS FILE
// 0 DEFINE MODELS
// 1 MERGE DATASETS
// 2 PLOT OVERALL PARAMETER DISTRIBUTIONS

// comparison graphics from any two models

// 0 DEFINE PARAMETERS
tempfile temp
// directory where files go, create it in case it doesn't exist
local homedir=c(pwd)
capture cd `graphicsdir_prefhet'/graph2
if (_rc!=0) {
    capture mkdir `graphicsdir_prefhet'/graph2
}
qui cd `homedir'

// model A should be the one with greater support of distributions
local modelA "kp"
local datatypeA "demog"
local fullsimpleA "s"
local freerestrA "restr"

local modelB "kp"
local datatypeB "demog"
local fullsimpleB "f"
local freerestrB "restr"

local legendnameA="Full set of covariates"
local legendnameB="Minimal set of covariates"

local parameterlist "gam lam rho omg"


// 1 MERGE DATASETS
local infilenameA "../`modelA'-`datatypeA'-`fullsimpleA'/`freerestrA'/data-stand"
local infilenameB "../`modelB'-`datatypeB'-`fullsimpleB'/`freerestrB'/data-stand"

u `graphicsdir_prefhet'/graph2/`infilenameB'
foreach var of varlist _all {
    rename `var' `var'B
}
rename nohhmemB nohhmem
qui replace nohhmem=-_n if nohhmem==.
qui save `temp', replace

u `graphicsdir_prefhet'/graph2/`infilenameA'
foreach var of varlist _all {
    rename `var' `var'A
}
rename nohhmemA nohhmem
qui replace nohhmem=-_n if nohhmem==.
qui merge nohhmem using `temp', sort


// 2 PLOT DISTRIBUTIONS
set scheme s1mono
local j=1
foreach par in `parameterlist' {
    local rangeLO=rangeLO`par'A[1]
    local rangeUP=rangeUP`par'A[1]
    
    if ("`par'"=="gam") {
        twoway ///
        (line f`par'_mixA x`par'_mixA , sort) ///
        (line f`par'_mixB x`par'_mixB , sort), ///
        legend(label(1 `legendnameA') label(2 `legendnameB') ) ///
        xtitle(Risk Preference Parameter) ytitle(Density) ///
        title(A: Risk Preference Parameter)
    }
    if ("`par'"=="lam") {
        local rangeUP=10
        twoway ///
        (line f`par'_mixA x`par'_mixA ///
        if x`par'_mixA>`rangeLO' & x`par'_mixA<`rangeUP', sort) ///
        (line f`par'_mixB x`par'_mixB ///
        if x`par'_mixB>`rangeLO' & x`par'_mixB<`rangeUP', sort), ///
        legend(label(1 `legendnameA') label(2 `legendnameB') ) ///
        xtitle(Loss Aversion Parameter) ytitle(Density) ///
        title(B: Loss Aversion Parameter)
    }
    if ("`par'"=="rho") {
        twoway ///
        (line f`par'_mixA x`par'_mixA ///
        if x`par'_mixA>`rangeLO' & x`par'_mixA<`rangeUP', sort) ///
        (line f`par'_mixB x`par'_mixB ///
        if x`par'_mixB>`rangeLO' & x`par'_mixB<`rangeUP', sort), ///
        legend(label(1 `legendnameA') label(2 `legendnameB') ) ///
        xtitle(Uncertainty Resolution Preference Parameter) ytitle(Density) ///
        title(C: Uncertainty Resolution Preference Parameter)
    }
    if ("`par'"=="omg") {
        twoway ///
        (line f`par'_mixA x`par'_mixA ///
        if x`par'_mixA>`rangeLO' & x`par'_mixA<`rangeUP', sort) ///
        (line f`par'_mixB x`par'_mixB ///
        if x`par'_mixB>`rangeLO' & x`par'_mixB<`rangeUP', sort), ///
        legend(label(1 `legendnameA') label(2 `legendnameB') ) ///
        xtitle(Random Choice Probability Parameter) ///
        ytitle(Density) title(C: Random Choice Probability Parameter)
    }
    local ++j
    qui graph_export_pdf `graphicsdir_prefhet'/graph2/`par'_mix__`modelA'-`datatypeA'-`fullsimpleA'__vs__`modelB'-`datatypeB'-`fullsimpleB',replace
}


scons_returncode


