local thisdofilename inconsistencies
include ../lib_local/header
pause on
use "`formatteddatadir'/exp_dhs_aer_meanswitch.dta", clear

// Table Inconsistencies per order of payoff configuration

// Number of inconsistencies
gen ninconsdominance = nincons5 + nincons6 + nincons7
egen ninconsbetween = rowmax(nincons3 nincons4)
// total, not only only one violation per payoff configuration is counted,
// but only one violation of each type per payoff configuration.

// Do the same for each payoff configuration separately
forvalues i = 1/7 {
    gen ninconsdominance`i' = inconsist5_`i' + inconsist6_`i' + inconsist7_`i'
    egen ninconsbetween`i' = rowmax(inconsist3_`i' inconsist4_`i')
    gen ninconswithin`i' = inconsist1_`i' + inconsist2_`i'
}
// Note that we only count one between-violation per
// payoff configuration and subject


// Count total number of second screens per individual
forvalues i = 1/7 {
    gen stop`i'= (inconsist1_`i' == 1 | inconsist5_`i' ==1)
    gen screens`i' = 2 - stop`i'
    gen secondscreens`i' = 1-stop`i'
}
egen totalstop = rowtotal(stop*)
gen secondscreens = 7-totalstop
drop totalstop

// Count total number of screens per individual
gen screens = 7 + secondscreens

// Count number of second screens with dominance possibility, per individual
forvalues i =1/7 {
    gen dom_poss`i' = (q`i'_100a !=. | q`i'_0 !=. )
    replace dom_poss`i' = dom_poss`i'+1
}
egen dom_poss = rowtotal(dom_poss*)

// Count total number of screens with dominance possibility by individual
gen total_dom_poss = 7 + dom_poss

// Make variable for with reordered payoff configuration
// Order 0: (2; 7; 3; 6; 1; 4; 5)
// Order 1: (1; 4; 5; 2; 6; 3; 7)
forvalues i = 1/7 {
    gen ninconsdominance_order`i' = .
    gen ninconsbetween_order`i' = .
    gen ninconswithin_order`i' = .
    gen inconstotal_order`i' = .
    gen screens_order`i' = .
    gen secondscreens_order`i' = .
    gen dom_poss_order`i' = .
}
foreach i in ninconsdominance ninconsbetween ninconswithin inconstotal screens secondscreens dom_poss {
    replace `i'_order1 = `i'5 if order == 0
    replace `i'_order2 = `i'1 if order == 0
    replace `i'_order3 = `i'3 if order == 0
    replace `i'_order4 = `i'6 if order == 0
    replace `i'_order5 = `i'7 if order == 0
    replace `i'_order6 = `i'4 if order == 0
    replace `i'_order7 = `i'2 if order == 0
    replace `i'_order1 = `i'1 if order == 1
    replace `i'_order2 = `i'4 if order == 1
    replace `i'_order3 = `i'6 if order == 1
    replace `i'_order4 = `i'2 if order == 1
    replace `i'_order5 = `i'3 if order == 1
    replace `i'_order6 = `i'5 if order == 1
    replace `i'_order7 = `i'7 if order == 1
}

// Summary statistics for aggregating over all payoff configurations
gen domviolations = ninconsdominance / dom_poss
gen withinviolations = ninconswithin / screens
gen betweenviolations = ninconsbetween / secondscreens
gen inconstotal = ninconstotal / 7

// Summary statistics by payoff configuration used in the table.
forvalues i = 1/7 {
    gen domviolations`i' = ninconsdominance`i'/dom_poss`i'
    gen withinviolations`i' = ninconswithin`i'/screens`i'
    gen betweenviolations`i' = ninconsbetween`i'/secondscreens`i'
    
    gen domviolations_order`i' = ninconsdominance_order`i'/dom_poss_order`i'
    gen withinviolations_order`i' = ninconswithin_order`i'/screens_order`i'
    gen betweenviolations_order`i' = ninconsbetween_order`i'/secondscreens_order`i'
}

collapse (mean) domviolations* withinviolations* betweenviolations* inconstotal*

// by payoff configuration
foreach i in domviolations withinviolations betweenviolations inconstotal {
    sum `i'1 `i'2 `i'3 `i'4 `i'5 `i'6 `i'7
}

// by order
foreach i in domviolations_order withinviolations_order betweenviolations_order inconstotal_order {
    sum `i'1 `i'2 `i'3 `i'4 `i'5 `i'6 `i'7
}

// total per error type
sum domviolations withinviolations betweenviolations inconstotal

cap file close tex_file 
// write tables
foreach stub in "pc" "order" {
    // pick right extension of variable name
    if "`stub'" == "pc" {
        local varstub 
        local title_col1 = "Payoff configuration"
    }
    else if "`stub'" == "order" {
        local varstub = "_order"
        local title_col1 = "Order of payoff configuration"
    }
    // open file
    qui file open tex_file using "`tablesdir_prefhet'/TableInconsistencies-`stub'.tex", write replace
    // write table contents
    file write tex_file "\begin{tabular}{ccccc}" _n
    file write tex_file "\hline\hline" _n
    file write tex_file "\textbf{`title_col1'} & \textbf{Dominance} & \textbf{Within} & \textbf{Between} & \textbf{Any type} \\" _n
    file write tex_file "\hline" _n
    forvalues i = 1 / 8 {
        if `i' < 8 {
            file write tex_file "`i' & "
        }
        else {
            local i 
            if "`stub'" == "order" {
                local varstub
            }
            file write tex_file "\hline" _n "Total & "
        }
        local j = 1
        foreach type in "domviolations" "withinviolations" "betweenviolations" "inconstotal" {
            file write tex_file %5.1f (`type'`varstub'`i' * 100) "\%"
            if `j' < 4 {
                file write tex_file " & "
            }
            else {
                file write tex_file " \\" _n
            }
            local ++j
        }
    }
    file write tex_file "\hline\hline" _n
    file write tex_file "\end{tabular}" _n
    // close file
    file close tex_file 
}



log close
scons_returncode

