local thisdofilename maingraphs
include ../lib_local/header
pause on

// STRUCTURE OF THIS FILE
// 0 DEFINE PARAMETERS
// 1 PLOT CONDITIONAL PARAMETER DISTRIBUTIONS (i.e. individual-level)
// 2 PLOT SMOOTHED INDIVIDUAL AVERAGE PARAMETERS
// 3 PLOT RAW INDIVIDUAL-LEVEL CHOICES

// ONLY VALID FOR INCENTIVE TREATMENT != 1


// 0 DEFINE PARAMETERS
tempvar fparnorm
local globalcounter=0


// list should start with people included in paper, in the right order
// try to keep short, lots of graphs produced
local individualslist = "97 370 1615 1589 193"

foreach model in ca la pt ptcrra kp {
    
    // translate models into parameter configurations
    if (regexm("`model'","ca")) {
        local parameterlist = "gam omg"
    }
    else if (regexm("`model'","la") | regexm("`model'","pt")) {
        local parameterlist = "gam lam omg"
    }
    else if (regexm("`model'","kp")) {
        local parameterlist = "gam lam rho omg"
    }
    else {
        di "Error: Wrong model specified -- `model'"
        error(1)
    }
    // implement [-1,1] restriction on \gamma in case of crra
    if regexm("`model'","crra")==1 {
        local gamrange "restr"
    }
    else {
        local gamrange "full"
    }
    local datatype = "demog"
    foreach fullsimple in f s {
        foreach Sigma in restr {
            // could add "free", but leave it at this to not litter directories
            
            // debugging info
            di " "
            di " "
            di " "
            di "`model'-`datatype'-`fullsimple'-`Sigma'"
            di "All incentive treatments standardised"
            di "to have the same distribution"
            di " "
            
            local outdirname "`graphicsdir_prefhet'/`model'-`datatype'-`fullsimple'/`Sigma'"
            local infilename "data-stand"

            capture use `outdirname'/`infilename', clear
            
            // step out par-loop in case model has not been estimated
            if (_rc!=0) {
                continue, break
            }
          
            // 1 PLOT CONDITIONAL VS UNCONDTIONAL PARAMETER DISTRIBUTIONS
            set scheme s1mono
            
            gen `fparnorm'=0
            local indpaper=0
            foreach indraw in `individualslist' {
                di "`indraw'"
                
                // set some values, get location of individual in data
                local ++indpaper
                local j=1
                local i1=0
                while (`i1'==0 & `j'<2000) {
                    if (nohhmem[`j'] == `indraw') {
                        local i1=`j'
                        continue, break
                    }
                    local ++j
                }
                if (`j'==2000) {
                    continue
                }
                local j = 1
                foreach par in `parameterlist' {
                    
                    // set parameters of the distributions
                    local med=`par'ind[`i1']
                    local sd=corr_`par'[`j']
                    local rangeLO=rangeLO`par'[1]
                    local rangeUP=rangeUP`par'[1]
                    
                    // generate local macro for normalised normal distribution
                    local ndens "normalden(x,`med',`sd')/(1/((2*_pi)^.5*`sd'))"
                    
                    // generate local macro for normalised log-normal distribution
                    local logndens "1/(x*(2*_pi)^.5*`sd')*exp(-.5*((log(x)-log(`med'))/`sd')^2)/(1/(exp(log(`med')-`sd'^2)*(2*_pi)^.5*`sd')*exp(-.5*(`sd')^2))"
                    
                    // generate local macro for normalised logit-normal distribution
                    if ("`par'"=="omg") {
                        local logitndens "1/(x*(1-x)*(2*_pi)^.5*`sd')*exp(-.5*((logit(x)-logit(`med'))/`sd')^2)"
                        gen x=`rangeLO'+uniform()/20
                        qui replace x=`rangeLO' in 1
                        gen temp=`logitndens'
                        qui su temp
                        drop x temp
                        local normalise=r(max)
                        local logitndens "1/(x*(1-x)*(2*_pi)^.5*`sd')*exp(-.5*((logit(x)-logit(`med'))/`sd')^2)/`normalise'"
                    }
                    // generate local macro for normalised logit2-normal distribution
                    if ("`par'"=="gam" & "`gamrange'"!="full") {
                        local logit2ndens "2/((1-x^2)*(2*_pi)^.5*`sd')*exp(-.5*((logit(x/2+.5)-logit(`med'/2+.5))/`sd')^2)"
                        gen x=`rangeUP'-uniform()
                        qui replace x=`rangeUP' in 1
                        gen temp=`logit2ndens'
                        qui su temp
                        drop x temp
                        local normalise2=r(max)
                        local logit2ndens "2/((1-x^2)*(2*_pi)^.5*`sd')*exp(-.5*((logit(x/2+.5)-logit(`med'/2+.5))/`sd')^2)/`normalise2'"
                    }
                    // do the graphics
                    capture destring f`par'_`indraw', replace force
                    qui su f`par'_`indraw'
                    qui replace `fparnorm'=f`par'_`indraw'/r(max)
                    
                    if ("`par'"=="gam" & "`gamrange'"=="full") {
                        local xlab `rangeLO' (.1)`rangeUP'
                        local mtix `rangeLO'(.01)`rangeUP'
                        twoway ///
                        (line f`par'_mix x`par'_mix, sort) ///
                        (line f`par'_`indraw' x`par'_`indraw' ///
                        if x`par'_`indraw'>`rangeLO' & x`par'_`indraw'<`rangeUP' & f`par'_`indraw'>.001, sort), ///
                        legend(off) xtitle(Risk Preference Parameter) ///
                        xmticks(`mtix') xlabel(`xlab') ytitle(Density) ///
                        title(A: Risk Preference Parameter)
                    }
                    if ("`par'"=="gam" & "`gamrange'"!="full") {
                        local xlab -1(.5)1
                        local mtix -1(.1)1
                        twoway ///
                        (line f`par'_mix x`par'_mix, sort) ///
                        (line f`par'_`indraw' x`par'_`indraw' ///
                        if x`par'_`indraw'>`rangeLO' & x`par'_`indraw'<`rangeUP' & f`par'_`indraw'>.001, sort), ///
                        legend(off) xtitle(Risk Preference Parameter) ///
                        xmticks(`mtix') xlabel(`xlab') ytitle(Density) ///
                        title(A: Risk Preference Parameter)
                    }
                    if ("`par'"=="lam") {
                        // only increase rangeUP for a couple of ind's
                        local rangeUP=10
                        local xlab 0(2)`rangeUP'
                        local mtix 0(1)`rangeUP'
                        if ( `indraw'==199701 ) {
                            local rangeUP=100
                            local xlab 0(10)`rangeUP'
                            local mtix 2(2)98
                        }
                        if ( `indraw'==370 | `indraw'==1327902 | `indraw'==1615 | `indraw'==1287201 ) {
                            local rangeUP=40
                            local xlab 0(5)`rangeUP'
                            local mtix 1(1)39
                        }
                        if ( `indraw'==1063001 ) {
                            local rangeUP=20
                            local xlab 0(2)`rangeUP'
                            local mtix 1(2)19
                        }
                        twoway ///
                        (line f`par'_mix x`par'_mix ///
                        if x`par'_mix>`rangeLO' & x`par'_mix<`rangeUP', sort) ///
                        (line f`par'_`indraw' x`par'_`indraw' ///
                        if x`par'_`indraw'>`rangeLO' & x`par'_`indraw'<`rangeUP' & f`par'_`indraw'>.001, sort), ///
                        legend(off) xtitle(Loss Aversion Parameter) ///
                        xmticks(`mtix') xlabel(`xlab') ytitle(Density) ///
                        title(B: Loss Aversion Parameter)
                    }
                    if ("`par'"=="rho") {
                        local xlab 0(1)`rangeUP'
                        local mtix 0(.5)`rangeUP'
                        twoway ///
                        (line f`par'_mix x`par'_mix, sort) ///
                        (line f`par'_`indraw' x`par'_`indraw' ///
                        if x`par'_`indraw'>`rangeLO' & x`par'_`indraw'<`rangeUP' & f`par'_`indraw'>.001, sort), ///
                        legend(off) xtitle(Uncertainty Resolution Preference Parameter) ///
                        xmticks(`mtix') xlabel(`xlab') ytitle(Density) ///
                        title(C: Uncertainty Resolution Preference Parameter)
                    }
                    if ("`par'"=="omg") {
                        local xlab 0(.2)1
                        local mtix 0(.1)1
                        twoway ///
                        (line f`par'_mix x`par'_mix, sort) ///
                        (line f`par'_`indraw' x`par'_`indraw' ///
                        if x`par'_`indraw'>`rangeLO' & x`par'_`indraw'<`rangeUP' & f`par'_`indraw'>.001, sort), ///
                        legend(off) xtitle(Random Choice Probability Parameter) ///
                        xmticks(`mtix') xlabel(`xlab') ytitle(Density) ///
                        title(D: Random Choice Probability Parameter)
                    }
                    local ++j
                    qui graph_export_pdf `outdirname'/f_`par'_`indpaper', replace
                }
            }
            drop `fparnorm'
            
            // 2 PLOT OBSERVED HET VS TOTAL HET
            set scheme s1mono
            
            local j=1
            foreach par in `parameterlist' {
                
                local rangeLO=rangeLO`par'[1]
                local rangeUP=rangeUP`par'[1]
                
                if ("`par'"=="gam") {
                    local mtix `rangeLO'(.01)`rangeUP'
                    if ("`gamrange'"!="full") local mtix -1(.1)1
                    twoway ///
                    (line f`par'_mix x`par'_mix, sort) ///
                    (line f`par'_obs x`par'_obs , sort), ///
                    legend(off) xtitle(Risk Preference Parameter) xmticks(`mtix') ytitle(Density) ///
                    title(A: Risk Preference Parameter)
                }
                if ("`par'"=="lam") {
                    local rangeUP=10
                    twoway ///
                    (line f`par'_mix x`par'_mix ///
                    if x`par'_mix>`rangeLO' & x`par'_mix<`rangeUP', sort) ///
                    (line f`par'_obs x`par'_obs ///
                    if x`par'_obs>`rangeLO' & x`par'_obs<`rangeUP', sort), ///
                    legend(off) xtitle(Loss Aversion Parameter) ytitle(Density) ///
                    title(B: Loss Aversion Parameter)
                }
                if ("`par'"=="rho") {
                    qui su x`par'_mix
                    local rangeUP=r(max)
                    twoway ///
                    (line f`par'_mix x`par'_mix ///
                    if x`par'_mix>`rangeLO' & x`par'_mix<`rangeUP', sort) ///
                    (line f`par'_obs x`par'_obs ///
                    if x`par'_obs>`rangeLO' & x`par'_obs<`rangeUP', sort), ///
                    legend(off) xtitle(Uncertainty Resolution Preference Parameter) ytitle(Density) ///
                    title(C: Uncertainty Resolution Preference Parameter)
                }
                if ("`par'"=="omg") {
                    qui su f`par'_obs
                    local maxdens=r(max)
                    twoway ///
                    (line f`par'_mix x`par'_mix ///
                    if f`par'_mix<1.1*`maxdens', sort) ///
                    (line f`par'_obs x`par'_obs ///
                    if x`par'_obs>`rangeLO' & x`par'_obs<`rangeUP', sort), ///
                    legend(off) xtitle(Random Choice Probability Parameter) ytitle(Density) ///
                    title(D: Random Choice Probability Parameter)
                }
                local ++j
                qui graph_export_pdf `outdirname'/f_`par'_obs_vs_total, replace
            }

            set scheme s1mono
            local j=1
            foreach par in `parameterlist' {
                
                local rangeLO=rangeLO`par'[1]
                local rangeUP=rangeUP`par'[1]
                
                if ("`par'"=="gam") {
                    local mtix `rangeLO'(.01)`rangeUP'
                    if ("`gamrange'"!="full") local mtix -1(.1)1
                    twoway ///
                    (line f`par'_mix x`par'_mix, sort), ///
                    legend(off) xtitle(Risk Preference Parameter) xmticks(`mtix') ytitle(Density) ///
                    title(A: Risk Preference Parameter)
                }
                if ("`par'"=="lam") {
                    local rangeUP=10
                    twoway ///
                    (line f`par'_mix x`par'_mix ///
                    if x`par'_mix>`rangeLO' & x`par'_mix<`rangeUP', sort), ///
                    legend(off) xtitle(Loss Aversion Parameter) ytitle(Density) ///
                    title(B: Loss Aversion Parameter)
                }
                if ("`par'"=="rho") {
                    qui su x`par'_mix
                    local rangeUP=r(max)
                    twoway ///
                    (line f`par'_mix x`par'_mix ///
                    if x`par'_mix>`rangeLO' & x`par'_mix<`rangeUP', sort), ///
                    legend(off) xtitle(Uncertainty Resolution Preference Parameter) ytitle(Density) ///
                    title(C: Uncertainty Resolution Preference Parameter)
                }
                if ("`par'"=="omg") {
                    qui su f`par'_mix
                    local maxdens=r(max)
                    twoway ///
                    (line f`par'_mix x`par'_mix ///
                    if f`par'_mix<1.1*`maxdens', sort), ///
                    legend(off) xtitle(Random Choice Probability Parameter) ytitle(Density) ///
                    title(D: Random Choice Probability Parameter)
                }
                local ++j
                qui graph_export_pdf `outdirname'/f_`par'_total, replace
            }
            
            // 3 PLOT RAW INDIVIDUAL-LEVEL CHOICES
            if (`globalcounter'==0) {
                // do these last two steps only in first round
                qui u ../../data/formatted/txt/`datatype'-f/`datatype', clear
                qui replace pHI=pHI+.01 if (pHI==.5 | pHI==1) & sheet==2
                local orderkeep = "nohhm quest sheet pHI choice incentive0 incentive1 sex agecat_exp3 agecat_exp4 agecat_exp5 agecat_exp6 educ_exp34 educ_exp5 educ_exp6"
                order `orderkeep'
                keep `orderkeep'
                
                local indpaper=0
                foreach indraw in `individualslist' {
                    local ++indpaper
                    twoway (scatter pHI quest if choice==0 & nohhmem==`indraw', msymbol(oh) msize(vlarge) mcolor(black)) ///
                    (scatter pHI quest if choice==1 & nohhmem==`indraw', msymbol(D) msize(large) mcolor(gs5) ), ///
                    xlabel(1(1)7) xscale(range(0.5,7.5)) scheme(s1mono) legend(label(1 "Choice A") label(2 "Choice B")) ///
                    ylabel(0(.25)1) xscale(range(0,1.01)) ///
                    xtitle("Payoff Configuration") ytitle("Probability for the High Outcome") title(A: Choices)
                    qui graph_export_pdf `outdirname'/../../rawchoices/choices`indpaper', replace
                    
                    if `indpaper'==1 {
                        local panelnumber A
                    }
                    else if `indpaper'==2 {
                        local panelnumber B
                    }
                    else if `indpaper'==3 {
                        local panelnumber C
                    }
                    else if `indpaper'==4 {
                        local panelnumber D
                    }
                    else if `indpaper'==5 {
                        local panelnumber E
                    }
                    else {
                        local panelnumber XXX
                    }
                    twoway (scatter pHI quest if choice==0 & nohhmem==`indraw', msymbol(oh) msize(vlarge) mcolor(black)) ///
                    (scatter pHI quest if choice==1 & nohhmem==`indraw', msymbol(D) msize(large) mcolor(gs5) ), ///
                    xlabel(1(1)7) xscale(range(0.5,7.5)) scheme(s1mono) legend(label(1 "Choice A") label(2 "Choice B")) ///
                    ylabel(0(.25)1) xscale(range(0,1.01)) ///
                    xtitle("Payoff Configuration") ytitle("Probability for the High Outcome") title(`panelnumber': Choices of Respondent R`indpaper')
                    qui graph_export_pdf `outdirname'/../../rawchoices/choices`indpaper'`panelnumber', replace
                }
                local ++globalcounter
            }
        }
    }
}


capture log close
scons_returncode

