local thisdofilename meanswitch_graphs
include ../lib_local/header

use "`formatteddatadir'/exp_dhs_aer_meanswitch.dta", clear

// barcharts with confidence intervals
preserve
keep nohhmem switchperc_lo*
reshape long switchperc_lo, i(nohhmem) j(screen)

collapse ///
  (mean) PC = switchperc_lo ///
  (sd) sdPC = switchperc_lo ///
  (count) n = switchperc_lo, ///
  by(screen)

local options "xscale(range(1(1)7)) xlabel(1 "PC1" 2 "PC2" 3 "PC3" 4 "PC4" 5 "PC5" 6 "PC6" 7 "PC7") yscale(range(0(10)80)) ylabel(0(20)80) xtitle("") legend(off)"

// graph settings
set scheme s1mono

gen hiPC = PC + invttail(n-1,0.025)*(sdPC / sqrt(n))
gen loPC = PC - invttail(n-1,0.025)*(sdPC / sqrt(n))

twoway (bar PC screen, barwidth(0.8) fcolor(gs12) lcolor(gs8)) ///
  (rcap loPC hiPC screen, color(black)), `options'
graph_export_pdf "`graphicsdir_prefhet'/switchperc", replace
restore

// run separately by treatment
foreach i in 0 1 3 {
    preserve
    keep if incentive`i' == 1
    keep nohhmem switchperc_lo*
    reshape long switchperc_lo, i(nohhmem) j(screen)
    
    collapse ///
    (mean) PC = switchperc_lo ///
    (sd) sdPC = switchperc_lo ///
    (count) n = switchperc_lo, ///
    by(screen)
    
    // graph settings, paper
    set scheme s1mono
    
    gen hiPC = PC + invttail(n-1,0.025)*(sdPC / sqrt(n))
    gen loPC = PC - invttail(n-1,0.025)*(sdPC / sqrt(n))
    
    twoway (bar PC screen, barwidth(0.8) fcolor(gs12) lcolor(gs8)) ///
    (rcap loPC hiPC screen, color(black)), `options'
    graph_export_pdf "`graphicsdir_prefhet'/switchperc`i'", replace
    restore
}


// Switch points by order of payoff configuration

// Make variable with reordered payoff configuration
// Order 0: (2; 7; 3; 6; 1; 4; 5)
// Order 1: (1; 4; 5; 2; 6; 3; 7)
forvalues i = 1/7 {
    gen switchperc_lo_order`i' =.
}
foreach i in switchperc_lo {
    replace `i'_order1 = `i'5 if order2 == 0
    replace `i'_order2 = `i'1 if order2 == 0
    replace `i'_order3 = `i'3 if order2 == 0
    replace `i'_order4 = `i'6 if order2 == 0
    replace `i'_order5 = `i'7 if order2 == 0
    replace `i'_order6 = `i'4 if order2 == 0
    replace `i'_order7 = `i'2 if order2 == 0
    replace `i'_order1 = `i'1 if order2 == 1
    replace `i'_order2 = `i'4 if order2 == 1
    replace `i'_order3 = `i'6 if order2 == 1
    replace `i'_order4 = `i'2 if order2 == 1
    replace `i'_order5 = `i'3 if order2 == 1
    replace `i'_order6 = `i'5 if order2 == 1
    replace `i'_order7 = `i'7 if order2 == 1
}
keep nohhmem switchperc_lo_order*
reshape long switchperc_lo_order, i(nohhmem) j(order)

collapse ///
  (mean) PC = switchperc_lo_order ///
  (sd) sdPC = switchperc_lo_order ///
  (count) n = switchperc_lo_order, ///
  by(order)

local options "xscale(range(1(1)7)) xlabel(1(1)7) yscale(range(0(10)80)) ylabel(0(20)80, grid) xtitle("Order") legend(off)"

// graph settings, paper
set scheme s1mono

gen hiPC = PC + invttail(n-1,0.025)*(sdPC / sqrt(n))
gen loPC = PC - invttail(n-1,0.025)*(sdPC / sqrt(n))

twoway (bar PC order, barwidth(0.8) fcolor(gs12) lcolor(gs8)) ///
  (rcap loPC hiPC order, color(black)), `options'
graph_export_pdf "`graphicsdir_prefhet'/switchperc_order", replace


log close
scons_returncode

