local thisdofilename prepdata
include ../lib_local/header
//set trace on
//pause on
// assumptions:
// gam unrestricted or in (-1,1) if crra is in model expression
// lam, rho >0
// omg in (0,1)
// tau not supported to be heterogeneous

local individualslist = "97 193 370 1589 1615"

// values used to plot the parameter distributions
local rangeLOgam=-.98
// endogenous in case gamma is unrestricted
local rangeUPgam= .98
// endogenous in case gamma is unrestricted
local rangeLOlam= 0.1
local rangeUPlam= 40
local rangeLOrho= 0.1
local rangeUPrho= 3
local rangeLOomg= 0.001
local rangeUPomg= 0.999

tempfile temp temp1 temp2 DataPar
tempvar ftemp xtemp


foreach model in ca la pt ptcrra kp {
    
    // translate models into parameter configurations
    if (regexm("`model'","ca")) {
        local parameterlist "gam omg"
    }
    else if (regexm("`model'","la") | regexm("`model'","pt")) {
        local parameterlist "gam lam omg"
    }
    else if (regexm("`model'","kp")) {
        local parameterlist "gam lam rho omg"
    }
    else {
        di "Error: Wrong model specified -- `model'"
        error(1)
    }
    // implement [-1,1] restriction on \gamma in case of crra
    if regexm("`model'","crra")==1 {
        local gamrange "restr"
    }
    else {
        local gamrange "full"
    }
    local datatype = "demog"
    foreach fullsimple in f s {
        foreach Sigma in restr free {
            
            // debugging info
            di " "
            di " "
            di " "
            di "`model'-`datatype'-`fullsimple'-`Sigma'"
            di "All incentive treatments standardised"
            di "to have the same distribution"
            di " "
            
            // reset counter variable and regressor lists for estimates loading
            local j=0
            local corrlist=" "
            local coefflist=" "
            
            foreach par in `parameterlist' {
                
                // take care of nonsensical naming...
                if ("`par'"=="gam") {
                    local longpar `par'ma
                }
                else if ("`par'"=="lam") {
                    local longpar `par'bda
                }
                else if ("`par'"=="rho" | "`par'"=="tau") {
                    local longpar `par'
                }
                else if ("`par'"=="omg") {
                    local longpar omega
                }
                else {
                    di "Error: Wrong parameter specified: -- `par'"
                    error(1)
                }
                capture infile B_`par'_`fullsimple' using ///
                "../main_estimation/`model'-`datatype'-`fullsimple'/output_`Sigma'/`longpar'.txt", clear

                // step out par-loop in case model has not been estimated
                if (_rc!=0) {
                    local ReturnCode=1
                    continue, break
                }
                else {
                    local ReturnCode=0
                }
                // load estimates of random coefficient parameters
                qui gen id=_n
                if (`j'!=0) {
                    merge id using `temp', sort
                    capture drop _m
                }
                else {
                    local j=1
                }
                qui save `temp', replace
                local corrlist="`corrlist' corr_`par'"
                local coefflist="`coefflist' B_`par'_`fullsimple'"
            }
            // step out Sigma-loop in case model has not been estimated
            if `ReturnCode'==1 {
                continue
            }
            // add estimates of incentive1 treatment (multiplicative)
            qui infile B_in1_`fullsimple' using ///
            "../main_estimation/`model'-`datatype'-`fullsimple'/output_`Sigma'/incentive1.txt", clear
            local coefflist="`coefflist' B_in1_`fullsimple'"
            qui gen id=_n
            merge id using `temp', sort
            drop _m
            qui save `temp', replace
            
            // add correlation matrix
            qui infile `corrlist' using ///
            "../main_estimation/`model'-`datatype'-`fullsimple'/output_`Sigma'/corr.txt", clear
            qui gen id=_n
            merge id using `temp', sort
            drop _m
            order `coefflist' `corrlist'
            qui save `temp', replace
            
            // add regressor names to parameter estimates
            u `formatteddatadir_txt'/`datatype'-f/`datatype', clear
            label data
            keep X_*
            qui duplicates drop
            qui gen id=_n
            merge id using `temp', sort
            drop _m
            qui save `temp', replace
            
            // add original data to regressor names and estimates
            qui u `formatteddatadir_txt'/`datatype'-f/`datatype', clear
            label data
            drop X_*
            qui duplicates drop nohhmem, force
            qui gen id=_n
            merge id using `temp', sort
            drop _m
            
            // calculate group-wise parameter averages
            // need to work on the untransformed parameters -> messy
            local parcount=1
            
            foreach par in `parameterlist' {
                local j=1
                local regname=X_`par'_`fullsimple'[`j']
                
                // do this for each parameter until list is empty
                while "`regname'">" " {
                    
                    // do not take into account difference due to
                    // hypothetical treatment in case standardisation is assumed
                    if "`regname'"=="incentive0" {
                        local j=`j'+1
                        local regname=X_`par'_`fullsimple'[`j']
                        continue
                    }
                    if ("`par'"=="gam" & "`gamrange'"=="full") {
                        if `j'==1 {
                            qui gen double `par'ind=B_`par'_`fullsimple'[1]
                        }
                        else {
                            qui replace `par'ind=`par'ind ///
                            +`regname'*B_`par'_`fullsimple'[`j']
                        }
                    }
                    if ("`par'"=="gam" & "`gamrange'"!="full") {
                        if `j'==1 {
                            qui gen double `par'ind=logit(B_`par'_`fullsimple'[1]/2+.5)
                        }
                        else {
                            qui replace `par'ind=`par'ind ///
                            +logit((`regname'*B_`par'_`fullsimple'[`j'] ///
                            +B_`par'_`fullsimple'[1])/2+.5) ///
                            -logit(B_`par'_`fullsimple'[1]/2+.5)
                        }
                    }
                    if ("`par'"=="lam" | "`par'"=="rho") {
                        if `j'==1 {
                            qui gen double `par'ind=log(B_`par'_`fullsimple'[1])
                        }
                        else {
                            if ("`regname'" != "bNEG") {
                                qui replace `par'ind=`par'ind ///
                                +log(`regname'*B_`par'_`fullsimple'[`j'] ///
                                +B_`par'_`fullsimple'[1]) ///
                                -log(B_`par'_`fullsimple'[1])
                            }
                        }
                    }
                    if ("`par'"=="omg") {
                        if `j'==1 {
                            qui gen double `par'ind=logit(B_`par'_`fullsimple'[1])
                        }
                        else {
                            qui replace `par'ind=`par'ind ///
                            +logit(`regname'*B_`par'_`fullsimple'[`j'] ///
                            +B_`par'_`fullsimple'[1]) ///
                            -logit(B_`par'_`fullsimple'[1])
                        }
                    }
                    local ++j
                    local regname=X_`par'_`fullsimple'[`j']
                }
                // transform back to correct scale
                if ("`par'"=="gam" & "`gamrange'"!="full") {
                    qui replace `par'ind=(invlogit(`par'ind)-.5)*2
                }
                if ("`par'"=="lam" | "`par'"=="rho") {
                    qui replace `par'ind=exp(`par'ind)
                }
                if ("`par'"=="omg") {
                    qui replace `par'ind= invlogit(`par'ind)
                }
                local ++parcount
            }
            qui save `DataPar', replace
            erase `temp'
            
            // generate unique values of group-wise parameter medians, means and weights
            local j=1
            foreach par in `parameterlist' {
                u `DataPar', clear
                local sd=corr_`par'[`j']
                qui su `par'ind
                local N=r(N)
                qui duplicates tag `par'ind, gen(`par'ind_grp_weights)
                qui replace `par'ind_grp_weights=(`par'ind_grp_weights+1)/`N'
                keep `par'ind `par'ind_grp_weights
                qui duplicates drop `par'ind, force
                rename `par'ind `par'ind_grp_med
                
                // means have to be simulated, later
                qui gen double `par'ind_grp_avg=.
                qui gen id=_n
                egen `par'ind_grp_n=max(id)
                qui replace `par'ind_grp_n=. if _n>1
                order id `par'ind_grp_med `par'ind_grp_avg `par'ind_grp_weights `par'ind_grp_n
                label var `par'ind_grp_med `"Group-wise Median of `par' `qualifier'"'
                label var `par'ind_grp_avg `"Group-wise Mean of `par' `qualifier'"'
                label var `par'ind_grp_weights `"Weights for group-wise Statistics of `par' `qualifier'"'
                label var `par'ind_grp_n `"Number of groups `qualifier'"'
                
                // add averages of group-wise parameters
                // loop over number of unique values
                local N=`par'ind_grp_n[1]
                forvalues k=1/`N' {
                    
                    // set parameter of the current distribution
                    local med =`par'ind_grp_med[`k']
                    
                    // risk preference parameter
                    if ("`par'"=="gam" & "`gamrange'"=="full") {
                        qui replace `par'ind_grp_avg=`par'ind_grp_med[`k'] in `k'
                    }
                    if ("`par'"=="gam" & "`gamrange'"!="full") {
                        twoway__function_gen `ftemp' = 2/((1-x^2)*(2*_pi)^.5*`sd')* ///
                        exp(-.5*((logit(x/2+.5)-logit(`med'/2+.5))/`sd')^2), ///
                        n(1000) xis(x) range(.00001 .99999) ///
                        gen(`ftemp' `xtemp', replace)
                        qui replace `xtemp'=`ftemp'*`xtemp'
                        qui su `xtemp'
                        qui replace `par'ind_grp_avg = r(mean) in `k'
                    }
                    // loss aversion and uncertainty resolution preference parameters
                    if ("`par'"=="lam" | "`par'"=="rho" ) {
                        qui replace `par'ind_grp_avg = exp(log(`par'ind_grp_med[`k'])+`sd'^2/2) in `k'
                    }
                    // random choice probability parameter
                    if ("`par'"=="omg" ) {
                        twoway__function_gen `ftemp' = 1/(x*(1-x)*(2*_pi)^.5*`sd')* ///
                        exp(-.5*((logit(x)-logit(`med'))/`sd')^2), ///
                        n(1000) xis(x) range(.00001 .99999) ///
                        gen(`ftemp' `xtemp', replace)
                        qui replace `xtemp'=`ftemp'*`xtemp'
                        qui su `xtemp'
                        qui replace `par'ind_grp_avg = r(mean) in `k'
                    }
                }
                // drop temporary variables, make sure no overhang observations
                capture drop `ftemp' `xtemp'
                egen `xtemp'=robs(_all)
                qui drop if `xtemp'==0
                drop `xtemp'
                
                if (`j'==1) {
                    qui save `temp1', replace
                }
                else {
                    qui save `temp2', replace
                    u `temp1'
                    merge id using `temp2', sort
                    drop _m
                    qui save `temp1', replace
                }
                local ++j
            }
            u `DataPar'
            merge id using `temp1', sort
            drop _m
            qui save `DataPar', replace
            capture erase `temp1' `temp2'
            
            // add individual-level (conditional) parameter distributions
            foreach ind in `individualslist' {
                local parcount=1
                foreach par in `parameterlist' {
                    
                    // set incentive0 and incentive1 coefficients for this particular individual
                    u `DataPar', clear
                    local beta_incentive1=B_in1_`fullsimple'[`parcount']
                    
                    // extract beta_incentive0
                    local i=1
                    local regname=X_`par'_`fullsimple'[`i']
                    while "`regname'">" " {
                        if "`regname'"=="incentive0" {
                            local beta_incentive0=B_`par'_`fullsimple'[`i']
                            local i=0
                            continue, break
                        }
                        local ++i
                        local regname=X_`par'_`fullsimple'[`i']
                    }
                    if (`i'!=0) {
                        di "Error: Could not load beta_incentive0 parameter for individual-specific parameters"
                        error(1)
                    }
                    capture insheet x`par'_`ind' f`par'_`ind' dummy using ///
                    "../main_estimation/`model'-`datatype'-`fullsimple'/outputind_`Sigma'/`ind'_`par'_f.csv", ///
                    delimiter(";") clear
                    
                    // step out in case individual does not exist among estimations
                    if (_rc!=0) {
                        continue, break
                    }
                    // dummy is just the (;) delimiter after the last element
                    drop dummy
                    
                    // safeguard against Fortran outputting very small values such
                    // as .33744-100 (no "E"), leading STATA to read them as strings
                    ds, has(type string)
                    foreach variable in `r(varlist)' {
                        qui replace `variable'="0.0" if regexm(`variable',"[0-9]-[0-9][0-9][0-9]$")==1
                        destring `variable', replace
                    }
                    // merge individual-level parameters in right order
                    sort x`par'_`ind'
                    qui gen id=_n
                    order id
                    if (`j'==1) {
                        qui save `temp1', replace
                    }
                    else {
                        qui save `temp2', replace
                        u `temp1'
                        qui merge id using `temp2', sort
                        drop _m
                        qui save `temp1', replace
                    }
                    local ++j
                }
            }
            // merge to remaining data
            u `DataPar'
            merge id using `temp1', sort
            qui replace nohhmem=-_n if missing(nohhmem)
            drop _m
            qui save `DataPar', replace
            
            // generate averages of parameters for overall distributions
            keep corr_* *ind
            local j=1
            foreach par in `parameterlist' {
                if ("`par'"=="gam" & "`gamrange'"=="full") {
                    egen `par'avg=mean(`par'ind)
                }
                if ("`par'"=="gam" & "`gamrange'"!="full") {
                    egen `par'avg =mean(logit(`par'ind/2 + .5))
                    qui replace `par'avg =(invlogit(`par'avg)-.5)*2
                }
                if ("`par'"=="lam" | "`par'"=="rho") {
                    egen `par'avg=mean(log(`par'ind))
                    qui replace `par'avg=exp(`par'avg)
                }
                if ("`par'"=="omg") {
                    egen `par'avg=mean(logit(`par'ind))
                    qui replace `par'avg=invlogit(`par'avg)
                }
                local j=`j'+1
                qui replace `par'avg=. if _n>1
            }
            keep *avg
            qui gen id=_n
            qui save `temp',replace
            u `DataPar'
            merge id using `temp', sort
            drop _m id
            
            // generate values used to plot the parameter distributions
            // first: mixture of observed and unobserved het.
            // second: kernel density estimates of observed het.
            if ("`gamrange'"=="full") {
                // need frequency weights...
                tempvar tempweight
                qui su nohhmem
                qui gen int `tempweight'=gamind_grp_weights*r(N)
                qui su gamind_grp_avg [fweight=`tempweight']
                qui gen rangeLOgam=floor((r(mean)-4*corr_gam[1])*100)/100 in 1
                qui gen rangeUPgam= ceil((r(mean)+4*corr_gam[1])*100)/100 in 1
                drop `tempweight'
            }
            else {
                qui gen rangeLOgam=`rangeLOgam' in 1
                qui gen rangeUPgam=`rangeUPgam' in 1
            }
            qui gen rangeLOlam=`rangeLOlam' in 1
            qui gen rangeUPlam=`rangeUPlam' in 1
            qui gen rangeLOrho=`rangeLOrho' in 1
            qui gen rangeUPrho=`rangeUPrho' in 1
            qui gen rangeLOomg=`rangeLOomg' in 1
            qui gen rangeUPomg=`rangeUPomg' in 1
            
            local j=1
            foreach par in `parameterlist' {
                
                // set values that do not change within each parameter
                local sd=corr_`par'[`j']
                local N=`par'ind_grp_n[1]
                
                local rangeLO=rangeLO`par'[1]
                local rangeUP=rangeUP`par'[1]
                
                // define mixture distributions
                forvalues k=1/`N' {
                    
                    // set parameters of the current contribution to the distribution
                    local med =`par'ind_grp_med[`k']
                    local frac=`par'ind_grp_weights[`k']
                    
                    // generate variable that contains the distribution
                    qui su nohhmem
                    if (r(N)<1000) set obs 1000
                    if (`k'==1) gen f`par'_mix=0
                    
                    // risk preference parameter
                    if ("`par'"=="gam") {
                        if ("`gamrange'"=="full") {
                            twoway__function_gen `ftemp' = `frac'*normalden(x,`med',`sd'), ///
                            n(1000) range(`rangeLO' `rangeUP') xis(x) ///
                            gen(`ftemp' x`par'_mix, replace)
                            qui replace f`par'_mix=f`par'_mix+`ftemp'
                        }
                        else {
                            twoway__function_gen `ftemp' = `frac'*2/((1-x^2)*(2*_pi)^.5*`sd')* ///
                            exp(-.5*((logit(x/2+.5)-logit(`med'/2+.5))/`sd')^2), ///
                            n(1000) range(`rangeLO' `rangeUP') xis(x) ///
                            gen(`ftemp' x`par'_mix, replace)
                            qui replace f`par'_mix=f`par'_mix+`ftemp'
                        }
                        if (`k'==`N') {
                            kdensity `par'ind if `par'ind>`rangeLO' & `par'ind<`rangeUP', ///
                            generate(x`par'_obs f`par'_obs) nograph n(1000)
                        }
                    }
                    // loss aversion and uncertainty resolution preference parameters
                    if ("`par'"=="lam" | "`par'"=="rho" ) {
                        twoway__function_gen `ftemp' = `frac'*1/(x*(2*_pi)^.5*`sd')* ///
                        exp(-.5*((log(x)-log(`med'))/`sd')^2), ///
                        n(1000) range(`rangeLO' `rangeUP') xis(x) ///
                        gen(`ftemp' x`par'_mix, replace)
                        qui replace f`par'_mix=f`par'_mix+`ftemp'
                        if (`k'==`N') {
                            kdensity `par'ind if `par'ind>`rangeLO' & `par'ind<`rangeUP', ///
                            generate(x`par'_obs f`par'_obs) nograph n(1000)
                        }
                    }
                    // random choice probability parameter
                    if ("`par'"=="omg" ) {
                        twoway__function_gen `ftemp' = `frac'*1/(x*(1-x)*(2*_pi)^.5*`sd')* ///
                        exp(-.5*((logit(x)-logit(`med'))/`sd')^2), ///
                        n(1000) range(`rangeLO' `rangeUP') xis(x) ///
                        gen(`ftemp' x`par'_mix, replace)
                        qui replace f`par'_mix=f`par'_mix+`ftemp'
                        if (`k'==`N') {
                            kdensity `par'ind if `par'ind>`rangeLO' & `par'ind<`rangeUP', ///
                            generate(x`par'_obs f`par'_obs) nograph n(1000)
                        }
                    }
                }
                local ++j
                
            }
            drop `ftemp'
            qui save `DataPar',replace
            
            // save data, remove unused files
            qui replace nohhmem=. if nohhmem<0
            sort nohhmem
            qui compress
            label data
            local outdirname "`graphicsdir_prefhet'/`model'-`datatype'-`fullsimple'/`Sigma'"
            local outfilename "data-stand"
            di "`outdirname'/`outfilename'"
            capture save `outdirname'/`outfilename', replace
            if (_rc!=0) {
                capture mkdir `outdirname'
                if (_rc!=0) {
                    mkdir "`graphicsdir_prefhet'/`model'-`datatype'-`fullsimple'"
                    mkdir `outdirname'
                }
                qui save `outdirname'/`outfilename'
            }
            capture erase `temp'
            capture erase `temp1'
            capture erase `temp2'
            capture erase `DataPar'
        }
    }
}


capture log close
scons_returncode

