local thisdofilename riskpremia
include ../lib_local/header

// GRAPHS FOR RISK PREMIA
set scheme s1mono

local modelslist kp ca la pt ptcrra
local datatype "demog"
local fullsimple "f"
local freerestr "restr"
local TreatmentStandardise 1

local individualslist "97 370 1615 1589"

tempvar ftemp f_mix_temp x_mix_temp interval integ_hlp integ_hlp_cons integ tempavg


foreach model in `modelslist' {
    
    // translate models into parameter configurations
    if (regexm("`model'","ca")) {
        local parameterlist "gam"
    }
    else if (regexm("`model'","la") | regexm("`model'","pt")) {
        local parameterlist "gam lam"
    }
    else if (regexm("`model'","kp")) {
        local parameterlist "gam lam rho"
    }
    else {
        di "Error: Wrong model specified -- `model'"
        error(1)
    }
    // implement [-1,1] restriction on \gamma in case of crra
    if regexm("`model'","crra")==1 {
        local gamrange "restr"
    }
    else {
        local gamrange "full"
    }
    if (`TreatmentStandardise'==1) {
        local infilename "`model'-`datatype'-`fullsimple'/`freerestr'/data-stand"
    }
    else {
        local infilename "`model'-`datatype'-`fullsimple'/`freerestr'/data"
    }
    u `graphicsdir_prefhet'/`infilename'
    
    // take quantiles from graphs of the distributions
    local j=1
    local keepparameterlist
    foreach par in `parameterlist' {
        
        // set values that do not change within each parameter
        local sd=corr_`par'[`j']
        
        // define mixture distributions
        local N=`par'ind_grp_n[1]
        forvalues k=1/`N' {
            
            // set parameters of the current contribution to the distribution
            local med =`par'ind_grp_med[`k']
            local frac=`par'ind_grp_weights[`k']
            
            // generate variable that contains the distribution
            qui su nohhmem
            if (`k'==1) {
                local R=10000
                capture set obs `R'
                gen `f_mix_temp'=0
            }
            // risk preference parameter
            if ("`par'"=="gam") {
                if ("`gamrange'"=="full") {
                    twoway__function_gen `ftemp' = `frac'*normalden(x,`med',`sd'), ///
                    n(10000) range(-.9 .49) xis(x) ///
                    gen(`ftemp' `x_mix_temp', replace)
                    qui replace `f_mix_temp'=`f_mix_temp'+`ftemp'
                }
                else {
                    twoway__function_gen `ftemp' = `frac'*2/((1-x^2)*(2*_pi)^.5*`sd')* ///
                    exp(-.5*((logit(x/2+.5)-logit(`med'/2+.5))/`sd')^2), ///
                    n(10000) range(-.9999999 .9999999) xis(x) ///
                    gen(`ftemp' `x_mix_temp', replace)
                    qui replace `f_mix_temp'=`f_mix_temp'+`ftemp'
                }
            }
            // loss aversion and uncertainty resolution preference parameters
            if ("`par'"=="lam" | "`par'"=="rho" ) {
                twoway__function_gen `ftemp' = `frac'*1/(x*(2*_pi)^.5*`sd')* ///
                exp(-.5*((log(x)-log(`med'))/`sd')^2), ///
                n(10000) range(.0000001 399) xis(x) ///
                gen(`ftemp' `x_mix_temp', replace)
                qui replace `f_mix_temp'=`f_mix_temp'+`ftemp'
            }
            // random choice probability parameter
            if ("`par'"=="omg" ) {
                twoway__function_gen `ftemp' = `frac'*1/(x*(1-x)*(2*_pi)^.5*`sd')* ///
                exp(-.5*((logit(x)-logit(`med'))/`sd')^2), ///
                n(10000) range(.0000000001 .9999999999) xis(x) ///
                gen(`ftemp' `x_mix_temp', replace)
                qui replace `f_mix_temp'=`f_mix_temp'+`ftemp'
            }
        }
        // calculate cdf by hand, get quantiles
        capture drop `interval'
        gen double `interval'=0
        forvalues i=2/`R' {
            qui replace `interval'=`x_mix_temp'[`i']-`x_mix_temp'[`i'-1] in `i'
        }
        qui gen `integ_hlp'=`interval'*`f_mix_temp'
        // normalize area under graph to one, can matter at indiv. level
        qui egen `integ_hlp_cons'=sum(`integ_hlp')
        gen `integ'=sum(`integ_hlp')/`integ_hlp_cons'[1]
        
        
        forvalues i=1/`R' {
            local counter=`i'
            if (`integ'[`i']>.1) {
                gen `par'_q10=`x_mix_temp'[`i']
                continue, break
            }
        }
        forvalues i=`counter'/`R' {
            if (`integ'[`i']>.5) {
                gen `par'_med=`x_mix_temp'[`i']
                continue, break
            }
        }
        forvalues i=`counter'/`R' {
            if (`integ'[`i']>.9) {
                gen `par'_q90=`x_mix_temp'[`i']
                continue, break
            }
        }
        foreach var in `ftemp' `f_mix_temp' `x_mix_temp' `interval' `integ_hlp' `integ_hlp_cons' `integ' {
            capture drop `var'
        }
        local ++j
        local keepparameterlist "`keepparameterlist' `par'_med `par'_q10 `par'_q90"
        
        // generate individual-level conditional quantiles in single variables
        foreach ind in `individualslist' {
            
            capture drop `interval'
            gen double `interval'=0
            forvalues i=2/1000 {
                qui replace `interval'=x`par'_`ind'[`i']-x`par'_`ind'[`i'-1] in `i'
            }
            qui gen `integ_hlp'=`interval'*f`par'_`ind'
            // normalize area under graph to one, can matter at indiv. level
            qui egen `integ_hlp_cons'=sum(`integ_hlp')
            gen `integ'=sum(`integ_hlp')/`integ_hlp_cons'[1]
            
            forvalues i=1/1000 {
                local counter=`i'
                if (`integ'[`i']>.1) {
                    gen `par'_`ind'_q10=x`par'_`ind'[`i']
                    continue, break
                }
            }
            forvalues i=`counter'/1000 {
                if (`integ'[`i']>.5) {
                    gen `par'_`ind'_med=x`par'_`ind'[`i']
                    continue, break
                }
            }
            forvalues i=`counter'/1000 {
                if (`integ'[`i']>.9) {
                    gen `par'_`ind'_q90=x`par'_`ind'[`i']
                    continue, break
                }
            }
            qui gen `tempavg'=f`par'_`ind'*x`par'_`ind'
            qui egen `par'_avg_`ind'=sum(`tempavg')
            drop `tempavg'
            local keepparameterlist "`keepparameterlist' `par'_`ind'_med `par'_`ind'_q10 `par'_`ind'_q90"
            foreach var in `ftemp' `f_mix_temp' `x_mix_temp' `interval' `integ_hlp' `integ_hlp_cons' `integ' {
                capture drop `var'
            }
        }
    }
    keep nohhmem `keepparameterlist'
    qui keep in 1/1
    qui replace nohhmem=0
    
    
    // add quantiles of individuals
    local indtypelist
    foreach ind in `individualslist' {
        local indtypelist "`indtypelist' `ind'_med `ind'_q10 `ind'_q90"
    }
    // if lam and rho are not in model, generate them
    foreach par in lam rho {
        foreach stat in med q10 q90 {
            capture gen double `par'_`stat'=1
            foreach ind in `individualslist' {
                capture su gam_`ind'_`stat'
                if (_rc==0) {
                    capture gen double `par'_`ind'_`stat'=1
                }
            }
        }
    }
    // values to calculate certainty equivalents
    gen signneg=1
    if ("`model'"=="pt") replace signneg=-1
    
    local BLO1=-15
    local BLO2=65
    local BHI1=25
    local BHI2=25
    local probHI1=.5
    local probHI2=.5
    
    local ALO1=(1-`probHI1')*`BLO1'+`probHI1'*`BHI1'
    local ALO2=(1-`probHI2')*`BLO2'+`probHI2'*`BHI2'
    local AHI1=`ALO1'
    local AHI2=`ALO2'
    local ALT1=0
    local ALT2=0
    
    // generate the certainty equivalents
    foreach par in `parameterlist' {
        foreach inddummy in 0 `individualslist' {
            if (`inddummy'==0) {
                local ind
            }
            else {
                local ind `inddummy'_
            }
            foreach type in med q10 q90 {
                
                forvalues i=1/2 {
                    if (`i'==1) {
                        local lot "lo"
                    }
                    if (`i'==2) {
                        local lot "hi"
                    }
                    // parameters for lotteries to base CE's on
                    gen BLO=`BLO`i''
                    gen BHI=`BHI`i''
                    gen BLT=0
                    gen ALO=`ALO`i''
                    gen AHI=`AHI`i''
                    gen ALT=`ALT`i''
                    gen probHI=`probHI`i''
                    
                    
                    if ("`par'"=="gam") {
                        local gamtype gam_`ind'`type'
                    }
                    else {
                        local gamtype gam_`ind'med
                    }
                    if ("`par'"=="lam") {
                        local lamtype lam_`ind'`type'
                    }
                    else {
                        local lamtype lam_`ind'med
                    }
                    if ("`par'"=="rho") {
                        local rhotype rho_`ind'`type'
                    }
                    else {
                        local rhotype rho_`ind'med
                    }
                    if ("`model'"~="ptcrra") {
                        if ("`model'"=="kp") {
                            forvalues j=0/1 {
                                qui replace BLT=`j'
                                if (`j'==0) {
                                    local res "E"
                                    
                                }
                                if (`j'==1) {
                                    local res "L"
                                }
                                cediff_cara `gamtype' `lamtype' `rhotype' signneg ALO AHI ALT BLO BHI BLT probHI , name(`lot'`ind'`type'`par'`res')
                            }
                        }
                        else {
                            cediff_cara `gamtype' `lamtype' `rhotype' signneg ALO AHI ALT BLO BHI BLT probHI , name(`lot'`ind'`type'`par')
                        }
                    }
                    else {
                        cediff_crra `gamtype' `lamtype' `lamtype' signneg ALO AHI ALT BLO BHI BLT probHI , name(`lot'`ind'`type'`par')
                    }
                    foreach var of varlist A* B* prob* {
                        drop `var'
                    }
                }
            }
        }
    }
    di "`reshapelistKP'"
    di "`reshapelist'"
    local reshapelistKP "`reshapelistKP' CE`lot'`ind'`type'`par'"
    
    // reshaping depends on whether early/late resolution matters
    if ("`model'"=="kp") {
        local KP "KP"
        unab vars : *L
        local stubs : subinstr local vars "L" "", all
        reshape long `stubs', i(nohhmem) j(`KP') string
    }
    else {
        local KP
    }
    unab vars : *gam
    local stubs : subinstr local vars "gam" "", all
    reshape long `stubs', i(nohhmem `KP') j(PAR) string
    reshape long CElo CEhi, i(nohhmem `KP' PAR) j(QUANTILE) string
    
    // reformat individual things
    capture label drop nohhmemval
    label value nohhmem nohhmemval
    local indpaper=1
    // need extra variable to get right order for graphs
    gen nohhmempaper=0
    capture label drop nohhmempaperval
    label value nohhmempaper nohhmempaperval
    foreach indraw in `individualslist' {
        qui replace nohhmem=`indraw' if regexm(QUANTILE,"^`indraw'_")
        qui replace nohhmempaper=`indpaper' if nohhmem==`indraw'
        qui replace QUANTILE=regexr(QUANTILE,"^`indraw'_","")
        
        label define nohhmemval `indraw' "Ind. `indpaper'", add
        label define nohhmempaperval `indpaper' "Ind. `indpaper'", add
        local ++indpaper
    }
    // use risk premia, not certainty equivalents
    gen RPlo=-CElo
    gen RPhi=-CEhi
    drop CElo CEhi
    
    // graphs depends on whether timing of uncertainty res. is an issue
    if ("`model'"=="kp") {
        sort nohhmem PAR KP QUANTILE
        order nohhmem PAR KP QUANTILE RPlo RPhi
        qui su nohhmem
        local N=r(N)
        forvalues i=1/`N' {
            if (nohhmem[`i']==0 & QUANTILE[`i']=="med" & KP[`i']=="E") {
                local RPmedloE=RPlo[`i']
                local RPmedhiE=RPhi[`i']
            }
            if (nohhmem[`i']==0 & QUANTILE[`i']=="med" & KP[`i']=="L") {
                local RPmedloL=RPlo[`i']
                local RPmedhiL=RPhi[`i']
            }
        }
        foreach res in E L {
            forvalues i=1/2 {
                preserve
                // set names for graphs, titles, etc
                if (`i'==1) {
                    local lot "lo"
                }
                if (`i'==2) {
                    local lot "hi"
                    }
                if ("`res'"=="E") {
                    local restit="Early Res."
                }
                if ("`res'"=="L") {
                    local restit="Late Res."
                }
                
                local ytit="Risk Premium"
              
                if ("`lot'`res'"=="hiE") local panel A
                if ("`lot'`res'"=="loE") local panel B
                if ("`lot'`res'"=="hiL") local panel C
                if ("`lot'`res'"=="loL") local panel D
                
                reshape wide RPhi RPlo, i(nohhmem PAR KP) j(QUANTILE) string
                sum  RP`lot'med if KP=="`res'" & nohhmem==0
                local med `r(mean)'
                encode PAR, gen(par)
            
                tw (rcap RP`lot'q10 RP`lot'q90 par if nohhmem==0 & KP=="`res'", ///
                    lcolor(black) lwidth(thick) msize(huge)) ///
                    (function y=`med', range(0.5 3.5)), ///
                    xlabel(1 "gam" 2 "lam" 3 "rho") xscale(range(0.5(1)3.5)) ///
                    yscale(range(-20 20)) ylabel(-20(5)20) ytitle(`ytit')  ///
                    title("`panel': Risk Premium of (`BHI`i'',`BLO`i'',`probHI`i'',`restit')") ///
                    legend(off) 
                graph_export_pdf `graphicsdir_prefhet'/`model'-`datatype'-`fullsimple'/`freerestr'/RP`lot'`res', replace
                restore
            }
        }
    } 
    else {
                     
        sort nohhmem PAR QUANTILE
        order nohhmem PAR QUANTILE RPlo RPhi
        qui su nohhmem
        local N=r(N)
        forvalues i=1/`N' {
            if (QUANTILE[`i']=="med") {
                local RPmedlo=RPlo[`i']
                local RPmedhi=RPhi[`i']
            }
        }
        forvalues i=1/2 {
            preserve 

            if (`i'==1) {
                local lot "lo"
            }
            if (`i'==2) {
                local lot "hi"
            }
            local linep solid
            
            local ytit="Risk Premium"
            
            reshape wide RPhi RPlo, i(nohhmem PAR) j(QUANTILE) string
            sum  RP`lot'med if nohhmem==0 
            local med `r(mean)'
            disp `med'
            encode PAR, gen(par)
            
            tw (rcap RP`lot'q10 RP`lot'q90 par if nohhmem==0, ///
                legend(off) lcolor(black) lwidth(thick) msize(huge)) ///
                (function y=`med', range(0.5 2.5)), ///
                xlabel(1 "gam" 2 "lam") xscale(range(0.5(1)2.5)) ///
                yscale(range(-20 20)) ylabel(-20(5)20) ytitle(`ytit')  ///
                title("Risk Premium of (`BHI`i'',`BLO`i''`probHI`i'')") 
            graph_export_pdf `graphicsdir_prefhet'/`model'-`datatype'-`fullsimple'/`freerestr'/RP`lot', replace
            
            restore
        }
    }
    save `graphicsdir_prefhet'/`model'-`datatype'-`fullsimple'/`freerestr'/rpgraphdata, replace
}


// COMPARISONS ACROSS MODELS

// graphs
tempvar temp
local j=1
foreach model in `modelslist' {
    
    u `graphicsdir_prefhet'/`model'-`datatype'-`fullsimple'/`freerestr'/rpgraphdata
    
    foreach var of varlist _all {
        if ("`var'"~="nohhmem" & "`var'"~="nohhmempaper" & "`var'"~="PAR" & "`var'"~="KP" & "`var'"~="QUANTILE") {
            rename `var' `var'`model'
            if (`j'==1) local reshapelist "`reshapelist' `var'"
        }
    }
    cap li KP
    if (_rc!=0) gen KP="E"
    if (`j'==1) {
        local file `graphicsdir_prefhet'/rpgraphjoint/rpgraphdatajoint
        capture save `file', replace
        if (_rc!=0) {
            mkdir `graphicsdir_prefhet'/rpgraphjoint
            qui save `file'
        }
    }
    else {
        drop nohhmempaper
        qui save `temp', replace
        qui u `file'
        qui merge nohhmem PAR KP QUANTILE using `temp', sort
        erase `temp'.dta
        drop _m
        qui save `file', replace
    }
    local j=2
}
reshape long `reshapelist', i(nohhmem nohhmempaper PAR KP QUANTILE) j(model) string
drop if RPlo==.

qui replace KP="late" if KP=="L"
qui replace KP="early" if KP=="E"
qui su nohhmem
local N=r(N)
forvalues i=1/`N' {
    if (model[`i']=="kp") qui replace model="kp-"+KP in `i'
}
drop KP
order nohhmempaper PAR QUANTILE model RPhi RPlo gam_med lam_med rho_med gam_q10 lam_q10 rho_q10 gam_q90 lam_q90 rho_q90
sort nohhmempaper PAR QUANTILE model
qui save `file', replace

forvalues i=1/`N' {
    if (nohhmem[`i']==0 & QUANTILE[`i']=="med" & model[`i']=="kp-early") {
        local RPmedlo=RPlo[`i']
        local RPmedhi=RPhi[`i']
    }
}

forvalues i=1/2 {
    
    if (`i'==1) {
        local lot "lo"
    }
    if (`i'==2) {
        local lot "hi"
    }
    local ytit="Risk Premium"
    foreach par in lam gam {
        preserve   

        if ("`lot'"=="hi" & "`par'"=="gam") {
            local panel "A"
        }
        if ("`lot'"=="lo" & "`par'"=="gam") {
            local panel "B"
        }
         if ("`lot'"=="hi" & "`par'"=="lam") {
            local panel "C"
        }
           if ("`lot'"=="lo" & "`par'"=="lam") {
            local panel "D"
        }        
        
        reshape wide RPhi RPlo, i(nohhmem PAR model) j(QUANTILE) string
        sum  RP`lot'med if nohhmem==0 & PAR=="`par'"
        local med `r(mean)'
        disp `med'
        encode model, gen(mod)
        drop if mod==2 | mod==3 // drop KP-models
         recode mod (4=2) (5=3) (6=4)

        tw (rcap RP`lot'q10 RP`lot'q90 mod if nohhmem==0 & PAR=="`par'" , ///
            legend(off) lcolor(black) lwidth(thick) msize(huge)) ///
            (scatter RP`lot'med mod if nohhmem==0 & PAR=="`par'", ///
             msize(large) mcolor(black)  ) /// 
            (function y=`med', range(0.5 4.5)), ///
            xlabel(1 "ca" 2 "la" 3 "pt" 4 "ptcrra") xscale(range(0.5(1)2.5)) ///
               yscale(range(-20 20)) ylabel(-20(5)20) ytitle(model)  ///
            title("`panel': Risk Premium of ( `BHI`i'',`BLO`i'',`probHI`i'' ), `par'")
        graph_export_pdf `graphicsdir_prefhet'/rpgraphjoint/RP`lot'`par', replace    

        restore
    }
    
}


// tables
gen str32 model_ref = ""
replace model_ref = "\eqref{EqnU-Expo}" if model == "ca"
replace model_ref = "\eqref{EqnKP-Per2util}--\eqref{Eqnh}, early" if model == "kp-early"
replace model_ref = "\eqref{EqnKP-Per2util}--\eqref{Eqnh}, late" if model == "kp-late"
replace model_ref = "\eqref{EqnU-LA}" if model == "la"
replace model_ref = "\eqref{EqnU-PT}" if model == "pt"
replace model_ref = "\eqref{EqnU-PT-power}" if model == "ptcrra"

gen int model_sort = .
replace model_sort = 3 if model == "ca"
replace model_sort = 1 if model == "kp-early"
replace model_sort = 2 if model == "kp-late"
replace model_sort = 4 if model == "la"
replace model_sort = 5 if model == "pt"
replace model_sort = 6 if model == "ptcrra"

sort nohhmempaper model_sort QUANTILE PAR
capture log close
qui tab nohhmem
local ntables=r(r)-1

forvalues table=0/`ntables' {
    local counter=1
    local logfile `graphicsdir_prefhet'/../tex/rp-ind`table'-`datatype'-`fullsimple'.tex
    capture erase `logfile'
    
    forvalues j=1/`N' {
        if (nohhmempaper[`j']==`table') {
            if (`table'==0) {
                local ind
            }
            else {
                local ind=nohhmem[`j']
                local ind `ind'_
            }
            qui log using `logfile', append
            if (`counter'==1) {
                di "\begin {tabular} {cccrrrrr}\hline\hline"
                di "PAR & QUANTILE & MODEL & RP $\pi^1$ & RP $\pi^2$ & $\gamma$ & $\lambda$ & $\rho$ \\\hline"
                local ++counter
            }
            foreach var in PAR QUANTILE model_ref {
                di `var'[`j'] "&"
            }
            local gam="gam_`ind'med"
            local lam="lam_`ind'med"
            local rho="rho_`ind'med"
            
            local q=QUANTILE[`j']
            
            if (PAR[`j']=="gam") {
                local gam="gam_`ind'`q'"
            }
            else if (PAR[`j']=="lam") {
                local lam="lam_`ind'`q'"
            }
            else if (PAR[`j']=="rho") {
                local rho="rho_`ind'`q'"
            }
            di %9.2f RPhi[`j'] "&"
            di %9.2f RPlo[`j'] "&"
            di %9.3f `gam'[`j'] "&"
            di %9.3f `lam'[`j'] "&"
            di %9.3f `rho'[`j'] "\\"
            
            qui log close
        }
        if (`j'==`N') {
            qui log using `logfile', append
            di "\hline\hline\end {tabular}"
            qui log close
        }
    }
}

scons_returncode

