local thisdofilename tables
include ../lib_local/header
log close
pause on
set trace off

tempfile temp1 temp2

foreach inctreat in 0 1 3 {
    
    foreach specname in kp-inc`inctreat' {
        
        local model = lower(substr("`specname'", 1, strpos("`specname'", "-") - 1))
        local datatype = "demog-inc`inctreat'"
        
        if ("`model'"=="kp") {
            local ncolumns = 4
            local parset = "gam lam rho omg"
        }
        else if ("`model'"=="ca") {
            local ncolumns = 2
            local parset = "gam omg"
        }
        else {
            local ncolumns = 3
            local parset = "gam lam omg"
        }
        
            
        foreach Sigma in restr free {
            
            foreach fullsimple in f s {
    
                // 1 PREPARE COLUMNS WITH VARIABLE NAMES
                
                // get raw parameter names from all models in the sample
                local n = 0
                foreach par in `parset' {
                    local ++n
                    qui insheet rawname`n' using "`formatteddatadir_txt'/`datatype'-`fullsimple'/varnames_`par'.txt", nonames clear
                    qui gen id=_n
                    order id
                    qui su id
                    local nvars`n'=r(max)
                    if `n'==1 {
                        qui save `temp1', replace
                    }
                    else {
                        qui save `temp2', replace
                        u `temp1'
                        qui merge id using `temp2', sort
                        drop _m
                        qui save `temp1', replace
                    }
                }
                    
                // pick model with the longest list of variables
                local maxnvars=`nvars1'
                local maxnvarsmodel=1
                forvalues n=2/`ncolumns' {
                    if (`nvars`n''>`maxnvars') {
                        local maxnvars=`nvars`n''
                        local maxnvarsmodel=`n'
                    }
                }
                qui gen rawname=rawname`maxnvarsmodel'
                
                // generate long variable names
                qui gen str30 name = ""
                forvalues i=1/`maxnvars' {
                    if rawname[`i']=="constant" qui replace name = "Constant" in `i'
                    if rawname[`i']=="bNEG" qui replace name = "Negative Outcome in B" in `i'
                    if rawname[`i']=="sex" qui replace name = "Female" in `i'
                    if rawname[`i']=="agecat_exp3" qui replace name = "Age 35-44" in `i'
                    if rawname[`i']=="agecat_exp4" qui replace name = "Age 45-54" in `i'
                    if rawname[`i']=="agecat_exp5" qui replace name = "Age 55-64" in `i'
                    if rawname[`i']=="agecat_exp6" qui replace name = "Age 65+" in `i'
                    if rawname[`i']=="educ_exp34" qui replace name = "Hi Sec Educ / Int Voc Train" in `i'
                    if rawname[`i']=="educ_exp5" qui replace name = "Higher Voc Train" in `i'
                    if rawname[`i']=="educ_exp6" qui replace name = "University" in `i'
                    if rawname[`i']=="ninchhcat2_exp3" qui replace name = "Income EUR 22k-40k" in `i'
                    if rawname[`i']=="ninchhcat2_exp4" qui replace name = "Income EUR 40k+" in `i'
                    if rawname[`i']=="assetd2" qui replace name = "Wealth EUR 10k-50k" in `i'
                    if rawname[`i']=="assetd3" qui replace name = "Wealth EUR 51k-200k" in `i'
                    if rawname[`i']=="assetd4" qui replace name = "Wealth EUR 201k+" in `i'
                    if rawname[`i']=="finadmin" qui replace name = "HH Financial Admin" in `i'
                    if rawname[`i']=="finknowd" qui replace name = "Financially Knowledgeable" in `i'
                    if rawname[`i']=="durshort" qui replace name = "Short Duration" in `i'
                    if rawname[`i']=="durlong" qui replace name = "Long Duration" in `i'
                    if rawname[`i']=="incentive0" qui replace name = "Hypothetical Treatment" in `i'
                    if rawname[`i']=="incentive1" qui replace name = "Low Incentive Treatment~$^\dag$" in `i'
                }
                // add space and id's for standard deviations of estimated parameters
                gen estimate=1
                local maxnvars2 = `maxnvars'*2
                qui set obs `maxnvars2'
                local temp = `maxnvars'+1
                qui replace id=_n-`maxnvars'+.5 in `temp'/`maxnvars2'
                qui replace estimate=2 in `temp'/`maxnvars2'
                sort id
                qui replace id=_n
                qui save `formatteddatadir'/`specname'-`Sigma', replace
                
                
                local n = 0
                foreach par in `parset' {
                    local ++n
                    // macros with long variable names due to stupid saving in fortran-code
                    if ("`par'"=="gam") local parlong "gamma"
                    if ("`par'"=="lam") local parlong "lambda"
                    if ("`par'"=="rho") local parlong "rho"
                    if ("`par'"=="tau") local parlong "tau"
                    if ("`par'"=="omg") local parlong "omega"
                    
                    // add estimates
                    insheet rawpar`n' using "../main_estimation/`model'-`datatype'-`fullsimple'/output_`Sigma'/`parlong'se.txt", clear
                    capture gen id=_n
                    capture save `temp1', replace
                    u `formatteddatadir'/`specname'-`Sigma'
                    capture merge id using `temp1', sort
                    capture drop _m
                    qui save `formatteddatadir'/`specname'-`Sigma',replace
                    qui gen par`n' = .
                    forvalues i=1/`nvars`n'' {
                        local i2=2*`i'-1
                        local i3=`i2'+1
                        if rawname[`i2']==rawname`n'[`i2'] {
                            qui replace par`n'=rawpar`n' in `i2'/`i3'
                        }
                        else {
                            forvalues j=1(2)`maxnvars2' {
                                local j2=`j'+1
                                if rawname[`j']==rawname`n'[`i2'] {
                                    qui replace par`n' =rawpar`n'[`i2'] in `j'
                                    qui replace par`n'=rawpar`n'[`i3'] in `j2'
                                }
                            }
                        }
                    }
                    qui save `formatteddatadir'/`specname'-`Sigma', replace
                }
                
                // preliminaries for out-tex
                local OUTFILE "`tablesdir_prefhet'/`model'-`datatype'-`fullsimple'-`Sigma'.tex"
                capture erase `OUTFILE'
                
                if (`ncolumns'==1) {
                    qui log using `OUTFILE', append
                    di "\begin {tabular} {lr}\hline\hline"
                    qui log c
                }
                if (`ncolumns'==2) {
                    qui log using `OUTFILE', append
                    di "\begin {tabular} {lrr}\hline\hline"
                    qui log c
                }
                if (`ncolumns'==3) {
                    qui log using `OUTFILE', append
                    di "\begin {tabular} {lrrr}\hline\hline"
                    qui log c
                }
                if (`ncolumns'==4) {
                    qui log using `OUTFILE', append
                    di "\begin {tabular} {lrrrr}\hline\hline"
                    qui log c
                }
                if (`ncolumns'==5) {
                    qui log using `OUTFILE', append
                    di "\begin {tabular} {lrrrrr}\hline\hline"
                    qui log c
                }
                if (`ncolumns'==6) {
                    qui log using `OUTFILE', append
                    di "\begin {tabular} {lrrrrrr}\hline\hline"
                    qui log c
                }
                if (`ncolumns'>6) {
                    di "Error: Too many columns specified"
                    error
                }
                // Header: First line with Subject Pool
                local COUNTER1=0
                local COUNTER2=1
                local COUNTER3=1
                local LINECNTR1=2
                local LINECNTR2=2
                
                // Header: First line with parameter names
                local COUNTER1=0
                qui log using `OUTFILE', append
                di " {\bf Covariate} "
                local n = 0
                foreach par in `parset' {
                    local ++n
                    if ("`par'"=="gam") local secline "\multicolumn {1} {c} {$\gamma$}"
                    if ("`par'"=="lam") local secline "\multicolumn {1} {c} {$\lambda$}"
                    if ("`par'"=="rho") local secline "\multicolumn {1} {c} {$\rho$}"
                    if ("`par'"=="tau") local secline "\multicolumn {1} {c} {$\tau$}"
                    if ("`par'"=="omg") local secline "\multicolumn {1} {c} {$\omega$}"
                    di "& `secline'"
                    local COUNTER1=1
                }
                di "\\\hline"
                
                di "\\[-.5ex]"
                qui log c
                
                // sort variables: incentive0/incentive1 to the bottom
                gen tempname=rawname
                forvalues i=2(2)`maxnvars2' {
                    local j=`i'-1
                    qui replace tempname=tempname[`j'] in `i'
                }
                qui replace id= 999 if tempname=="incentive0"
                qui replace id= 1000 if tempname=="incentive1"
                sort id estimate
                qui replace id=_n
                
                qui log using `OUTFILE', append
                forvalues i=1/`maxnvars2' {
                    if (rawname[`i'-1]=="incentive1") {
                        di "\vspace* {2ex}"
                    }
                    if (rawname[`i']=="sex" ///
                      | rawname[`i']=="educ_exp34" ///
                      | rawname[`i']=="ninchhcat2_exp3" ///
                      | rawname[`i']=="finadmin" ///
                      | rawname[`i']=="incentive0" ///
                      | rawname[`i']=="durshort") {
                        di "\hline"
                    }
                    di name[`i']
                    if (estimate[`i']==1) {
                        local j = 0
                        foreach par in `parset' {
                            local ++j
                            if ( (("`par'"=="lam" | "`par'"=="rho") & `i'==1) | (rawname[`i']=="incentive1") ) {
                                local b0=1
                            }
                            else {
                                local b0=0
                            }
                            local coeffprint
                            local signif
                            if (par`j'[`i']!=.) {
                                local coeff=par`j'[`i']
                                local sd=par`j'[`i'+1]
                                local signif
                                
                                if (abs(`coeff'-`b0')-invnormal(.95) *`sd'>0) {
                                    local signif "$^ {\ast}$"
                                }
                                if (abs(`coeff'-`b0')-invnormal(.975)*`sd'>0) {
                                    local signif "$^ {\ast\ast}$"
                                }
                                if (abs(`coeff'-`b0')-invnormal(.995)*`sd'>0) {
                                    local signif "$^ {\ast\ast\ast}$"
                                }
                                if (abs(`coeff')>10) {
                                    di "&" %9.1f `coeff' "`signif'"
                                }
                                if (abs(`coeff')<10 & abs(`coeff')>=1) {
                                    di "&" %9.2f `coeff' "`signif'"
                                }
                                if (abs(`coeff')<1 & abs(`coeff')>=.1) {
                                    di "&" %9.3f `coeff' "`signif'"
                                }
                                if (abs(`coeff')<.1) {
                                    di "&" %9.4f `coeff' "`signif'"
                                }
                            }
                            else {
                                di "&"
                            }
                        }
                        di "\\[-.75ex]"
                    }
                    else {
                        local j = 0
                        foreach par in `parset' {
                            local ++j
                            local coeffprint
                            if (par`j'[`i'-1]!=. & par`j'[`i']!=. ) {
                                local coeff=par`j'[`i']
                                if (abs(`coeff')>10) {
                                    di "& \tiny {(" %9.1f `coeff' ")}"
                                }
                                if (abs(`coeff')<10 & abs(`coeff')>=1) {
                                    di "& \tiny {(" %9.2f `coeff' ")}"
                                }
                                if (abs(`coeff')<1 & abs(`coeff')>=.1) {
                                    di "& \tiny {(" %9.3f `coeff' ")}"
                                }
                                if (abs(`coeff')<.1) {
                                    di "& \tiny {(" %9.4f `coeff' ")}"
                                }
                            }
                            else {
                                di "&"
                            }
                        }
                        di "\\"
                    }
                }
                qui log c
                
                qui log using `OUTFILE', append
                di "\hline\hline\end {tabular}"
                qui log c
                
                save `formatteddatadir'/`specname'-`Sigma', replace
                
            }
            capture erase `temp1'.dta
            capture erase `temp2'.dta
        }
    }
}

scons_returncode

