__doc__ = "Function setting options in the Stata builder and emitter/scanner"

__revision__ = '$Id: stata_options.py 33 2008-10-18 14:49:39Z hgaudecker $'

from SCons.Script import *

### @export "determine_options"
def determine_options(target, source_node, env):
    """
    Determines the configuration of the Stata builder, i.e. whether
    the standard log file is deleted or not and whether input files 
    should be scanned for implicit dependencies / targets.
    Default is deletion of standard log files and scanning of files.
    Standard log files are kept if (1) deletion is turned off, or
    (2) deletion is turned on but standard log file is explicit target.
    """
    options = {}
    # get name and path of default log file
    source_file_base, source_file_ext = os.path.splitext(str(source_node))
    options['default_log'] = File(os.path.join(source_file_base + '.log'))
    # see whether option to delete the standard log file has been set, 
    # otherwise continue with default of deletion.
    try:
        options['log_delete'] = env['log_delete']
    except:
        options['log_delete'] = True
    # override deletion of standard log file if it is 
    # explicitly mentioned in the target file list.
    if options['log_delete'] == True:
        if options['default_log'] in target:
            options['log_delete'] = False
    # see whether option to scan the file has been set, otherwise
    # continue with default of scanning.
    try:
        options['scan_file'] = env['scan_file']
    except:
        options['scan_file'] = True
        
    return options
### @end